@@ -31,8 +31,6 @@ import com.biglybt.core.config.impl.ConfigurationDefaults;
 import com.biglybt.core.config.impl.ConfigurationManager;
 import com.biglybt.core.util.*;
 import com.biglybt.core.util.protocol.AzURLStreamHandlerFactory;
-import com.biglybt.core.util.spi.AENameServiceJava9;
-import com.biglybt.core.util.spi.AENameServiceJava12;
 
 public class
 COConfigurationManager
@@ -234,13 +232,22 @@ COConfigurationManager
 
 				if ( Constants.isJava9OrHigher ){
 					
-					if ( Constants.isJava12OrHigher ){
+					try{
+						if ( Constants.isJava12OrHigher ){
+							
+								// AENameServiceJava12.init();
+							
+							Class.forName( "com.biglybt.core.util.spi.AENameServiceJava12").getMethod( "init" ).invoke( null );
+							
+						}else{
+							
+								// AENameServiceJava9.init();
+							
+							Class.forName( "com.biglybt.core.util.spi.AENameServiceJava9").getMethod( "init" ).invoke( null );
+						}
+					}catch( Throwable e ){
 						
-						AENameServiceJava12.init();
-						
-					}else{
-						
-						AENameServiceJava9.init();
+						// issues will be reported later
 					}
 				}else{
 					
@@ -644,6 +651,49 @@ COConfigurationManager
 		}
 	}
 	
+	public static void
+	addAndFireWeakParameterListener(String parameter, ParameterListener listener)
+	{
+	  ConfigurationManager.getInstance().addWeakParameterListener(parameter, listener);
+
+	  try {
+		  listener.parameterChanged( parameter );
+
+	  }catch (Throwable e) {
+
+		  Debug.printStackTrace(e);
+	  }
+	}
+
+	public static void
+	addAndFireWeakParameterListeners(String[] parameters, ParameterListener listener)
+	{
+		for (int i=0;i<parameters.length;i++){
+			ConfigurationManager.getInstance().addWeakParameterListener(parameters[i], listener);
+		}
+
+		try{
+			listener.parameterChanged( null );	// code out there relies on the param being null, no changey!
+
+		}catch (Throwable e) {
+
+			Debug.printStackTrace(e);
+		}
+	}
+	public static void
+	removeWeakParameterListener(String parameter, ParameterListener listener)
+	{
+		ConfigurationManager.getInstance().removeWeakParameterListener(parameter, listener);
+	}
+
+	public static void
+	removeWeakParameterListeners(String[] parameters, ParameterListener listener)
+	{
+		for ( String parameter: parameters ){
+			ConfigurationManager.getInstance().removeWeakParameterListener(parameter, listener);
+		}
+	}
+	
 	public static void
 	removeListener(
 		COConfigurationListener		listener )
