@@ -21,6 +21,8 @@
 
 package com.biglybt.core.config.impl;
 
+import static com.biglybt.core.config.ConfigKeys.Tag.BCFG_TAG_SHOW_SWARM_TAGS_IN_OVERVIEW;
+
 import java.io.File;
 import java.util.*;
 
@@ -225,11 +227,13 @@ public class ConfigurationDefaults {
     def.put("On Resume Recheck All", FALSE);
     def.put("Save Resume Interval", new Long(5));
     def.put("Check Pieces on Completion", TRUE);
+    def.put("Check Pieces on Completion Before Move", FALSE);
     def.put("Merge Same Size Files", TRUE );
     def.put("Merge Same Size Files Extended", FALSE );
     def.put("Merge Same Size Files Tolerance", ZERO );
     def.put(ConfigKeys.File.ICFG_MERGE_SAME_SIZE_FILES_MIN_PIECES, 5 );
     def.put(ConfigKeys.File.BCFG_SKIP_COMP_DL_FILE_CHECKS, FALSE );
+    def.put(ConfigKeys.File.BCFG_SKIP_INCOMP_DL_FILE_CHECKS, FALSE );
     def.put(ConfigKeys.File.BCFG_FILE_MOVE_ORIGIN_DELETE_FAIL_IS_WARNING, FALSE );
     def.put("Stop Ratio", new Float(0));
     def.put("Stop Peers Ratio", ZERO);
@@ -289,7 +293,8 @@ public class ConfigurationDefaults {
     def.put("Prevent Sleep FP Seeding", FALSE );
     def.put("Prevent Sleep Tag", "" );
 
-    def.put("Auto Restart When Idle", ZERO );
+    def.put(ConfigKeys.StartupShutdown.ICFG_AUTO_RESTART_WHEN_IDLE, ZERO );
+    def.put(ConfigKeys.StartupShutdown.BCFG_AUTO_RESTART_WHEN_IDLE_PROMPT, TRUE );
 
     def.put( "Download History Enabled", TRUE );
 
@@ -459,6 +464,7 @@ public class ConfigurationDefaults {
 
     def.put( Tag.BCFG_TRACKER_AUTO_TAG_INTERESTING_TRACKERS, TRUE );
     def.put( Tag.ICFG_TAG_AUTO_FULL_REAPPLY_PERIOD_SECS, 30 );
+    def.put( Tag.BCFG_TAG_SHOW_SWARM_TAGS_IN_OVERVIEW, TRUE );
     
     //default torrent directory option
     def.put( "Save Torrent Files", TRUE );
@@ -581,6 +587,7 @@ public class ConfigurationDefaults {
     def.put( "Peer Source Selection Default.PeerExchange", TRUE);
     def.put( "Peer Source Selection Default.Plugin", TRUE);
     def.put( "Peer Source Selection Default.Incoming", TRUE);
+    def.put( "Peer Source Selection Default.HolePunch", TRUE);
 
     def.put( "config.style.useSIUnits", FALSE );
     def.put( "config.style.forceSIValues", Constants.isOSX?FALSE:TRUE );
@@ -617,6 +624,7 @@ public class ConfigurationDefaults {
     def.put( "diskmanager.hashchecking.strategy", ONE );
     def.put( "diskmanager.hashchecking.smallestfirst", TRUE );
     def.put( ConfigKeys.File.BCFG_DISKMANAGER_ONE_OP_PER_FS, FALSE );
+    def.put( ConfigKeys.File.BCFG_DISKMANAGER_ONE_OP_PER_FS_CONC_READ, FALSE );
     def.put( "diskmanager.hashchecking.maxactive", ONE );
     def.put( "Default Start Torrents Stopped", FALSE);
     def.put( "Default Start Torrents Stopped Auto Pause", FALSE );
@@ -650,7 +658,7 @@ public class ConfigurationDefaults {
     def.put( "peercontrol.udp.fallback.connect.fail", TRUE );
     def.put( "peercontrol.udp.fallback.connect.drop", TRUE );
     def.put( "peercontrol.udp.probe.enable", FALSE );
-    def.put( "peercontrol.hide.piece", FALSE );
+    def.put( ConfigKeys.Transfer.BCFG_PEERCONTROL_HIDE_PIECE, FALSE );
     def.put( "peercontrol.scheduler.use.priorities", TRUE );
     def.put( "peercontrol.prefer.udp", FALSE );
     def.put( ConfigKeys.Connection.BCFG_PEERCONTROL_PREFER_IPV6_CONNECTIONS, FALSE );
@@ -729,6 +737,7 @@ public class ConfigurationDefaults {
     def.put( "Completed Files Directory", "" );
     def.put( "Move Only When In Default Save Dir", TRUE );
     def.put( "Move Torrent When Done", TRUE );
+    def.put( ConfigKeys.File.BCFG_FILE_MOVE_ADD_SUB_FOLDER, FALSE );
     def.put( ConfigKeys.File.SCFG_FILE_USE_TEMP_AND_MOVE_PATH, "" );
     def.put( ConfigKeys.File.BCFG_FILE_USE_TEMP_AND_MOVE_ENABLE, FALSE );
 
