@@ -238,15 +238,18 @@ ConfigurationManager
     load(CONFIG_FILENAME);
 
     try {
-      String[] keys = propertiesMap.keySet().toArray(new String[0]);
-      for (String key : keys) {
-      	if (key == null) {
-      		continue;
-      	}
-  			if (key.startsWith("SideBar.Expanded.AutoOpen.") || key.startsWith("NameColumn.wrapText.")) {
-  				removeParameter(key);
-  			}
-  		}
+    	String[] keys = propertiesMap.keySet().toArray(new String[0]);
+    	for (String key : keys) {
+    		if (key == null) {
+    			continue;
+    		}
+    			// remove old potentially non-ascii keys
+    		if ( 	key.startsWith("SideBar.Expanded.") || 
+    				key.startsWith("NameColumn.wrapText.")) {
+    			
+    			removeParameter(key);
+    		}
+    	}
     } catch (Exception e) {
     	// not sure if I can do Debug.out here.. could be in that evil
     	// preinitialization loop of dooom
@@ -687,6 +690,22 @@ ConfigurationManager
 		return changed;
 	}
 
+	public int[] getRGBParameter(String parameter) {
+		
+		int	r = getIntParameter( parameter + ".red", -1 );
+		int	g = getIntParameter( parameter + ".green", -1 );
+		int	b = getIntParameter( parameter + ".blue", -1 );
+		
+		if ( 	r < 0 || r > 255 ||
+				g < 0 || g > 255 ||
+				b < 0 || b > 255 ){
+			
+			return( null );
+		}
+		
+		return( new int[]{ r, g, b });
+	}	
+	
 	public Object
   getParameter(
 	String	name )
