@@ -28,8 +28,11 @@ DHTTransportAlternativeNetwork
 	public static final int	AT_MLDHT_IPV4		= 1;
 	public static final int	AT_MLDHT_IPV6		= 2;
 	public static final int	AT_I2P				= 3;
+	public static final int	AT_BIGLYBT_IPV4		= 4;	// these are hardcoded in i2p plugin during migration
+	public static final int	AT_BIGLYBT_IPV6		= 5;	// these are hardcoded in i2p plugin during migration
 
-	public static final int[]	AT_ALL = { AT_MLDHT_IPV4, AT_MLDHT_IPV6, AT_I2P };
+	public static final int[]	AT_ALL_PUB = { AT_MLDHT_IPV4, AT_MLDHT_IPV6, AT_I2P };
+	public static final int[]	AT_ALL_I2P = { AT_BIGLYBT_IPV4, AT_BIGLYBT_IPV6 };
 
 	public int
 	getNetworkType();
