@@ -39,6 +39,7 @@ import com.biglybt.core.util.IndentWriter;
 public interface
 DiskManager
 {
+	public static final int SNAPSHOT = 0;
 	public static final int INITIALIZING = 1;
 	public static final int ALLOCATING = 2;
 	public static final int CHECKING = 3;
@@ -288,6 +289,9 @@ DiskManager
 	public int
 	getCompleteRecheckStatus();
 
+	public boolean
+	getRecheckCancelled();
+	
 		/**
 		 * When a download's data is moving (for completion or removal events) this gives the [progress in 1000 notation,total_size]
 		 * null if nothing's going on
