@@ -23,6 +23,7 @@ package com.biglybt.core.disk.impl;
 import com.biglybt.core.CoreOperation;
 import com.biglybt.core.CoreOperationTask;
 import com.biglybt.core.config.COConfigurationManager;
+import com.biglybt.core.config.ConfigKeys;
 import com.biglybt.core.config.ParameterListener;
 import com.biglybt.core.disk.*;
 import com.biglybt.core.disk.DiskManager.DownloadEndedProgress;
@@ -240,7 +241,14 @@ DiskManagerUtil
 							
 							File currentFile = file.getFile(true);
 							
-							FileUtil.deleteWithRecycle( currentFile, dm.getDownloadState().getFlag( DownloadManagerState.FLAG_LOW_NOISE ));
+								// these are compact files and can't be recovered as they just contain
+								// start/end piece data
+							
+							boolean no_recycle = true;
+							
+							FileUtil.deleteWithRecycle( 
+									currentFile, 
+									dm.getDownloadState().getFlag( DownloadManagerState.FLAG_LOW_NOISE ) || no_recycle );
 						}
 					}
 				}
@@ -262,6 +270,7 @@ DiskManagerUtil
 	    DiskManagerFileInfo    		file_info,
 	    File                   		from_file,
 	    File                   		to_link,
+	    boolean						dont_delete_existing,
 	    FileUtil.ProgressListener	pl )
 	{
 	    if ( to_link != null ){
@@ -323,21 +332,25 @@ DiskManagerUtil
 					                return( error );
 					            }
 				        	}else{
-				        	
-					        	Object	skip_delete = download_manager.getUserData( "set_link_dont_delete_existing" );
-			
+				        				
 					        		// user is manually re-targetting a file - this hack is to stop us from deleting the old file which
 					        		// we really have no right to go and delete
 			
-					        	if ( ( skip_delete instanceof Boolean ) && (Boolean)skip_delete ){
+					        	if ( dont_delete_existing ){
 			
 					        		 download_manager.recheckFile( file_info );
 			
 					        	}else{
 			
+					        		int st = file_info.getStorageType();
+
+										// don't bother recycling if compact as just contain start/end piece data
+									
+									boolean no_recycle = st == DiskManagerFileInfo.ST_COMPACT || st == DiskManagerFileInfo.ST_REORDER_COMPACT;
+									
 					                if ( FileUtil.deleteWithRecycle(
 					                		existing_file,
-					                		download_manager.getDownloadState().getFlag( DownloadManagerState.FLAG_LOW_NOISE ))){
+					                		download_manager.getDownloadState().getFlag( DownloadManagerState.FLAG_LOW_NOISE ) || no_recycle )){
 			
 						                    // new file, recheck
 			
@@ -453,6 +466,12 @@ DiskManagerUtil
 						return res;
 					}
 
+					private DiskManager
+					getDiskManager()
+					{
+						return( null );
+					}
+					
 					@Override
 					public int nbFiles() {
 						return res.length;
@@ -473,7 +492,7 @@ DiskManagerUtil
 
 						for(int i=0;i<res.length;i++)
 							if(newPriorities[i] != 0 )
-								listener.filePriorityChanged(res[i]);
+								listener.filePriorityChanged(getDiskManager(),res[i]);
 					}
 
 					@Override
@@ -559,7 +578,7 @@ DiskManagerUtil
 
 						for(int i=0;i<res.length;i++){
 							if(toChange[i]){
-								listener.filePriorityChanged(res[i]);
+								listener.filePriorityChanged(getDiskManager(),res[i]);
 							}
 						}
 
@@ -732,7 +751,7 @@ DiskManagerUtil
 						
 						for(int i=0;i<res.length;i++){
 							if(toChange[i]){
-								listener.filePriorityChanged(res[i]);
+								listener.filePriorityChanged(getDiskManager(),res[i]);
 							}
 						}
 						
@@ -762,7 +781,7 @@ DiskManagerUtil
 
 		            		DiskManagerImpl.storeFilePriorities( download_manager, res );
 
-		            		listener.filePriorityChanged( this );
+		            		listener.filePriorityChanged( getDiskManager(), this );
 		            	}
 
 		            	@Override
@@ -792,7 +811,7 @@ DiskManagerUtil
 			            			download_manager.getDownloadState().setFileLink( file_index, getFile( false ), to_link );
 			            		}
 	
-			            		listener.filePriorityChanged( this );
+			            		listener.filePriorityChanged( getDiskManager(), this );
 	
 		            			boolean[] toCheck = new boolean[fileSetSkeleton.nbFiles()];
 			            			
@@ -1148,7 +1167,8 @@ DiskManagerUtil
 	                	@Override
 		                public boolean
 	                	setLink(
-	                		File    link_destination )
+	                		File    	link_destination,
+	                		boolean		no_delete )
 	                	{
 	                		last_error = null;
 	                		
@@ -1170,7 +1190,7 @@ DiskManagerUtil
 	                				return false;
 	                			}
 	                		}
-	                		return setLinkAtomic(link_destination);
+	                		return setLinkAtomic(link_destination, no_delete );
 	                	}
 
 	    				@Override
@@ -1181,9 +1201,10 @@ DiskManagerUtil
 	                	@Override
 		                public boolean
 	                	setLinkAtomic(
-	                		File    link_destination )
+	                		File    	link_destination,
+	                		boolean		no_delete)
 	                	{
-	                		last_error = setFileLink( download_manager, res, this, lazyGetFile(), link_destination, null );
+	                		last_error = setFileLink( download_manager, res, this, lazyGetFile(), link_destination, no_delete, null );
 	                		
 	                		return( last_error == null );
 	                	}
@@ -1192,9 +1213,10 @@ DiskManagerUtil
 		                public boolean
 	                	setLinkAtomic(
 	                		File    						link_destination,
+	                		boolean							no_delete,
 	                		FileUtil.ProgressListener		pl )
 	                	{
-	                		last_error = setFileLink( download_manager, res, this, lazyGetFile(), link_destination , pl);
+	                		last_error = setFileLink( download_manager, res, this, lazyGetFile(), link_destination, no_delete, pl);
 	                		
 	                		return( last_error == null );
 	                	}
@@ -1704,15 +1726,15 @@ DiskManagerUtil
 					new DiskManagerListener(){
 						
 						@Override
-						public void stateChanged(int oldState, int newState){
+						public void stateChanged(DiskManager dm, int oldState, int newState){
 						}
 						
 						@Override
-						public void pieceDoneChanged(DiskManagerPiece piece){
+						public void pieceDoneChanged(DiskManager dm, DiskManagerPiece piece){
 						}
 						
 						@Override
-						public void filePriorityChanged(DiskManagerFileInfo file){
+						public void filePriorityChanged(DiskManager dm, DiskManagerFileInfo file){
 						}
 					});
 				
@@ -1827,7 +1849,7 @@ DiskManagerUtil
 					
 					@Override
 					public int getState(){
-						return 0;
+						return( SNAPSHOT );
 					}
 					
 					@Override
@@ -1950,6 +1972,13 @@ DiskManagerUtil
 						return 0;
 					}
 					
+					@Override
+					public boolean
+					getRecheckCancelled()
+					{
+						return( false );
+					}
+					
 					@Override
 					public int getCacheMode(){
 						return 0;
@@ -2281,8 +2310,47 @@ DiskManagerUtil
 					@Override
 					public void
 					run(
-							CoreOperation operation)
+						CoreOperation operation)
 					{
+						boolean has_scheduler = DiskManagerOperationScheduler.isEnabled();
+						
+							// if nothing is scheduling operations then we have to implement
+							// the 'recheck before move' ourselves (with a scheduler the move operation
+							// is guaranteed to be added after the recheck operation if so configured)
+						
+						if ( !has_scheduler ){
+							
+							while( true ){
+							
+								boolean checkBeforeMove	= COConfigurationManager.getBooleanParameter(ConfigKeys.File.BCFG_CHECK_PIECES_ON_COMPLETION_BEFORE_MOVE);
+
+								if ( checkBeforeMove ){
+									
+									DiskManager dm = download_manager.getDiskManager();
+									
+									if ( dm != null && dm.getCompleteRecheckStatus() >= 0 ){
+																				
+										try{
+											Thread.sleep( 500 );
+											
+										}catch( Throwable e ){
+											
+										}
+										
+										if ( callback.getTaskState() == ProgressCallback.ST_CANCEL ){
+
+											throw( new RuntimeException( "Cancelled" ));
+										}
+									}else{
+										
+										break;
+									}
+								}else{
+									
+									break;
+								}
+							}
+						}
 						boolean ready;
 
 						synchronized( move_tasks ){
@@ -2293,7 +2361,7 @@ DiskManagerUtil
 						}
 
 						try{
-							if ( DiskManagerOperationScheduler.isEnabled()){
+							if ( has_scheduler ){
 
 								while( callback.getTaskState() == ProgressCallback.ST_PAUSE ){
 
