@@ -25,11 +25,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 import com.biglybt.core.disk.DiskManagerFileInfo;
-import com.biglybt.core.disk.impl.DiskManagerFileInfoImpl;
-import com.biglybt.core.disk.impl.piecemapper.DMPieceList;
-import com.biglybt.core.disk.impl.piecemapper.DMPieceMap;
-import com.biglybt.core.disk.impl.piecemapper.DMPieceMapper;
-import com.biglybt.core.disk.impl.piecemapper.DMPieceMapperFile;
+import com.biglybt.core.disk.impl.piecemapper.*;
 import com.biglybt.core.internat.LocaleUtilDecoder;
 import com.biglybt.core.torrent.TOTorrent;
 import com.biglybt.core.torrent.TOTorrentFile;
@@ -335,17 +331,20 @@ PieceMapperImpl
 	{
 		private DiskManagerFileInfo					file;
 		private final TOTorrentFile					torrent_file;
-		private final String 						path;
+		private final String 						relative_path;
 		private final String 						name;
 
+		/**
+		 * @param _relative_path  Blank or Relative Path with trailing File.separator
+		 */
 		public
 		fileInfo(
 			TOTorrentFile	_torrent_file,
-			String 			_path,
+			String 			_relative_path,
 			String 			_name )
 		{
 			torrent_file	= _torrent_file;
-			path			= StringInterner.intern(_path);
+			relative_path = StringInterner.intern(_relative_path);
 			name 			= _name;
 		}
 
@@ -354,10 +353,9 @@ PieceMapperImpl
 			return torrent_file.getLength();
 		}
 		@Override
-		public File
-		getDataFile()
+		public String getRelativeDataPath()
 		{
-			return( FileUtil.newFile( path, name ));
+			return relative_path + name;
 		}
 		@Override
 		public TOTorrentFile
