@@ -91,7 +91,8 @@ DownloadManagerState
 	public static final String AT_TORRENT_SAVE_TIME			= "tst";			// long
 	public static final String AT_TORRENT_EXPORT_PROPAGATED	= "tep";			// bool
 	public static final String AT_SWARM_TAGS				= "stag";			// list
-	public static final String AT_MASK_DL_COMP				= "mdlc";			// bool
+	public static final String AT_MASK_DL_COMP_OPTIONAL		= "mdlc";			// Boolean (optional)
+	public static final String AT_REAL_DM_MAGNET_TIME		= "rdmmt";			// long
 	
 	public static final String AT_TRANSIENT_FLAGS			= "t_flags";
 
@@ -261,6 +262,18 @@ DownloadManagerState
 	public boolean
 	isResumeDataComplete();
 
+	/**
+	 * Ordered by time, most recent last
+	 * @return
+	 */
+	
+	public List<ResumeHistory>
+	getResumeDataHistory();
+	
+	public void
+	restoreResumeData(
+		ResumeHistory	history );
+	
 	public void
 	clearTrackerResponseCache();
 
@@ -383,6 +396,7 @@ DownloadManagerState
 
 	// General access - make sure you use an AT_ value defined above when calling
 	// these methods.
+	
 	public void setAttribute(String	name, String value);
 	public void setAttribute(String	name, String value, boolean setDirty);
 	public String getAttribute(String name);
@@ -398,7 +412,32 @@ DownloadManagerState
 	public void setBooleanAttribute(String name, boolean value);
 	public boolean getBooleanAttribute(String name);
 	public boolean hasAttribute(String name);
+	public void removeAttribute(String name);
 
+	public default Boolean
+	getOptionalBooleanAttribute(
+		String		name )
+	{
+		if ( hasAttribute(name)){
+			return( getBooleanAttribute(name));
+		}else{
+			return( null );
+		}
+	}
+	
+	public default void
+	setOptionalBooleanAttribute(
+		String		name,
+		Boolean		value )
+	{
+		if ( value == null ){
+			removeAttribute( name );
+		}else{
+			setBooleanAttribute(name, value );
+		}
+	}
+
+	
 	public void
 	setActive(
 		boolean	active );
@@ -442,4 +481,11 @@ DownloadManagerState
 
 	public void addListener(DownloadManagerStateAttributeListener l, String attribute, int event_type);
 	public void removeListener(DownloadManagerStateAttributeListener l, String attribute, int event_type);
+	
+	public interface
+	ResumeHistory
+	{
+		public long 
+		getDate();
+	}
 }
