@@ -31,6 +31,7 @@ import com.biglybt.core.config.ParameterListener;
 import com.biglybt.core.disk.*;
 import com.biglybt.core.disk.impl.DiskManagerUtil;
 import com.biglybt.core.download.*;
+import com.biglybt.core.download.DownloadManagerState.ResumeHistory;
 import com.biglybt.core.global.GlobalManager;
 import com.biglybt.core.global.GlobalManagerEvent;
 import com.biglybt.core.global.GlobalManagerStats;
@@ -42,6 +43,7 @@ import com.biglybt.core.logging.Logger;
 import com.biglybt.core.networkmanager.LimitedRateGroup;
 import com.biglybt.core.networkmanager.NetworkConnection;
 import com.biglybt.core.networkmanager.NetworkManager;
+import com.biglybt.core.networkmanager.Transport;
 import com.biglybt.core.peer.*;
 import com.biglybt.core.peermanager.PeerManager;
 import com.biglybt.core.peermanager.PeerManagerRegistration;
@@ -380,7 +382,7 @@ DownloadManagerController
 				
 				download_manager_state.removeListener(
 						dm_attribute_listener,
-						DownloadManagerState.AT_MASK_DL_COMP,
+						DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL,
 						DownloadManagerStateAttributeListener.WRITTEN );
 
 				dm_attribute_listener = null;
@@ -646,7 +648,7 @@ DownloadManagerController
 
 								if ( !allowed.contains( peer.getPeerSource())){
 
-									pm.removePeer( peer, "Peer source not permitted" );
+									pm.removePeer( peer, "Peer source not permitted", Transport.CR_STOPPED_OR_REMOVED );
 								}
 							}
 						}
@@ -678,7 +680,7 @@ DownloadManagerController
 				
 				download_manager_state.removeListener(
 						dm_attribute_listener,
-						DownloadManagerState.AT_MASK_DL_COMP,
+						DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL,
 						DownloadManagerStateAttributeListener.WRITTEN );
 			}
 			
@@ -718,7 +720,7 @@ DownloadManagerController
 						}
 					}
 					
-					boolean mask = download_manager_state.getBooleanAttribute(DownloadManagerState.AT_MASK_DL_COMP );
+					Boolean mask = download_manager_state.getOptionalBooleanAttribute(DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL );
 
 					temp.setMaskDownloadCompletion( mask );
 				}
@@ -731,7 +733,7 @@ DownloadManagerController
 			
 			download_manager_state.addListener(
 					dm_attribute_listener,
-					DownloadManagerState.AT_MASK_DL_COMP,
+					DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL,
 					DownloadManagerStateAttributeListener.WRITTEN );
 
 			dm_attribute_listener.attributeEventOccurred( null, null, -1 );	// set initial state
@@ -860,7 +862,7 @@ DownloadManagerController
 	
 	public void
 	forceRecheck(
-		final ForceRecheckListener l)
+		Map						resume_data )
 	{
 		try{
 			control_mon.enter();
@@ -883,10 +885,16 @@ DownloadManagerController
 			
 			int start_state = DownloadManagerController.this.getState();
 
-				// remove resume data
-
-			download_manager_state.clearResumeData();
-
+			if ( resume_data == null ){
+					// remove resume data
+	
+				download_manager_state.clearResumeData();
+				
+			}else{
+				
+				download_manager_state.setResumeData( resume_data );
+			}
+			
 	  			// For extra protection from a plugin stopping a checking torrent,
 	  			// fake a forced start.
 
@@ -909,15 +917,29 @@ DownloadManagerController
 	  				{
 	  					public void 
 	  					forceRecheckComplete(
-	  						DownloadManager dm)
+	  						DownloadManager dm,
+	  						boolean			cancelled )
 	  					{
 	  						is_force_rechecking = false;
 	  						
-	  						download_manager.fireGlobalManagerEvent( GlobalManagerEvent.ET_RECHECK_COMPLETE,  true );
+	  							// only fire for actual rechecks rather than restoring of resume state
 	  						
-	  						if ( l != null ){
+	  						if ( resume_data == null ){
+	  						
+	  							download_manager.fireGlobalManagerEvent( GlobalManagerEvent.ET_RECHECK_COMPLETE,  new Object[]{ true, cancelled });
 	  							
-	  							l.forceRecheckComplete(dm);
+	  							if ( cancelled ){
+	  								
+	  								List<ResumeHistory> history = download_manager_state.getResumeDataHistory();
+	  								
+	  								if ( !history.isEmpty()){
+	  									
+	  									AEThread2.createAndStartDaemon( "resetResume", ()->{
+	  										
+	  										download_manager_state.restoreResumeData( history.get( history.size()-1));
+	  									});
+	  								}
+	  							}
 	  						}
 	  					}
 	  				}));
@@ -928,6 +950,15 @@ DownloadManagerController
 		}
 	}
 
+	interface
+	ForceRecheckListener
+	{
+		public void 
+		forceRecheckComplete(
+			DownloadManager dm,
+			boolean			cancelled );
+	}
+	
  	public void
   	setPieceCheckingEnabled(
   		boolean enabled )
@@ -1045,7 +1076,7 @@ DownloadManagerController
 								
 								download_manager_state.removeListener(
 										dm_attribute_listener,
-										DownloadManagerState.AT_MASK_DL_COMP,
+										DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL,
 										DownloadManagerStateAttributeListener.WRITTEN );
 
 								dm_attribute_listener = null;
@@ -1514,7 +1545,7 @@ DownloadManagerController
 								// disconnect all peers - this is required as the new network assignment can
 								// require an alternative destination to be used for peer connections
 
-							pm.removeAllPeers( "Networks changed, reconnection required" );
+							pm.removeAllPeers( "Networks changed, reconnection required", Transport.CR_NONE );
 						}
 					}
 				},
@@ -3090,10 +3121,10 @@ DownloadManagerController
 						}
 						active = DiskManagerFactory.getFileInfoSkeleton(download_manager, new DiskManagerListener() {
 							@Override
-							public void stateChanged(int oldState, int newState) {}
+							public void stateChanged(DiskManager dm, int oldState, int newState) {}
 
 							@Override
-							public void filePriorityChanged(DiskManagerFileInfo file) {
+							public void filePriorityChanged(DiskManager dm, DiskManagerFileInfo file) {
 								if (initialising[0]) {
 									delayed_prio_changes.add(file);
 								} else {
@@ -3102,8 +3133,12 @@ DownloadManagerController
 							}
 
 							@Override
-							public void pieceDoneChanged(DiskManagerPiece piece) {}
-
+							public void pieceDoneChanged(DiskManager dm, DiskManagerPiece piece) {}
+							
+							@Override
+							public void fileCompleted(DiskManager dm, DiskManagerFileInfo file){
+								// nothing to do here
+							}
 						});
 					} finally {
 						initialising[0] = false;
@@ -3123,6 +3158,7 @@ DownloadManagerController
 			}
 
 			fileFacadeSet.facadeFiles = info;
+			
 			download_manager.informPrioritiesChange(delayed_prio_changes);
 
 			delayed_prio_changes.clear();
@@ -3246,9 +3282,10 @@ DownloadManagerController
 		@Override
 		public boolean
 		setLink(
-			File	link_destination )
+			File	link_destination,
+			boolean	no_delete )
 		{
-			return( delegate.setLink( link_destination ));
+			return( delegate.setLink( link_destination, no_delete ));
 		}
 		
 		@Override
@@ -3259,18 +3296,20 @@ DownloadManagerController
 		@Override
 		public boolean
 		setLinkAtomic(
-			File	link_destination )
+			File		link_destination,
+			boolean		no_delete )
 		{
-			return( delegate.setLinkAtomic( link_destination ));
+			return( delegate.setLinkAtomic( link_destination, no_delete ));
 		}
 		
 		@Override
 		public boolean
 		setLinkAtomic(
 			File						link_destination,
+			boolean						no_delete,
 			FileUtil.ProgressListener 	pl )
 		{
-			return( delegate.setLinkAtomic( link_destination, pl ));
+			return( delegate.setLinkAtomic( link_destination, no_delete, pl ));
 		}
 		
 
@@ -3564,19 +3603,25 @@ DownloadManagerController
 
 		private final ForceRecheckListener l;
 
-		public ForceRecheckDiskManagerListener(boolean wasForceStarted,
-				int start_state, ForceRecheckListener l) {
+		public 
+		ForceRecheckDiskManagerListener(
+			boolean 				wasForceStarted,
+			int 					start_state, 
+			ForceRecheckListener 	l ) 
+		{
 			this.wasForceStarted = wasForceStarted;
 			this.start_state = start_state;
 			this.l = l;
 		}
 
 		@Override
-		public void stateChanged(int oldDMState, int newDMState) {
+		public void stateChanged(DiskManager dm, int oldDMState, int newDMState) {
 			try {
 				control_mon.enter();
 
-				if (getDiskManager() == null) {
+				DiskManager latest_dm = getDiskManager();
+				
+				if ( latest_dm == null || latest_dm != dm ) {
 
 					// already closed down via stop
 
@@ -3584,7 +3629,7 @@ DownloadManagerController
 
 					if ( l != null ){
 						
-						l.forceRecheckComplete(download_manager);
+						l.forceRecheckComplete(download_manager, dm.getRecheckCancelled());
 					}
 
 					return;
@@ -3615,9 +3660,9 @@ DownloadManagerController
 						try {
 							control_mon.enter();
 
-							DiskManager dm = getDiskManager();
+							DiskManager latest_dm = getDiskManager();
 
-							if (dm != null) {
+							if (latest_dm != null && latest_dm == dm ){
 
 								dm.stop(false);
 
@@ -3660,9 +3705,9 @@ DownloadManagerController
 					try {
 						control_mon.enter();
 
-						DiskManager dm = getDiskManager();
+						DiskManager latest_dm = getDiskManager();
 
-						if (dm != null) {
+						if (latest_dm != null && latest_dm == dm ) {
 
 							dm.stop(false);
 
@@ -3680,18 +3725,23 @@ DownloadManagerController
 				
 				if ( l != null ){
 					
-					l.forceRecheckComplete(download_manager);
+					l.forceRecheckComplete(download_manager, dm.getRecheckCancelled());
 				}
 			}
 		}
 
 		@Override
-		public void filePriorityChanged(DiskManagerFileInfo file) {
+		public void filePriorityChanged(DiskManager	dm, DiskManagerFileInfo file) {
 			download_manager.informPriorityChange(file);
 		}
 
 		@Override
-		public void pieceDoneChanged(DiskManagerPiece piece) {
+		public void pieceDoneChanged(DiskManager dm, DiskManagerPiece piece) {
+		}
+		
+		@Override
+		public void fileCompleted(DiskManager dm, DiskManagerFileInfo file){
+			download_manager.informFileCompletionChange(file);
 		}
 	}
 
@@ -3705,17 +3755,16 @@ DownloadManagerController
 		@Override
 		public void
 		stateChanged(
-			int 	oldDMState,
-			int		newDMState )
+			DiskManager		dm, 
+			int 			oldDMState,
+			int				newDMState )
 		{
-			DiskManager	dm;
-
 			try{
 				control_mon.enter();
 
-				dm = getDiskManager();
+				DiskManager latest_dm = getDiskManager();
 
-				if ( dm == null ){
+				if ( latest_dm == null || latest_dm != dm ){
 
 					// already been cleared down
 
@@ -3817,6 +3866,7 @@ DownloadManagerController
 		@Override
 		public void
 		filePriorityChanged(
+			DiskManager			dm, 
 			DiskManagerFileInfo	file )
 		{
 			download_manager.informPriorityChange( file );
@@ -3825,8 +3875,18 @@ DownloadManagerController
 		@Override
 		public void
 		pieceDoneChanged(
+			DiskManager			dm, 
 			DiskManagerPiece	piece )
 		{
 		}
+		
+		@Override
+		public void 
+		fileCompleted(
+			DiskManager			dm, 
+			DiskManagerFileInfo file)
+		{
+			download_manager.informFileCompletionChange( file );
+		}
 	}
 }
