@@ -123,6 +123,8 @@ DownloadManagerStatsImpl
 
 	private int	last_sr_progress = -1;
 
+	private int[]		file_priority_stats = { 0,0,0,0 };
+	
 	protected
 	DownloadManagerStatsImpl(
 		DownloadManagerImpl	dm )
@@ -1585,6 +1587,20 @@ DownloadManagerStatsImpl
 		return saved_skipped_file_set_size;
 	}
 
+	protected void
+	setFilePriorityStats(
+		int[]	stats )
+	{
+		file_priority_stats = stats;
+	}
+	
+	@Override
+	public int[] 
+	getFilePriorityStats()
+	{
+		return( file_priority_stats );
+	}
+	
 	@Override
   public long
   getRemainingExcludingDND()
@@ -1641,9 +1657,17 @@ DownloadManagerStatsImpl
 		if (sizeExcludingDND < 0) {
 			return 0;
 		}
-		float pct = (sizeExcludingDND - getRemainingExcludingDND()) / (float) sizeExcludingDND;
+		long rem = getRemainingExcludingDND();
+		float pct = (sizeExcludingDND - rem) / (float) sizeExcludingDND;
 
-		return (int) (1000 * pct);
+		int result =  (int) (1000 * pct);
+		
+		if ( result == 1000 && rem > 0 ){
+			result = 999;
+		}else if ( result < 0 ){
+			result = 0;	// can occur with a borked download that has files missing and inconsistent cached stats
+		}
+		return( result );
 	}
 
 
