@@ -35,6 +35,7 @@ import com.biglybt.core.peermanager.messaging.Message;
 import com.biglybt.core.peermanager.piecepicker.util.BitFlags;
 import com.biglybt.core.tag.Taggable;
 import com.biglybt.pif.network.Connection;
+import com.biglybt.pif.peers.PeerReadRequest;
 
 
 /**
@@ -355,15 +356,79 @@ PEPeer
    */
   public int[] getOutgoingRequestedPieceNumbers();
 
-  public default DiskManagerReadRequest[] getRecentPiecesSent(){
+  public default DiskManagerReadRequest[] 
+  getRecentPiecesSent()
+  {
 	  return( new DiskManagerReadRequest[0]) ;
   }
+  	
+  public default int
+  getPercentDoneOfCurrentIncomingRequest()
+  {
+	  int[] progress = getCurrentIncomingRequestProgress();
+	  
+	  if ( progress == null ){
+	  
+		  return( -1 );
+		  
+	  }else{
+		  
+		  int length 	= progress[0];
+		  int done		= progress[1];
+		  
+		  if ( length <= 0 ){
+			  
+			  return( -1 );
+			  
+		  }else if ( done >= length ){
+			  
+			  return( 100 );
+			  
+		  }else{
+			  
+			  return((done*100)/length);
+		  }
+	  }
+  }
   
-  public int
-  getPercentDoneOfCurrentIncomingRequest();
+  /**
+   * @return null or { size, done }
+   */
+  
+  public int[]
+  getCurrentIncomingRequestProgress();
 
-  public int
-  getPercentDoneOfCurrentOutgoingRequest();
+  public default int
+  getPercentDoneOfCurrentOutgoingRequest()
+  {
+	  int[] progress = getCurrentOutgoingRequestProgress();
+	  
+	  if ( progress == null ){
+	  
+		  return( -1 );
+		  
+	  }else{
+		  
+		  int length 	= progress[0];
+		  int done		= progress[1];
+		  
+		  if ( length <= 0 ){
+			  
+			  return( -1 );
+			  
+		  }else if ( done >= length ){
+			  
+			  return( 100 );
+			  
+		  }else{
+			  
+			  return((done*100)/length);
+		  }
+	  }
+  }
+  
+  public int[]
+  getCurrentOutgoingRequestProgress();
 
   public long
   getBytesRemaining();
