@@ -136,7 +136,7 @@ LongTermStatsGenericImpl
 
 		stats_dir	= FileUtil.getUserFile( "stats" );
 
-		stats_dir	= new File( stats_dir, "gen."  + id );
+		stats_dir	= FileUtil.newFile( stats_dir, "gen."  + id );
 
 		COConfigurationManager.addParameterListener(
 			"long.term.stats.enable",
@@ -468,11 +468,11 @@ LongTermStatsGenericImpl
 
 					if ( record_type != RT_SESSION_END ){
 
-						File file = new File( stats_dir, current_rel_file );
+						File file = FileUtil.newFile( stats_dir, current_rel_file );
 
 						file.getParentFile().mkdirs();
 
-						writer = new PrintWriter( new FileWriter( file, true ));
+						writer = new PrintWriter( new OutputStreamWriter( FileUtil.newFileOutputStream( file, true )));
 
 						writer_rel_file = current_rel_file;
 
@@ -745,9 +745,7 @@ LongTermStatsGenericImpl
 					can_cache = false;
 				}
 
-				String	current_rel_file = bits[0] + File.separator + bits[1] + File.separator + bits[2] + ".dat";
-
-				File stats_file = new File( stats_dir, current_rel_file );
+				File stats_file = FileUtil.newFile( stats_dir, bits[0],  bits[1], bits[2] + ".dat" );
 
 				if ( !stats_file.exists()){
 
@@ -762,7 +760,7 @@ LongTermStatsGenericImpl
 					try{
 						// System.out.println( "Reading " + stats_file );
 
-						lnr = new LineNumberReader( new FileReader( stats_file ));
+						lnr = new LineNumberReader( new InputStreamReader( FileUtil.newFileInputStream( stats_file )));
 
 						long	file_start_time	= 0;
 
@@ -1177,7 +1175,7 @@ LongTermStatsGenericImpl
 		private File
 		getCacheFile()
 		{
-			return( new File( stats_dir, year + File.separator + month + File.separator + "cache.dat" ));
+			return( FileUtil.newFile( stats_dir, year, month, "cache.dat" ));
 		}
 
 		private boolean
