@@ -12,8 +12,10 @@ import org.json.simple.JSONObject;
 
 import com.biglybt.core.metasearch.FilterableResult;
 import com.biglybt.core.metasearch.Result;
+import com.biglybt.core.subs.Subscription;
 import com.biglybt.core.subs.SubscriptionException;
 import com.biglybt.core.subs.SubscriptionResultFilter;
+import com.biglybt.core.subs.SubscriptionUtils;
 import com.biglybt.core.util.DisplayFormatters;
 import com.biglybt.core.util.SystemTime;
 import com.biglybt.core.util.TimeFormatter;
@@ -226,6 +228,29 @@ SubscriptionResultFilterImpl
 		excludeTextFilterPatterns = getPatterns( excludeTextFilters );
 	}
 	
+	@Override
+	public long 
+	getDependenciesVersion()
+	{
+		long result = 0;
+		
+		List<Subscription> deps = getDependsOn();
+		
+		for ( Subscription dep: deps ){
+			
+			result += dep.getMetadataMutationIndicator();
+		}
+		
+		return( result );
+	}
+	
+	@Override
+	public List<Subscription>
+	getDependsOn()
+	{
+		return( SubscriptionUtils.getDependsOnClosure( subs ));
+	}
+	
 	@Override
 	public void
 	save()
@@ -249,6 +274,7 @@ SubscriptionResultFilterImpl
 		subs.setDetails( subs.getName( false ), subs.isPublic(), map.toString());
 	}
 
+	@Override
 	public String
 	getString()
 	{
@@ -256,11 +282,14 @@ SubscriptionResultFilterImpl
 
 		res = addString( res, "-", getString(excludeTextFilters));
 
+		long kInB = DisplayFormatters.getKinB();
+		long mInB = kInB*kInB;
+		
 		res = addString( res, "cat=", categoryFilter );
-		res = addString( res, "min-size=", minSize<=0?null:DisplayFormatters.formatByteCountToKiBEtc(minSize));
-		res = addString( res, "max-size=", maxSize<=0?null:DisplayFormatters.formatByteCountToKiBEtc(maxSize));
-		res = addString( res, "min-seeds=", minSeeds<=0?null:String.valueOf(minSeeds));
-		res = addString( res, "max-age=", maxAgeSecs<=0?null:TimeFormatter.format3( maxAgeSecs, null, true ) );
+		res = addString( res, ">=", minSize<=0?null:(minSize/mInB)+" MB");
+		res = addString( res, "<=", maxSize<=0?null:(maxSize/mInB)+" MB");
+		res = addString( res, "s>=", minSeeds<=0?null:String.valueOf(minSeeds));
+		res = addString( res, "a<=", maxAgeSecs<=0?null:TimeFormatter.format3( maxAgeSecs, null, true ) );
 
 		return( res );
 	}
@@ -377,10 +406,35 @@ SubscriptionResultFilterImpl
 		return fResults;
 	}
 	
-	@Override
 	public boolean 
 	isFiltered(
 		FilterableResult result )
+	{
+		if ( isFilteredSupport( result )){
+			
+			return( true );
+		}
+		
+		List<Subscription> deps = getDependsOn();
+		
+		for ( Subscription dep: deps ){
+			
+			try{
+				if (((SubscriptionImpl)dep).getFilters().isFiltered( result )){
+				
+					return( true );
+				}
+			}catch( Throwable e ){
+				
+			}
+		}
+		
+		return( false );
+	}
+	
+	public boolean 
+	isFilteredSupport(
+		FilterableResult result )
 	{
 		String name = result.getName();
 		//Results need a name, or they are by default invalid
