@@ -46,6 +46,8 @@ TagFeatureExecOnAssign
 	public static final int ACTION_ASSIGN_TAGS				= 0x0800;
 	public static final int ACTION_HOST						= 0x1000;
 	public static final int ACTION_PUBLISH					= 0x2000;
+	public static final int ACTION_REMOVE_TAGS				= 0x4000;
+	public static final int ACTION_QUEUE					= 0x8000;
 
 	public static final int[] ACTIONS = {
 			ACTION_DESTROY,
@@ -62,6 +64,8 @@ TagFeatureExecOnAssign
 			ACTION_ASSIGN_TAGS,
 			ACTION_HOST,
 			ACTION_PUBLISH,
+			ACTION_REMOVE_TAGS,
+			ACTION_QUEUE,
 	};
 	
 	public int
@@ -100,6 +104,13 @@ TagFeatureExecOnAssign
 	setTagAssigns(
 		List<Tag>	tags );
 	
+	public List<Tag>
+	getTagRemoves();
+	
+	public void
+	setTagRemoves(
+		List<Tag>	tags );
+
 	public interface
 	OptionsTemplateHandler
 		extends DownloadManagerOptionsHandler
@@ -119,4 +130,7 @@ TagFeatureExecOnAssign
 	setPostMessageChannel(
 		String		chat );
 	
+	public String
+	getEOAString();
+	
 }
