@@ -9,6 +9,10 @@ TagGroup
 	public String
 	getName();
 	
+	public void
+	setName(
+		String	name );
+	
 	public boolean
 	isExclusive();
 	
