@@ -59,9 +59,9 @@ public class TorrentOpenOptions
 	private final static String PARAM_QUEUEPOSITION 	= "Add Torrent Queue Position";
 
 	
-	public final static int QUEUELOCATION_BOTTOM = 1;
-
-	public final static int QUEUELOCATION_TOP = 0;
+	public final static int QUEUELOCATION_TOP		= 0;
+	public final static int QUEUELOCATION_BOTTOM 	= 1;
+	public final static int QUEUELOCATION_AUTO 		= 2;
 
 	public final static String[] STARTMODE_KEYS = {
 			"OpenTorrentWindow.startMode.queuedstarted",
@@ -194,7 +194,11 @@ public class TorrentOpenOptions
 		Map<String,Object>		options ) 
 	{
 		iStartID = getDefaultStartMode();
-		iQueueLocation = COConfigurationManager.getIntParameter( PARAM_QUEUEPOSITION, QUEUELOCATION_BOTTOM );
+		if ( getAutoQueuePositionTime() > 0 ){
+			iQueueLocation = QUEUELOCATION_AUTO;
+		}else{
+			iQueueLocation = getDefaultQueueLocation();
+		}
 		bSequentialDownload = false;
 		isValid = true;
 		
@@ -370,6 +374,12 @@ public class TorrentOpenOptions
 		}
 	}
 	
+	public int
+	getDefaultQueueLocation()
+	{
+		return( COConfigurationManager.getIntParameter( PARAM_QUEUEPOSITION, QUEUELOCATION_BOTTOM ));
+	}
+	
 	public int
 	getQueueLocation()
 	{
@@ -384,7 +394,10 @@ public class TorrentOpenOptions
 			
 			iQueueLocation = l;
 			
-			COConfigurationManager.setParameter( PARAM_QUEUEPOSITION, l );
+			if ( iQueueLocation != QUEUELOCATION_AUTO ){
+			
+				COConfigurationManager.setParameter( PARAM_QUEUEPOSITION, l );
+			}
 			
 			startOptionsChanged();
 		}
@@ -574,6 +587,25 @@ public class TorrentOpenOptions
 		}
 	}
 	
+	public long
+	getAutoQueuePositionTime()
+	{
+		if ( COConfigurationManager.getBooleanParameter( "Plugin.Magnet URI Handler.MagnetPlugin.dl.position.from.mag.time" )){
+
+			if ( initialMetadata != null ){
+							
+				Long addedTime = (Long)initialMetadata.get( "added_time" );
+			
+				if ( addedTime != null ){
+				
+					return( addedTime );
+				}
+			}
+		}
+		
+		return( -1 );
+	}
+	
 	public Map<String,Object>
 	getInitialMetadata()
 	{
@@ -685,7 +717,7 @@ public class TorrentOpenOptions
 		if (files == null && torrent != null) {
 			files = new TorrentOpenFileOptions[torrent.getFiles().length];
 
-			applySkipConfig();
+			applyPriorityAndSkipConfig();
 		}
 
 		return files;
@@ -710,7 +742,7 @@ public class TorrentOpenOptions
 	}
 
 	public void
-	applySkipConfig()
+	applyPriorityAndSkipConfig()
 	{
 		if ( torrent == null ){
 			
@@ -719,6 +751,10 @@ public class TorrentOpenOptions
 		
 		boolean[]	skip = TorrentUtils.getSkipFiles( torrent );
 		
+        Set<String>	priority_file_exts = TorrentUtils.getFilePriorityExtensions();
+
+        boolean priority_file_exts_ignore_case = TorrentUtils.getFilePriorityExtensionsIgnoreCase();
+        
 		TOTorrentFile[] tfiles = torrent.getFiles();
 
 		if ( skip == null ){
@@ -735,13 +771,51 @@ public class TorrentOpenOptions
 
 			boolean	wanted = !skip[i];
 
-			if ( files[i] == null ){
+			TorrentOpenFileOptions file = files[i];
+			
+			if ( file == null ){
 				
-				files[i] = new TorrentOpenFileOptions( this, i, orgFullName, orgFileName, torrentFile.getLength(), wanted );
+				file = files[i] = new TorrentOpenFileOptions( this, i, orgFullName, orgFileName, torrentFile.getLength(), wanted );
 				
 			}else{
+								
+				file.setToDownload( wanted );
+			}
+			
+			boolean	auto = false;
+			
+			if ( !priority_file_exts.isEmpty()){
 				
-				files[i].setToDownload( wanted );
+                String      ext  = orgFileName;
+
+                int separator = ext.lastIndexOf(".");
+
+                if ( separator != -1 ){
+
+                	ext = ext.substring( separator );
+                	
+                	if ( priority_file_exts_ignore_case ){
+                    	
+                		ext = ext.toLowerCase( Locale.US );
+                    }
+                	
+                	if ( priority_file_exts.contains( ext )){
+                		
+                		file.setPriority( 1, true );
+                		
+                		auto = true;
+                	}
+                }
+			}
+			
+			if ( !auto ){
+				
+					// reset auto indicator
+				
+				if ( file.isPriorityAuto()){
+				
+					file.setPriority( 0, false );
+				}
 			}
 		}
 		
@@ -1417,6 +1491,11 @@ public class TorrentOpenOptions
 			
 			initialMetadata = TorrentUtils.getInitialMetadata( torrent );
 			
+			if ( getAutoQueuePositionTime() > 0 ){
+				
+				iQueueLocation = QUEUELOCATION_AUTO;
+			}
+			
 			renameDuplicates();
 
 			String display_name = TorrentUtils.getDisplayName( torrent );
@@ -1965,7 +2044,7 @@ public class TorrentOpenOptions
 
 							dms.setAttribute( DownloadManagerState.AT_MOVE_ON_COMPLETE_DIR, moc.getAbsolutePath());
 						}
-
+						
 						Map<String,Object>	md = getInitialMetadata();
 
 						if ( md != null ){
@@ -2008,11 +2087,120 @@ public class TorrentOpenOptions
 					return;
 				}
 
-				if ( getQueueLocation() == TorrentOpenOptions.QUEUELOCATION_TOP ){
+				boolean position_set = false;
+				
+				int queueLoc = getQueueLocation();
+				
+				if ( queueLoc ==  TorrentOpenOptions.QUEUELOCATION_AUTO ){
+				
+					long addedTime = getAutoQueuePositionTime();
+				
+					if ( addedTime > 0 ){
+											
+						dm.getDownloadState().setLongAttribute( DownloadManagerState.AT_REAL_DM_MAGNET_TIME, addedTime );
+						
+						List<DownloadManager> dms = gm.getDownloadManagers();
+						
+						DownloadManager dmBefore 		= null;
+						long			dmBeforeTime	= -1;
+							
+						DownloadManager dmAfter 		= null;
+						long			dmAfterTime		= Long.MAX_VALUE;
+						
+						for ( DownloadManager d: dms ){
+							
+							if ( d == dm ){
+								
+								continue;
+							}
+							
+							if ( !d.isDownloadComplete( false )){
+								
+								DownloadManagerState ds = d.getDownloadState();
+								
+								if ( ds.getFlag( DownloadManagerState.FLAG_METADATA_DOWNLOAD )){
+									
+									continue;
+								}
+								
+								long t = ds.getLongAttribute( DownloadManagerState.AT_REAL_DM_MAGNET_TIME );
 
-					gm.moveTop(new DownloadManager[] {
-						dm
-					});
+								if ( t <= 0 ){
+								
+									t = ds.getLongParameter( DownloadManagerState.PARAM_DOWNLOAD_ADDED_TIME );
+								}
+								
+								if ( t < addedTime && t > dmBeforeTime ){
+									
+									dmBefore 		= d;
+									dmBeforeTime	= t;
+								}
+								
+								if ( t >= addedTime && t < dmAfterTime ){
+									
+									dmAfter 		= d;
+									dmAfterTime		= t;
+								}
+								
+							}
+						}
+						
+						position_set = true;
+						
+						int def_queue_loc = getDefaultQueueLocation();
+						
+						if ( dmBefore == null && dmAfter == null ){
+							
+							// stick it wherever
+							
+						}else if ( dmBefore == null ){
+							
+								// only remaining downloads were added after this one
+							
+							if ( def_queue_loc == QUEUELOCATION_BOTTOM ){
+															
+								gm.moveTop(new DownloadManager[]{ dm });
+								
+							}else{
+
+								gm.moveEnd(new DownloadManager[]{ dm });
+							}
+							
+						}else if ( dmAfter == null ){
+							
+								// only remaining downloads were added before this one
+							
+							if ( def_queue_loc == QUEUELOCATION_BOTTOM ){
+																
+								gm.moveEnd(new DownloadManager[]{ dm });
+								
+							}else{
+								
+								gm.moveTop(new DownloadManager[]{ dm });
+							}
+							
+						}else{
+						
+							if ( def_queue_loc == QUEUELOCATION_BOTTOM ){
+								
+								gm.moveTo( dm, dmAfter.getPosition());
+								
+							}else{
+								
+								gm.moveTo( dm, dmBefore.getPosition());
+							}
+						}
+					}
+				}
+			
+				if ( !position_set ){
+					
+					if ( getQueueLocation() == TorrentOpenOptions.QUEUELOCATION_TOP ){
+	
+						gm.moveTop(new DownloadManager[] {
+							dm
+						});
+					}
 				}
 
 				TorrentOpenOptions.addModePostCreate(startMode, dm );
