@@ -52,6 +52,10 @@ AllTrackersManager
 		registerTorrent(
 			TOTorrent	torrent );
 		
+		public void
+		unregisterTorrent(
+			TOTorrent	torrent );
+		
 		public void
 		registerTracker(
 			TOTorrent	torrent,
@@ -232,6 +236,9 @@ AllTrackersManager
 		public int
 		getPrivatePercentage();
 		
+		public int
+		getTorrentCount();
+		
 		public boolean
 		isRemovable();
 		
