@@ -39,6 +39,9 @@ import com.biglybt.core.networkmanager.impl.udp.UDPNetworkManager;
 import com.biglybt.core.proxy.AEProxyFactory;
 import com.biglybt.core.proxy.AEProxyFactory.PluginProxy;
 import com.biglybt.core.security.SESecurityManager;
+import com.biglybt.core.tracker.AllTrackersManager;
+import com.biglybt.core.tracker.AllTrackersManager.AllTrackers;
+import com.biglybt.core.tracker.AllTrackersManager.ScrapeStats;
 import com.biglybt.core.tracker.client.TRTrackerAnnouncer;
 import com.biglybt.core.tracker.client.TRTrackerScraperClientResolver;
 import com.biglybt.core.tracker.client.TRTrackerScraperResponse;
@@ -100,12 +103,34 @@ public class TrackerStatus {
 			});
 	}
 
+	private static final AllTrackers	all_trackers = AllTrackersManager.getAllTrackers();
+
 	private byte					autoUDPscrapeEvery				= 1;
 	private int						scrapeCount;
 
-	private static final List				logged_invalid_urls				= new ArrayList();
+	private static final List			logged_invalid_urls				= new ArrayList();
 	private static final ThreadPool		thread_pool						= new ThreadPool("TrackerStatus", 10, true);	// queue when full rather than block
 
+	static{
+		all_trackers.registerScrapeStatsProvider(
+			new AllTrackersManager.ScrapeStatsProvider(){
+				
+				@Override
+				public ScrapeStats 
+				getStats()
+				{
+					return( new ScrapeStats(){
+						@Override
+						public long getLagMillis(){
+				  			ScrapeTask oldest = (ScrapeTask)thread_pool.getOldestQueuedTask();
+				  			
+				  			return( oldest==null?0:(SystemTime.getMonotonousTime()-oldest.create_time ));
+						}
+					});
+				}
+			});
+	}
+	
 	private final URL				tracker_url;
 	private boolean					az_tracker;
 	private boolean					enable_sni_hack;
@@ -225,11 +250,6 @@ public class TrackerStatus {
   		boolean 		async )
   	{
   		//LGLogger.log( "updateSingleHash():: force=" + force + ", async=" +async+ ", url=" +scrapeURL+ ", hash=" +ByteFormatter.nicePrint(hash, true) );
-
-  		if ( Logger.isClosingTakingTooLong()){
-  			
-  			return;
-  		}
   		
   		if ( scrapeURL == null ){
   			if (Logger.isEnabled()) {
@@ -343,10 +363,10 @@ public class TrackerStatus {
   		if ( async ){
 
   			thread_pool.run(
-  				new AERunnable()
+  				new ScrapeTask()
   				{
   					@Override
-					  public void
+					public void
   					runSupport()
   					{
   						runScrapesSupport( responses, force );
@@ -561,7 +581,9 @@ public class TrackerStatus {
 		  			}
 		  		}
 
-		  		try{
+		  		try{		  			
+		  			all_trackers.addScrapeRequest();
+		  			
 		  				// set context in case authentication dialog is required
 
 					TorrentUtils.setTLSTorrentHash(one_of_the_hashes);
@@ -600,6 +622,8 @@ public class TrackerStatus {
 			  		}
 				}finally{
 
+					all_trackers.removeScrapeRequest();
+					
 					TorrentUtils.setTLSTorrentHash( null );
 				}
 
@@ -1800,4 +1824,11 @@ public class TrackerStatus {
 	public int getNumActiveScrapes() {
 		return numActiveScrapes.get();
 	}
+	
+	private abstract class
+	ScrapeTask
+		extends AERunnable
+	{
+		final long	create_time = SystemTime.getMonotonousTime();
+	}
 }
