@@ -67,6 +67,7 @@ Constants
 	public static final String PAIRING_SERVER			= "pair.biglybt.com";
 	public static final String WEB_REMOTE_SERVER		= "remote.biglybt.com";
 
+	public static final String XMLNS_VUZE			= "xmlns:vuze=\"http://www.vuze.com\"";
 	public static final String SPEED_TEST_SERVER	= "speedtest.vuze.com";
 
 	public static final String[] APP_DOMAINS = { "azureusplatform.com", "azureus.com", "aelitis.com", "vuze.com", "biglybt.com" };
@@ -121,10 +122,11 @@ Constants
 
 	/**
 	 *  Can't be final as accesed from client speed measurer plugin
+	 *  27/04/2022 dead plugin, remove this sometime
 	 */
 
-	@SuppressWarnings("CanBeFinal")
-	public static boolean DOWNLOAD_SOURCES_PRETEND_COMPLETE	= false;
+	// @SuppressWarnings("CanBeFinal")
+	public static final boolean DOWNLOAD_SOURCES_PRETEND_COMPLETE	= false;
 
 	// keep the CVS style constant coz version checkers depend on it!
 	// e.g. 2.0.8.3
@@ -142,11 +144,11 @@ Constants
 	public static final String BIGLY_PEER_ID						= "BI";
 
 	
-	public static final String BIGLYBT_VERSION  = "3.0.0.0";
+	public static final String BIGLYBT_VERSION  = "3.2.0.0";
 	
 	//public static final String BUILD_VERSION  = "@build.version@";   //Ant replace - believed dead
 	public static final String SUBVERSION		= "";
-	public static final byte[] VERSION_ID       = ("-" + BIGLY_PEER_ID + "3000" + "-").getBytes();  //MUST be 8 chars long!
+	public static final byte[] VERSION_ID       = ("-" + BIGLY_PEER_ID + "3200" + "-").getBytes();  //MUST be 8 chars long!
 
 	private static final boolean FORCE_NON_CVS = System.getProperty( "az.force.noncvs", "0" ).equals( "1" );
 
@@ -177,6 +179,7 @@ Constants
 	public static final boolean isWindows7OrHigher;
 	public static final boolean isWindows8OrHigher;
 	public static final boolean isWindows10OrHigher;
+	// public static final boolean isWindows11OrHigher;   BORKED
 
 
 	public static final boolean is64Bit;
@@ -234,6 +237,7 @@ Constants
 				isWindows7OrHigher		= false;
 				isWindows8OrHigher		= false;
 				isWindows10OrHigher		= false;
+				// isWindows11OrHigher		= false;
 
 			}else{
 				float f_ver = ver.floatValue();
@@ -244,6 +248,23 @@ Constants
 				isWindows8OrHigher	 	= f_ver >= 6.2f;
 				isWindows10OrHigher		= f_ver >= 10.0f;
 
+
+				// would like to write
+				// isWindows11OrHigher		= f_ver >= 11.0f;
+				// but apparently it is broken
+				// https://stackoverflow.com/questions/72668838/system-getpropertyos-name-and-system-getpropertyos-version-returning-win
+				// this also doesn't seem to have been backported
+				/*
+				if ( isWindows10OrHigher ){
+										
+					isWindows11OrHigher = !OSName.equalsIgnoreCase( "Windows 10" );
+					
+				}else{
+					
+					isWindows11OrHigher = false;
+				}
+				*/
+				
 				if ( isWindowsVista ){
 
 					LineNumberReader lnr = null;
@@ -301,7 +322,7 @@ Constants
 			isWindows7OrHigher 		= false;
 			isWindows8OrHigher 		= false;
 			isWindows10OrHigher		= false;
-
+			// isWindows11OrHigher		= false;
 		}
 	}
 
@@ -370,6 +391,7 @@ Constants
 	public static final boolean isJava8OrHigher;
 	public static final boolean isJava9OrHigher;
 	public static final boolean isJava10OrHigher;
+	public static final boolean isJava11OrHigher;
 	public static final boolean isJava12OrHigher;
 
 	static{
@@ -383,6 +405,7 @@ Constants
 		boolean	_8plus;
 		boolean	_9plus;
 		boolean	_10plus;
+		boolean	_11plus;
 		boolean	_12plus;
 
 		try{
@@ -406,6 +429,7 @@ Constants
 			_9plus = first > 1 || second >= 9;
 
 			_10plus = first >= 10;
+			_11plus = first >= 11;
 			_12plus = first >= 12;
 
 		}catch( Throwable e ){
@@ -417,12 +441,14 @@ Constants
 			_8plus = false;		
 			_9plus = false;	
 			_10plus = false;
+			_11plus = false;
 			_12plus = false;
 		}
 
 		isJava8OrHigher		= _8plus;
 		isJava9OrHigher		= _9plus;
 		isJava10OrHigher	= _10plus;
+		isJava11OrHigher	= _11plus;
 		isJava12OrHigher	= _12plus;
 	}
 
