@@ -29,6 +29,7 @@ import java.math.BigDecimal;
 import java.text.DecimalFormat;
 import java.text.DecimalFormatSymbols;
 import java.text.NumberFormat;
+import java.text.ParsePosition;
 import java.text.SimpleDateFormat;
 import java.util.*;
 
@@ -272,6 +273,7 @@ DisplayFormatters
 	private static String	ManagerItem_downloading;
 	private static String	ManagerItem_swarmMerge;
 	private static String	ManagerItem_seeding;
+	private static String	ManagerItem_lightseeding;
 	private static String	ManagerItem_superseeding;
 	private static String	ManagerItem_stopping;
 	private static String	ManagerItem_stopped;
@@ -280,6 +282,7 @@ DisplayFormatters
 	private static String	ManagerItem_error;
 	private static String	ManagerItem_forced;
 	private static String	ManagerItem_moving;
+	private static String	ManagerItem_unallocated;
 
 	private static String	yes;
 	private static String	no;
@@ -301,6 +304,7 @@ DisplayFormatters
 		ManagerItem_swarmMerge			= getResourceString( "TableColumn.header.mergeddata", "swarm merge" );
 		ManagerItem_seeding				= getResourceString( "ManagerItem.seeding", "seeding" );
 		ManagerItem_superseeding		= getResourceString( "ManagerItem.superseeding", "superseeding" );
+		ManagerItem_lightseeding		= getResourceString( "ManagerItem.lightseeding", "lightseeding" );
 		ManagerItem_stopping			= getResourceString( "ManagerItem.stopping", "stopping" );
 		ManagerItem_stopped				= getResourceString( "ManagerItem.stopped", "stopped" );
 		ManagerItem_paused				= getResourceString( "ManagerItem.paused", "paused" );
@@ -308,6 +312,7 @@ DisplayFormatters
 		ManagerItem_error				= getResourceString( "ManagerItem.error", "error" );
 		ManagerItem_forced				= getResourceString( "ManagerItem.forced", "forced" );
 		ManagerItem_moving				= getResourceString( "ManagerItem.moving", "moving" );
+		ManagerItem_unallocated			= getResourceString( "label.unallocated", "unallocated" );
 		yes								= getResourceString( "GeneralView.yes", "Yes" );
 		no								= getResourceString( "GeneralView.no", "No" );
 	}
@@ -807,7 +812,16 @@ DisplayFormatters
 					 
 				}else{	 
 
-					tmp = ManagerItem_queued;
+					int substate = manager.getSubState();
+					
+					if ( substate == DownloadManager.STATE_SEEDING ){
+						
+						tmp = ManagerItem_lightseeding;
+						
+					}else{
+					
+						tmp = ManagerItem_queued;
+					}
 				}
 				
 				break;
@@ -886,6 +900,13 @@ DisplayFormatters
 							sr = MessageText.getString( sr.substring( 1, sr.length() - 1 ));
 						}
 						tmp += " (" + sr + ")";
+					}else{
+						if ( 	!manager.isDataAlreadyAllocated() && 
+								//manager.getStats().getSecondsDownloading() == 0 &&
+								!manager.isDownloadComplete( false )){
+							
+							tmp += " (" + ManagerItem_unallocated + ")";
+						}
 					}
 				}
 				
@@ -1341,6 +1362,33 @@ DisplayFormatters
 		format_map = map;
 	}
 
+	public static float
+	parseFloat(
+		DecimalFormat		df,
+		String				str )
+	
+		throws NumberFormatException
+	{
+		if ( str == null ){
+			throw( new NumberFormatException());
+		}
+		
+		str = str.trim();
+		
+		ParsePosition parsePosition = new ParsePosition(0);
+		 
+		float result = df.parse(str,parsePosition).floatValue();
+		
+		if ( parsePosition.getIndex() == str.length()){
+			
+			return( result );
+			
+		}else{
+			
+			throw( new NumberFormatException( "Invalid float: " + str ));
+		}
+	}
+	
 	public static String
 	formatCustomRate(
 		String		key,
