@@ -40,6 +40,8 @@ import com.biglybt.core.logging.LogIDs;
 import com.biglybt.core.logging.Logger;
 import com.biglybt.core.networkmanager.admin.NetworkAdmin;
 import com.biglybt.core.networkmanager.admin.NetworkAdminPropertyChangeListener;
+import com.biglybt.core.stats.CoreStats;
+import com.biglybt.core.stats.CoreStatsProvider;
 import com.biglybt.core.util.*;
 import com.biglybt.net.udp.uc.*;
 
@@ -68,6 +70,49 @@ PRUDPPacketHandlerImpl
 			});
 	}
 
+	private static volatile long	total_packets_sent;
+	private static volatile long	total_packets_received;
+	private static volatile long	total_bytes_sent;
+	private static volatile long	total_bytes_received;
+	
+	static{
+		Set<String>	types = new HashSet<>();
+		
+		types.add( CoreStats.ST_NET_UDP_SEND_PACKET_COUNT );
+		types.add( CoreStats.ST_NET_UDP_SEND_BYTE_COUNT);
+		types.add( CoreStats.ST_NET_UDP_RECEIVE_PACKET_COUNT );
+		types.add( CoreStats.ST_NET_UDP_RECEIVE_BYTE_COUNT );
+		
+		CoreStats.registerProvider( 
+			types,
+			new CoreStatsProvider(){
+				
+				@Override
+				public void 
+				updateStats(
+					Set<String>				types, 
+					Map<String, Object>		values)
+				{
+					if ( types.contains( CoreStats.ST_NET_UDP_SEND_PACKET_COUNT )){
+
+						values.put( CoreStats.ST_NET_UDP_SEND_PACKET_COUNT, new Long( total_packets_sent ));
+					}
+					if ( types.contains( CoreStats.ST_NET_UDP_SEND_BYTE_COUNT )){
+
+						values.put( CoreStats.ST_NET_UDP_SEND_BYTE_COUNT, new Long( total_bytes_sent ));
+					}
+					if ( types.contains( CoreStats.ST_NET_UDP_RECEIVE_PACKET_COUNT )){
+
+						values.put( CoreStats.ST_NET_UDP_RECEIVE_PACKET_COUNT, new Long( total_packets_received ));
+					}
+					if ( types.contains( CoreStats.ST_NET_UDP_RECEIVE_BYTE_COUNT )){
+
+						values.put( CoreStats.ST_NET_UDP_RECEIVE_BYTE_COUNT, new Long( total_bytes_received ));
+					}
+				}
+			});
+	}
+	
 	private static final long	MAX_SEND_QUEUE_DATA_SIZE	= 2*1024*1024;
 	private static final long	MAX_RECV_QUEUE_DATA_SIZE	= 1*1024*1024;
 
@@ -95,7 +140,8 @@ PRUDPPacketHandlerImpl
 	}
 
 
-	private int				port;
+	private final int		port;
+	
 	private DatagramSocket	socket;
 
 	private CopyOnWriteList<PRUDPPrimordialHandler>	primordial_handlers = new CopyOnWriteList<>();
@@ -104,19 +150,20 @@ PRUDPPacketHandlerImpl
 	private PRUDPPacketHandlerStatsImpl	stats = new PRUDPPacketHandlerStatsImpl( this );
 
 
-	private Map			requests = new LightHashMap();
+	private Map<Integer,PRUDPPacketHandlerRequestImpl>			requests = new LightHashMap<>();
+	
 	private AEMonitor	requests_mon	= new AEMonitor( "PRUDPPH:req" );
 
 
-	private AEMonitor		send_queue_mon	= new AEMonitor( "PRUDPPH:sd" );
+	private AEMonitor		send_queue_mon	= new AEMonitor( "PRUDPPH:sd", true );
 	private long			send_queue_data_size;
 	private final List[]	send_queues		= new List[]{ new LinkedList(),new LinkedList(),new LinkedList()};
 	private AESemaphore		send_queue_sem	= new AESemaphore( "PRUDPPH:sq" );
 	private AEThread2		send_thread;
 
-	private AEMonitor	recv_queue_mon	= new AEMonitor( "PRUDPPH:rq" );
-	private long		recv_queue_data_size;
-	private List<Object[]>	recv_queue		= new ArrayList();
+	private AEMonitor		recv_queue_mon	= new AEMonitor( "PRUDPPH:rq", true );
+	private long			recv_queue_data_size;
+	private List<Object[]>	recv_queue		= new ArrayList<>();
 	private AESemaphore		recv_queue_sem	= new AESemaphore( "PRUDPPH:rq" );
 	private AEThread2		recv_thread;
 
@@ -723,7 +770,7 @@ PRUDPPacketHandlerImpl
 						}
 
 						if ( buffer != null ){
-
+							
 							process( packet, receive_time );
 						}
 
@@ -905,9 +952,14 @@ PRUDPPacketHandlerImpl
 				// must have their MSB set. As requests always start with the action, which
 				// always has the MSB clear, we can use this to differentiate.
 
-			byte[]	packet_data = dg_packet.getData();
-			int		packet_len	= dg_packet.getLength();
+			final byte[]	packet_data = dg_packet.getData();
+			final int		packet_len	= dg_packet.getLength();
 
+			if ( packet_len == 0 ){
+				
+				Debug.out( "zero length packet received" );
+			}
+			
 			// System.out.println( "received:" + packet_len );
 
 			PRUDPPacket packet;
@@ -994,9 +1046,9 @@ PRUDPPacketHandlerImpl
 
 						}else{
 
-							recv_queue.add( new Object[]{ packet, new Integer( dg_packet.getLength()) });
+							recv_queue.add( new Object[]{ packet, new Integer( packet_len )});
 
-							recv_queue_data_size	+= dg_packet.getLength();
+							recv_queue_data_size	+= packet_len;
 
 							recv_queue_sem.release();
 
@@ -1009,18 +1061,55 @@ PRUDPPacketHandlerImpl
 										public void
 										run()
 										{
+											InetAddress bind_ip = current_bind_ip;
+											
+											boolean 	set_name = true;
+											
 											Average		request_receive_average = Average.getInstance( 1000, 10 );
 
 											while( true ){
 
+												if ( !set_name ){
+													
+													InetAddress bp = current_bind_ip;
+													
+													if ( bp != bind_ip ){
+														
+														bind_ip = bp;
+														
+														set_name = true;
+													}
+												}
+												
+												if ( set_name ){
+													
+													set_name = false;
+													
+													setName( "PRUDPPacketHandler:receiver: " + bind_ip + ":" + port );
+												}
+												
 												try{
-													recv_queue_sem.reserve();
+													boolean got_it = recv_queue_sem.reserve( 30*1000 );
 
 													Object[]	data;
 
 													try{
 														recv_queue_mon.enter();
 
+														if ( !got_it ){
+															
+															if ( recv_queue_data_size == 0 ){
+																
+																recv_thread = null;
+																
+																break;
+																
+															}else{
+																
+																continue;
+															}
+														}
+														
 														data = (Object[])recv_queue.remove(0);
 														
 														total_requests_processed++;
@@ -1316,6 +1405,13 @@ PRUDPPacketHandlerImpl
 
 			DatagramPacket dg_packet = new DatagramPacket(_buffer, _length, destination_address );
 
+			int packet_len = dg_packet.getLength();
+			
+			if ( packet_len == 0 ){
+				
+				Debug.out( "zero length packet sent" );
+			}
+			
 			PRUDPPacketHandlerRequestImpl	request = new PRUDPPacketHandlerRequestImpl( receiver, timeout );
 
 			try{
@@ -1326,7 +1422,10 @@ PRUDPPacketHandlerImpl
 					throw( new PRUDPPacketHandlerException( "Handler destroyed" ));
 				}
 				
-				requests.put( new Integer( request_packet.getTransactionId()), request );
+				if ( requests.put( new Integer( request_packet.getTransactionId()), request ) != null ){
+					
+					Debug.out( "Duplicate request transaction id!!!!" );
+				}
 
 			}finally{
 
@@ -1349,7 +1448,7 @@ PRUDPPacketHandlerImpl
 
 							sendToSocket( dg_packet );
 
-							stats.packetSent( _length );
+							stats.packetSent( packet_len );
 
 							if ( TRACE_REQUESTS ){
 								Logger.log(new LogEvent(LOGID,
@@ -1362,7 +1461,7 @@ PRUDPPacketHandlerImpl
 
 						}else{
 
-							send_queue_data_size	+= dg_packet.getLength();
+							send_queue_data_size	+= packet_len;
 
 							send_queues[priority].add( new Object[]{ dg_packet, request });
 
@@ -1389,10 +1488,33 @@ PRUDPPacketHandlerImpl
 										{
 											int[]		consecutive_sends = new int[send_queues.length];
 
+											InetAddress bind_ip = current_bind_ip;
+											
+											boolean set_name = true;
+											
 											while( true ){
 
+												if ( !set_name ){
+													
+													InetAddress bp = current_bind_ip;
+													
+													if ( bp != bind_ip ){
+														
+														bind_ip = bp;
+														
+														set_name = true;
+													}
+												}
+												
+												if ( set_name ){
+													
+													set_name = false;
+													
+													setName( "PRUDPPacketHandler:sender: " + bind_ip + ":" + port );
+												}
+												
 												try{
-													send_queue_sem.reserve();
+													boolean got_it = send_queue_sem.reserve(30*1000);
 
 													Object[]	data;
 													int			selected_priority	= 0;
@@ -1400,6 +1522,19 @@ PRUDPPacketHandlerImpl
 													try{
 														send_queue_mon.enter();
 
+														if ( !got_it ){
+															
+															if ( send_queue_data_size == 0 ){
+																
+																send_thread = null;
+																
+																break;
+																
+															}else{
+																
+																continue;
+															}
+														}
 															// invariant: at least one queue must have an entry
 
 														for (int i=0;i<send_queues.length;i++){
@@ -1477,7 +1612,7 @@ PRUDPPacketHandlerImpl
 														new LogEvent(
 															LOGID,
 															LogEvent.LT_WARNING,
-															"PRUDPPacketHandler: send failed: " + Debug.getNestedExceptionMessage(e)));
+															"PRUDPPacketHandler: send failed to " + destination_address + ": " + Debug.getNestedExceptionMessage(e)));
 												}
 											}
 										}
@@ -1498,7 +1633,7 @@ PRUDPPacketHandlerImpl
 
 					// System.out.println( "sent:" + buffer.length );
 
-					stats.packetSent( _length );
+					stats.packetSent( packet_len );
 
 					if ( TRACE_REQUESTS ){
 						Logger.log(new LogEvent(LOGID, "PRUDPPacketHandler: "
@@ -1768,6 +1903,9 @@ PRUDPPacketHandlerImpl
 
 		throws IOException
 	{
+		total_packets_sent++;
+		total_bytes_sent += p.getLength();
+		
 		if ( packet_transformer != null ){
 
 			packet_transformer.transformSend( p );
@@ -1784,6 +1922,10 @@ PRUDPPacketHandlerImpl
 	{
 		socket.receive( p );
 
+		total_packets_received++;
+		total_bytes_received += p.getLength();
+
+		
 		if ( packet_transformer != null ){
 
 			packet_transformer.transformReceive( p );
