@@ -316,6 +316,17 @@ Download extends DownloadEventNotifier, DownloadStub, Taggable
 
 		throws DownloadException;
 
+	/**
+	 * @since BiglyBT 2.6.0.1
+	 */
+	public void
+	stopAndRemove(
+		boolean	delete_torrent,
+		boolean	delete_data )
+
+		throws DownloadException, DownloadRemovalVetoException;
+
+
 	/**
 	 * See lifecycle description above
 	 * @throws DownloadException
@@ -978,14 +989,14 @@ Download extends DownloadEventNotifier, DownloadStub, Taggable
 	 *
 	 * @return Seeding Rank
 	 */
-	public int getSeedingRank();
+	public SeedingRank getSeedingRank();
 
 	/**
 	 * The torrents with the highest rankings will be seeded first.
 	 *
 	 * @param rank New Ranking
 	 */
-	public void setSeedingRank(int rank);
+	public void setSeedingRank(SeedingRank rank);
 
   /**
    * Get the local peerID advertised to the download swarm.
@@ -1097,4 +1108,33 @@ Download extends DownloadEventNotifier, DownloadStub, Taggable
 	 * @since 5.0.0.1
 	 */
 	public DiskManagerFileInfo getPrimaryFile();
+	
+	public interface
+	SeedingRank
+	{
+		public default int
+		getRank()
+		{
+			return( 0 );
+		}
+		
+		public default long
+		getLightSeedEligibility()
+		{
+			return( Long.MAX_VALUE );
+		}
+		
+		public default void
+		setActivationStatus(
+			String	str )
+		{
+		}
+				
+		public default String[]
+		getStatus(
+			boolean	verbose )
+		{
+			return( new String[]{ "", null });
+		}
+	}
 }
