@@ -188,10 +188,10 @@ GenericMessageDecoder
 	}
 
 	@Override
-	public int
-	getPercentDoneOfCurrentMessage()
+	public int[]
+	getCurrentMessageProgress()
 	{
-		return( 0 );
+		return( null );
 	}
 
 	@Override
