@@ -63,8 +63,8 @@ PeerForeignDelegate
 
 	protected volatile int		_lastPiece =-1;
 
-	private PeerManagerImpl		manager;
-	private Peer				foreign;
+	private final PeerManagerImpl		manager;
+	private final Peer					foreign;
 
 	private NetworkConnectionBase	network_connection;
 
@@ -271,7 +271,7 @@ PeerForeignDelegate
 	{
 		return( foreign.getRequests().indexOf( request ));
 	}
-
+	
 	protected  void
 	dataReceived()
 	{
@@ -281,12 +281,13 @@ PeerForeignDelegate
 	@Override
 	public void
 	closeConnection(
-		String reason )
+		String 	reason,
+		int		reason_code )
 	{
 		closed = true;
 
 		try{
-			foreign.close( reason, false, false );
+			foreign.close( reason, reason_code, false, false );
 
 		}finally{
 
@@ -310,9 +311,9 @@ PeerForeignDelegate
 
 	@Override
 	public long
-	getLastMessageSentTime()
+	getLastMessageSentTimeMono()
 	{
-		return( 0 );
+		return( -1 );
 	}
 
 	@Override
@@ -775,7 +776,14 @@ PeerForeignDelegate
 	public PEPeerStats
 	getStats()
 	{
-		return( ((PeerStatsImpl)foreign.getStats()).getDelegate());
+		PeerStatsImpl ps = (PeerStatsImpl)foreign.getStats();
+		
+		if ( ps == null ){
+			
+			return( null );
+		}
+		
+		return( ps.getDelegate());
 	}
 
 
@@ -945,17 +953,17 @@ PeerForeignDelegate
 	}
 
 	@Override
-	public int
-	getPercentDoneOfCurrentIncomingRequest()
+	public int[]
+	getCurrentIncomingRequestProgress()
 	{
-		return( foreign.getPercentDoneOfCurrentIncomingRequest());
+		return( foreign.getCurrentIncomingRequestProgress());
 	}
 
 	@Override
-	public int
-	getPercentDoneOfCurrentOutgoingRequest()
+	public int[]
+	getCurrentOutgoingRequestProgress()
 	{
-		return( foreign.getPercentDoneOfCurrentOutgoingRequest());
+		return( foreign.getCurrentOutgoingRequestProgress());
 	}
 
 	@Override
@@ -1222,7 +1230,10 @@ PeerForeignDelegate
 	public void clearAvailabilityAdded() {}
 
 	@Override
-	public PEPeerTransport reconnect(boolean tryUDP, boolean tryIPv6){ return null; }
+	public PEPeerTransport reconnect(boolean tryUDP, boolean tryIPv6, Map userData ){ return null; }
+	
+	@Override
+	public boolean isReconnect(){ return false; }
 	@Override
 	public boolean isSafeForReconnect() { return false; }
 
@@ -1325,16 +1336,13 @@ PeerForeignDelegate
 
 			if ( is_download_disabled ){
 
-				List<Object>	list = foreign.getRequests();
+				List<PeerReadRequest>	list = foreign.getRequests();
 
 				if ( list != null ){
 
-					for ( Object obj: list ){
+					for ( PeerReadRequest req: list ){
 
-						if ( obj instanceof PeerReadRequest ){
-
-							foreign.cancelRequest((PeerReadRequest)obj);
-						}
+						foreign.cancelRequest( req );
 					}
 				}
 			}
@@ -1378,6 +1386,21 @@ PeerForeignDelegate
 		return( priority_connection );
 	}
 
+	@Override
+	public boolean 
+	canSendHolePunch()
+	{
+		return( false );
+	}
+	
+	@Override
+	public void 
+	sendHolePunch(
+		InetAddress address,
+		int 		port)
+	{
+	}
+	
 	@Override
 	public void
 	generateEvidence(
