@@ -495,9 +495,6 @@ ShareResourceImpl
 	{
 		return( manager.getTorrentFile(item));
 	}
-
-	protected abstract ShareResource 
-	lookupShare(byte[] torrent_hash);
 	
 	protected abstract void
 	checkConsistency()
