@@ -36,6 +36,7 @@ import java.util.zip.ZipException;
 
 import javax.net.ssl.*;
 
+import com.biglybt.core.CoreFactory;
 import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.proxy.AEProxyFactory;
 import com.biglybt.core.proxy.AEProxyFactory.PluginProxy;
@@ -674,7 +675,7 @@ ResourceDownloaderURLImpl
 				this_mon.exit();
 			}
 
-			try{
+			try{				
 				URL	outer_url = new URL( original_url.toString().replaceAll( " ", "%20" ));
 
 					// some authentications screw up without an explicit port number here
