@@ -39,6 +39,7 @@ DefaultRankCalculator
 	public static final int	DOWNLOAD_ORDER_SIZE					= 4;
 	public static final int	DOWNLOAD_ORDER_REVERSE_SIZE			= 5;
 	public static final int	DOWNLOAD_ORDER_ETA					= 6;
+	public static final int	DOWNLOAD_ORDER_FILE_PRIORITIES		= 7;
 
 	//
 	// Seeding Rank (SR) Limits and Values
@@ -186,6 +187,9 @@ DefaultRankCalculator
 	public long
 	getSizeExcludingDND();
 	
+	public int[]
+	getFilePriorityStats();
+	
 	public DownloadScrapeResult
 	getAggregatedScrapeResult(
 		boolean 		b );
@@ -225,7 +229,8 @@ DefaultRankCalculator
 		RankCalculatorSlotReserver	slot );
 	
 	public boolean
-	activationRequest();
+	activationRequest(
+		Runnable to_do );
 	
 	public TagFeatureRateLimit[]
 	getTagsWithDLLimits();
