@@ -248,6 +248,13 @@ RankCalculatorSlotReserver
 		return( 0 );
 	}
 	
+	@Override
+	public int[] 
+	getFilePriorityStats()
+	{
+		return( null );
+	}
+	
 	public DownloadScrapeResult
 	getAggregatedScrapeResult(
 		boolean 		b )
@@ -323,7 +330,8 @@ RankCalculatorSlotReserver
 	
 	@Override
 	public boolean 
-	activationRequest()
+	activationRequest(
+		Runnable to_do )
 	{
 		return( false );
 	}
