@@ -126,6 +126,8 @@ public class TableColumnImpl
 	private ArrayList<TableCellToolTipListener> cellToolTipListeners;
 
 	private ArrayList<TableCellMouseListener> cellMouseListeners;
+	
+	private ArrayList<TableCellMenuListener> cellMenuListeners;
 
 	private ArrayList<TableCellMouseMoveListener> cellMouseMoveListeners;
 
@@ -702,6 +704,38 @@ public class TableColumnImpl
 		}
 	}
 
+	@Override
+	public void addCellMenuListener(TableCellMenuListener listener) {
+		try {
+			this_mon.enter();
+
+			if (cellMenuListeners == null) {
+				cellMenuListeners = new ArrayList<>(1);
+			}
+
+			cellMenuListeners.add(listener);
+
+		} finally {
+			this_mon.exit();
+		}
+	}
+
+	@Override
+	public void removeCellMenuListener(TableCellMenuListener listener) {
+		try {
+			this_mon.enter();
+
+			if (cellMenuListeners == null) {
+				return;
+			}
+
+			cellMenuListeners.remove(listener);
+
+		} finally {
+			this_mon.exit();
+		}
+	}
+	
 	@Override
 	public boolean hasCellMouseMoveListener() {
 		return cellMouseMoveListeners != null && cellMouseMoveListeners.size() > 0;
@@ -884,6 +918,10 @@ public class TableColumnImpl
 			addCellMouseListener((TableCellMouseListener) listenerObject);
 		}
 
+		if (listenerObject instanceof TableCellMenuListener) {
+			addCellMenuListener((TableCellMenuListener) listenerObject);
+		}
+
 		if (listenerObject instanceof TableCellVisibilityListener) {
 			addCellVisibilityListener((TableCellVisibilityListener) listenerObject);
 		}
@@ -1065,6 +1103,33 @@ public class TableColumnImpl
 		}
 	}
 
+	@Override
+	public void invokeCellMenuListeners(TableCellMenuEvent event) {
+	
+		ArrayList<TableCellMenuListener> listeners = cellMenuListeners;
+		
+		if ( listeners == null ){
+			
+			return;
+		}
+		
+		for ( TableCellMenuListener listener: listeners ){
+			
+			if ( event.skipCoreFunctionality ){
+				
+				return;
+			}
+			
+			try{
+				listener.menuEventOccurred( event );
+
+			}catch( Throwable e ){
+				
+				Debug.printStackTrace(e);
+			}
+		}
+	}
+	
 	@Override
 	public void invokeCellVisibilityListeners(TableCellCore cell, int visibility) {
 		if (cellVisibilityListeners == null) {
