@@ -24,13 +24,19 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.regex.PatternSyntaxException;
 import java.util.stream.Collectors;
 
+import com.biglybt.core.config.COConfigurationManager;
+import com.biglybt.core.config.ParameterListener;
 import com.biglybt.core.config.impl.ConfigurationManager;
+import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.logging.LogEvent;
 import com.biglybt.core.logging.LogIDs;
 import com.biglybt.core.logging.Logger;
 import com.biglybt.core.util.*;
+import com.biglybt.ui.UIFunctions;
+import com.biglybt.ui.UIFunctionsManager;
 import com.biglybt.ui.common.table.*;
 import com.biglybt.ui.selectedcontent.SelectedContentManager;
+import com.biglybt.util.DataSourceUtils;
 import com.biglybt.pif.ui.tables.TableColumn;
 import com.biglybt.pif.ui.tables.TableRow;
 import com.biglybt.pif.ui.tables.TableRowRefreshListener;
@@ -57,6 +63,20 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 	// Shorter name for ConfigManager, easier to read code
 	protected static final ConfigurationManager configMan = ConfigurationManager.getInstance();
 
+	private static boolean	confusableFiltering;
+	
+	static{
+		COConfigurationManager.addAndFireParameterListener(
+			"Table.filter.confusable",
+			new ParameterListener(){
+				
+				@Override
+				public void parameterChanged(String parameterName){
+					confusableFiltering = COConfigurationManager.getBooleanParameter( "Table.filter.confusable" );
+				}
+			});	
+	}
+	
 	private class
 	rowSorterRunnable
 		extends AERunnable
@@ -220,7 +240,9 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 
 	private boolean provideIndexesOnRemove = false;
 
-
+	
+	private LinkedList<HistoryEntry>	historyBefore 	= new LinkedList<>();
+	private LinkedList<HistoryEntry>	historyAfter	= new LinkedList<>();	
 
 	public TableViewImpl(Class<?> pluginDataSourceType, String _sTableID,
 			String _sPropertiesPrefix, Object rows_sync,
@@ -689,7 +711,7 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 				boolean isOurs;
 				
 				try{
-					isOurs = filter.checker.filterCheck(dst, filter.text,filter.regex);
+					isOurs = filterCheck(dst);
 					
 				}catch( PatternSyntaxException e ){
 					// get this with malformed filter regex, ignore
@@ -737,7 +759,7 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 		}
 
 		try{
-			return( filter.checker.filterCheck( ds, filter.text, filter.regex ));
+			return( filterCheck( ds ));
 			
 		}catch( PatternSyntaxException e ){
 			// get this with malformed filter regex, ignore		
@@ -842,8 +864,7 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 		}
 
 		try{
-			if (!skipFilterCheck && filter != null
-					&& !filter.checker.filterCheck(dataSource, filter.text, filter.regex)) {
+			if (!skipFilterCheck && filter != null && !filterCheck(dataSource)) {
 				return;
 			}
 		}catch( PatternSyntaxException e ){
@@ -917,8 +938,7 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 			if (!skipFilterCheck && filter != null) {
 				try{
 					for (int i = 0; i < dataSources.length; i++) {
-						if (!filter.checker.filterCheck(dataSources[i], filter.text,
-								filter.regex)) {
+						if (!filterCheck(dataSources[i])) {
 							dataSources[i] = null;
 						}
 					}
@@ -946,8 +966,7 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 				try{
 					if (!skipFilterCheck
 							&& filter != null
-							&& !filter.checker.filterCheck(dataSource, filter.text,
-									filter.regex)) {
+							&& !filterCheck(dataSource )) {
 						continue;
 					}
 				}catch( PatternSyntaxException e ){
@@ -976,6 +995,32 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 		refreshenProcessDataSourcesTimer();
 	}
 	
+	boolean
+	filterCheck(
+		DATASOURCETYPE	ds )
+	{
+		if ( confusableFiltering ){
+			
+			boolean regex = filter.regex;
+			
+			if ( regex ){
+				
+				return( filter.checker.filterCheck( ds, filter.text, regex, false ));
+			}
+			
+			if ( filter.checker.filterCheck( ds, filter.text, false, false )){
+				
+				return( true );
+			}
+			
+			return( filter.checker.filterCheck( ds, filter.text, false, true ));
+			
+		}else{
+			
+			return( filter.checker.filterCheck( ds, filter.text, filter.regex, false ));
+		}
+	}
+	
 	protected boolean
 	hasPendingDSChanges()
 	{
@@ -2010,12 +2055,16 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 	}
 
 	@Override
-	public void tableStructureChanged(boolean columnAddedOrRemoved,
-	                                  Class forPluginDataSourceType) {
-		if (forPluginDataSourceType != null
-				&& !forPluginDataSourceType.equals(getDataSourceType())) {
+	public void 
+	tableStructureChanged(
+		boolean		columnAddedOrRemoved,
+	    Class		forPluginDataSourceType ) 
+	{
+		if ( forPluginDataSourceType != null && !DataSourceUtils.isPluginTypeCompatible( forPluginDataSourceType, getDataSourceType() )){
+			
 			return;
 		}
+		
 		triggerLifeCycleListener(TableLifeCycleListener.EVENT_TABLELIFECYCLE_DESTROYED);
 
 		DATASOURCETYPE[] unfilteredDS;
@@ -2091,6 +2140,22 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 		return null;
 	}
 
+	@Override
+	public com.biglybt.pif.ui.tables.TableColumn getTableColumn(
+			String sColumnName, boolean localized ) {
+		for (int i = 0; i < tableColumns.length; i++) {
+			TableColumnCore tc = tableColumns[i];
+			if ( localized ){
+				if ( MessageText.getString(tc.getTitleLanguageKey()).equalsIgnoreCase( sColumnName )){
+					return( tc );
+				}
+			}else if (tc.getName().equals(sColumnName)) {
+				return tc;
+			}
+		}
+		return null;
+	}
+	
 	// @see TableView#getVisibleColumns()
 	@Override
 	public TableColumnCore[] getVisibleColumns() {
@@ -2326,21 +2391,34 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 		TableColumnCore[] sortColumns = getSortColumns();
 		List<TableColumnCore> listNewColumns = new ArrayList<>();
 		boolean alreadySortingByColumn = false;
+		Map<TableColumnCore,Boolean> originalAscMap = new HashMap<>();
 		for (TableColumnCore existingSortColumn : sortColumns) {
 			listNewColumns.add(existingSortColumn);
 			if (existingSortColumn == column) {
-				column.setSortAscending(!column.isSortAscending());
+				boolean asc = column.isSortAscending();
+				originalAscMap.put(column, asc);
+				column.setSortAscending(!asc);
 				alreadySortingByColumn = true;
 			}
 		}
 		if (!alreadySortingByColumn) {
 			listNewColumns.add(column);
 		}
-		setSortColumns(listNewColumns.toArray(new TableColumnCore[0]), false);
+		setSortColumns(listNewColumns.toArray(new TableColumnCore[0]), false,originalAscMap,true);
 	}
 
 	@Override
 	public boolean setSortColumns(TableColumnCore[] newSortColumns, boolean allowOrderChange) {
+		return( setSortColumns( newSortColumns, allowOrderChange, null, true ));
+	}
+
+	private boolean 
+	setSortColumns(
+		TableColumnCore[] 				newSortColumns, 
+		boolean 						allowOrderChange,
+		Map<TableColumnCore,Boolean> 	originalAscMap,
+		boolean 						doHistory ) 
+	{
 		if (newSortColumns == null) {
 			return false;
 		}
@@ -2348,6 +2426,24 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 			// did use sortColumn_mon
 
 		synchronized (rows_sync) {
+			TableColumnCore[] 	originalColumns 	= null;
+			boolean[]			originalAscending	= null;
+			
+			if ( doHistory ){
+				originalColumns 	= sortColumns.toArray( new TableColumnCore[sortColumns.size()]);
+				originalAscending	= new boolean[originalColumns.length];
+
+				for ( int i=0;i<originalColumns.length; i++){
+					originalAscending[i] = originalColumns[i].isSortAscending();
+					if ( originalAscMap != null ){
+						Boolean asc = originalAscMap.get(originalColumns[i]);
+						if ( asc != null ){
+							originalAscending[i] = asc;
+						}
+					}
+				}
+			}
+			
 			boolean columnsChanged = sortColumns.size() != newSortColumns.length;
 			if (!columnsChanged) {
 				for (int i = 0; i < sortColumns.size(); i++) {
@@ -2397,6 +2493,16 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 					row.setSortColumn(sortColumnNames);
 				}
 			}
+			if ( doHistory && originalColumns.length > 0 ){
+				TableColumnCore[] 	newColumns 		= sortColumns.toArray( new TableColumnCore[sortColumns.size()]);
+				boolean[]			newAscending	= new boolean[newColumns.length];
+
+				for ( int i=0;i<newColumns.length; i++){
+					newAscending[i] = newColumns[i].isSortAscending();
+				}
+				addHistory( new HistorySort( originalColumns, originalAscending, newColumns, newAscending ));
+			}
+			
  			uiChangeColumnIndicator();
  			resetLastSortedOn();
  			sortRows(columnsChanged,false);
@@ -2433,6 +2539,11 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 
 	public void setSelectedRows(final TableRowCore[] newSelectionArray,
 			final boolean trigger) {
+		setSelectedRows( newSelectionArray, trigger, true);
+	}
+	
+	private void setSelectedRows(final TableRowCore[] newSelectionArray,
+			final boolean trigger, boolean updateHistory ) {
 		if (isDisposed()) {
 			return;
 		}
@@ -2491,6 +2602,15 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 
 			somethingChanged = listNewlySelected.size() > 0
 					|| oldSelectionList.size() > 0;
+					
+			if ( somethingChanged && updateHistory ){
+				
+				addHistory( 
+					new HistorySelection( 
+						oldSelectionList.toArray( new TableRowCore[ oldSelectionList.size()]), 
+						selectedRows.toArray( new TableRowCore[ selectedRows.size()])));
+			}
+			
 			if (DEBUG_SELECTION) {
 				System.out.println(somethingChanged + "] +"
 						+ listNewlySelected.size() + "/-" + oldSelectionList.size()
@@ -2600,4 +2720,211 @@ public abstract class TableViewImpl<DATASOURCETYPE>
 	
 	protected abstract boolean
 	isTableFocused();
+	
+	@Override
+	public boolean 
+	canMoveBack()
+	{
+		return( !historyBefore.isEmpty());
+	}
+	
+	@Override
+	public void 
+	moveBack()
+	{
+		HistoryEntry history;
+		
+		synchronized( rows_sync ){
+			
+			if ( historyBefore.isEmpty()){
+				
+				return;
+			}
+			
+			history = historyBefore.removeLast();
+			
+			historyAfter.addFirst( history );
+		}
+		
+		history.applyPrev();
+		
+		if ( 	SelectedContentManager.getCurrentlySelectedTableView() == this &&
+				( historyBefore.isEmpty() || historyAfter.size() == 1 )){
+			
+			UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
+			
+		  	if ( uiFunctions != null ){
+		  		
+		  		uiFunctions.refreshIconBar();
+		  	}
+		}
+	}
+	
+	@Override
+	public boolean 
+	canMoveForward()
+	{
+		return( !historyAfter.isEmpty());
+	}
+	
+	@Override
+	public void 
+	moveForward()
+	{
+		HistoryEntry history;
+		
+		synchronized( rows_sync ){
+			
+			if ( historyAfter.isEmpty()){
+				
+				return;
+			}
+			
+			history = historyAfter.removeFirst();
+			
+			historyBefore.addLast( history );
+		}
+		
+		history.applyNext();
+		
+		if ( 	SelectedContentManager.getCurrentlySelectedTableView() == this &&
+				( historyAfter.isEmpty() || historyBefore.size() == 1 )){
+			
+			UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
+			
+		  	if ( uiFunctions != null ){
+		  		
+		  		uiFunctions.refreshIconBar();
+		  	}
+		}
+	}
+	
+	private void
+	addHistory(
+		HistoryEntry		entry )
+	{
+		historyBefore.add( entry );
+		
+		if ( historyBefore.size() > 32 ){
+			
+			historyBefore.removeFirst();
+		}
+		
+		boolean historyAfterWasEmpty = historyAfter.isEmpty();
+		
+		historyAfter.clear();
+		
+		if ( 	SelectedContentManager.getCurrentlySelectedTableView() == this &&
+				( !historyAfterWasEmpty || historyBefore.size() == 1 )){
+			
+			UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
+			
+		  	if ( uiFunctions != null ){
+		  		
+		  		uiFunctions.refreshIconBar();
+		  	}
+		}
+	}
+	
+	private static interface
+	HistoryEntry
+	{
+		void
+		applyNext();
+		
+		void
+		applyPrev();
+	}
+	
+	private class
+	HistorySelection
+		implements HistoryEntry
+	{
+		private final TableRowCore[]	prevSel;
+		private final TableRowCore[]	nextSel;
+		
+		HistorySelection(
+			TableRowCore[]	_prev,
+			TableRowCore[]	_next )
+		{
+			prevSel = _prev;
+			nextSel	= _next;
+		}
+		
+		public void
+		applyNext()
+		{
+			apply( nextSel );
+		}
+		
+		public void
+		applyPrev()
+		{
+			apply( prevSel );
+		}
+		
+		private void
+		apply(
+			TableRowCore[]	sel )
+		{
+			setSelectedRows( sel, true, false ) ;
+			
+			if ( sel.length > 0 ){
+				
+				TableRowCore first = sel[0];
+				
+				if ( !first.isVisible()){
+				
+					showRow( first );
+				}
+			}
+		}
+	}
+	
+	private class
+	HistorySort
+		implements HistoryEntry
+	{
+		private final TableColumnCore[]	prevCols;
+		private final TableColumnCore[]	nextCols;
+		
+		private final boolean[]		prevAsc;
+		private final boolean[]		nextAsc;
+		
+		HistorySort(
+			TableColumnCore[]	pCols,
+			boolean[]			pAsc,
+			TableColumnCore[] 	nCols,
+			boolean[]			nAsc )
+		{
+			prevCols		= pCols;
+			prevAsc			= pAsc;
+			nextCols		= nCols;
+			nextAsc			= nAsc;
+		}
+		
+		public void
+		applyNext()
+		{
+			apply( nextCols, nextAsc );
+		}
+		
+		public void
+		applyPrev()
+		{
+			apply( prevCols, prevAsc );
+		}
+		
+		private void
+		apply(
+			TableColumnCore[]	columns,
+			boolean[]			asc )
+		{
+			for ( int i=0;i<columns.length;i++){
+				columns[i].setSortAscending(asc[i]);
+			}
+			
+			setSortColumns( columns, false, null, false );
+		}
+	}
 }
