@@ -42,7 +42,8 @@ public class ConfigSectionFile
 	extends ConfigSectionImpl
 {
 
-	public static final String REFID_TORRENT_ADD_AUTO_SKIP = "torrent-add-auto-skip";
+	public static final String REFID_TORRENT_ADD_AUTO_SKIP 		= "torrent-add-auto-skip";
+	public static final String REFID_TORRENT_ADD_AUTO_PRIORITY	= "torrent-add-auto-priority";
 
 	public ConfigSectionFile() {
 		super(ConfigSection.SECTION_FILES, ConfigSection.SECTION_ROOT);
@@ -251,16 +252,21 @@ public class ConfigSectionFile
 		add(minmerge, Parameter.MODE_INTERMEDIATE);
 		minmerge.setIndent(1, true);
 
-		mergeSameSize.addEnabledOnSelection(minmerge);
-		
-		
+		mergeSameSize.addEnabledOnSelection(minmerge);		
 		
 		// check on complete
 		BooleanParameterImpl checkPiecesOnCompletion = new BooleanParameterImpl(
 				BCFG_CHECK_PIECES_ON_COMPLETION, "ConfigView.label.checkOncompletion");
 		add(checkPiecesOnCompletion, Parameter.MODE_INTERMEDIATE);
 
-		// check on complete
+		BooleanParameterImpl checkPiecesOnCompletionBeforeMove = new BooleanParameterImpl(
+				BCFG_CHECK_PIECES_ON_COMPLETION_BEFORE_MOVE, "ConfigView.label.checkOncompletionBeforeMove");
+		add(checkPiecesOnCompletionBeforeMove, Parameter.MODE_INTERMEDIATE);
+		checkPiecesOnCompletionBeforeMove.setIndent(1, true);
+		
+		checkPiecesOnCompletion.addEnabledOnSelection(checkPiecesOnCompletionBeforeMove);
+		
+		// check on seeding
 		BooleanParameterImpl seedingPieceCheckRecheck = new BooleanParameterImpl(
 				BCFG_SEEDING_PIECE_CHECK_RECHECK_ENABLE,
 				"ConfigView.label.checkOnSeeding");
@@ -347,12 +353,18 @@ public class ConfigSectionFile
 
 		save_peers.addEnabledOnSelection(savePeersMax);
 
-		// disable interim state save 
+			// disable interim state save 
 		BooleanParameterImpl bDisableSveInterim = new BooleanParameterImpl(BCFG_DISABLE_SAVE_INTERIM_DOWNLOAD_STATE,
 				"ConfigView.label.disableinterimstatesave");
 		add(bDisableSveInterim, Parameter.MODE_ADVANCED );
 		
-			// skip complete download file existance checks 
+			// skip incomplete download file existence checks 
+		
+		BooleanParameterImpl bSkipIncompDLFileChecks = new BooleanParameterImpl(BCFG_SKIP_INCOMP_DL_FILE_CHECKS,
+			"ConfigView.label.skipIncompDLFileChecks");
+		add(bSkipIncompDLFileChecks, Parameter.MODE_ADVANCED );
+
+			// skip complete download file existence checks 
 		
 		BooleanParameterImpl bSkipCompDLFileChecks = new BooleanParameterImpl(BCFG_SKIP_COMP_DL_FILE_CHECKS,
 				"ConfigView.label.skipCompDLFileChecks");
@@ -368,15 +380,15 @@ public class ConfigSectionFile
 				BCFG_PRIORITY_EXTENSIONS_IGNORE_CASE, "ConfigView.label.ignoreCase");
 		add(priorityExtensionsIgnoreCase, Parameter.MODE_INTERMEDIATE);
 
-		ParameterGroupImpl pgPriorityExt = new ParameterGroupImpl(null,
-				priorityExtensions, priorityExtensionsIgnoreCase);
+		ParameterGroupImpl pgPriorityExt = new ParameterGroupImpl(null,	priorityExtensions, priorityExtensionsIgnoreCase);
+		pgPriorityExt.setReferenceID(REFID_TORRENT_ADD_AUTO_PRIORITY);
 		add("pgPriorityExt", pgPriorityExt, listExt);
 		pgPriorityExt.setNumberOfColumns(2);
 
 		add(new StringParameterImpl(SCFG_FILE_AUTO_SEQUENTIAL_EXTS,
 				"ConfigView.label.sequential.exts"), Parameter.MODE_INTERMEDIATE,
 				listExt);
-
+		
 		// quick view
 
 		StringParameterImpl quickViewExts = new StringParameterImpl(
@@ -389,9 +401,10 @@ public class ConfigSectionFile
 
 		ParameterGroupImpl pgQV = new ParameterGroupImpl(null, quickViewExts,
 				quickViewMaxKB);
+		
 		add("pgQV", pgQV, listExt);
 		pgQV.setNumberOfColumns(2);
-
+		
 		// rename incomplete files
 
 		BooleanParameterImpl rename_incomplete = new BooleanParameterImpl(
