@@ -1232,7 +1232,7 @@ BuddyPluginView
 				
 				TableManager	table_manager = plugin.getPluginInterface().getUIManager().getTableManager();
 				
-				table_manager.unregisterColumn(Download.class, "azbuddy.ui.column.msgpending",	columnMessagePending);
+				table_manager.unregisterColumn(Download.class, "azbuddy.ui.column.msgpending");
 				
 				columnMessagePending = null;
 				
@@ -1747,7 +1747,7 @@ BuddyPluginView
 
 				String	short_name = chat.getShortName();
 
-				mi = menu_manager.addMenuItem( mc, "!" + short_name + "!" );
+				mi = menu_manager.addMenuItem( mc, "!" + Utils.escapeAccelerators(short_name) + "!" );
 
 				mi.addListener(
 					new MenuItemListener() {
@@ -1797,7 +1797,7 @@ BuddyPluginView
 
 						String	short_name = chat.getShortName();
 
-						mi = menu_manager.addMenuItem( mc, "!" + short_name + "!" );
+						mi = menu_manager.addMenuItem( mc, "!" + Utils.escapeAccelerators(short_name) + "!" );
 
 						mi.addListener(
 							new MenuItemListener() {
