@@ -45,12 +45,13 @@ import com.biglybt.pif.ui.menus.MenuItemFillListener;
 import com.biglybt.pif.ui.menus.MenuItemListener;
 import com.biglybt.pif.ui.menus.MenuManager;
 import com.biglybt.pifimpl.local.ui.menus.MenuItemImpl;
+import com.biglybt.pifimpl.local.ui.tables.TableContextMenuItemImpl;
 import com.biglybt.pifimpl.local.utils.FormattersImpl;
 import com.biglybt.pif.ui.tables.TableContextMenuItem;
+import com.biglybt.ui.common.table.TableView;
 import com.biglybt.ui.swt.pif.UISWTGraphic;
 import com.biglybt.ui.swt.shells.main.MainMenuV3;
 import com.biglybt.core.internat.MessageText;
-import com.biglybt.core.tag.Tag;
 import com.biglybt.core.util.*;
 
 import com.biglybt.plugin.I2PHelpers;
@@ -167,6 +168,8 @@ public class MenuBuildUtils {
 	 */
 	public static interface PluginMenuController {
 
+		public void buildStarts( Menu menu );
+		
 		/**
 		 * This method should create a listener object which should be invoked
 		 * when the given menu item is selected.
@@ -195,6 +198,8 @@ public class MenuBuildUtils {
 	public static class MenuItemPluginMenuControllerImpl implements
 			PluginMenuController {
 
+		private Menu	parentMenu;
+		
 		private Object[] objects;
 
 		public MenuItemPluginMenuControllerImpl(Object[] o) {
@@ -207,6 +212,10 @@ public class MenuBuildUtils {
 			return new Listener() {
 				@Override
 				public void handleEvent(Event e) {
+					if ( mii instanceof TableContextMenuItemImpl ){
+						TableView<?> tv = (TableView<?>)parentMenu.getData( TableContextMenuItemImpl.MENUKEY_TABLE_VIEW );
+						((TableContextMenuItemImpl)mii).setTable(tv);
+					}
 					mii.invokeListenersMulti(objects);
 				}
 			};
@@ -214,7 +223,12 @@ public class MenuBuildUtils {
 
 		@Override
 		public void notifyFillListeners(MenuItem menu_item) {
-			((MenuItemImpl) menu_item).invokeMenuWillBeShownListeners(objects);
+			MenuItemImpl mii = (MenuItemImpl) menu_item;
+			if ( mii instanceof TableContextMenuItemImpl ){
+				TableView<?> tv = (TableView<?>)parentMenu.getData( TableContextMenuItemImpl.MENUKEY_TABLE_VIEW );
+				((TableContextMenuItemImpl)mii).setTable(tv);
+			}
+			mii.invokeMenuWillBeShownListeners(objects);
 		}
 
 		// @see com.biglybt.ui.swt.MenuBuildUtils.PluginMenuController#buildSubmenu(com.biglybt.pif.ui.menus.MenuItem)
@@ -231,8 +245,14 @@ public class MenuBuildUtils {
 			}
 		}
 		
+		@Override
+		public void buildStarts(Menu menu){
+			parentMenu = menu;
+		}
+		
 		@Override
 		public void buildComplete(Menu menu){
+			parentMenu = menu;
 		}
 	}
 
@@ -268,6 +288,8 @@ public class MenuBuildUtils {
 			boolean prev_was_separator,
 			final boolean enable_items, final PluginMenuController controller) {
 
+		controller.buildStarts( parent );
+		
 		for (int i = 0; i < items.length; i++) {
 			final MenuItemImpl az_menuitem = (MenuItemImpl) items[i];
 
@@ -305,11 +327,19 @@ public class MenuBuildUtils {
 
 			prev_was_separator = this_is_separator;
 
-			final org.eclipse.swt.widgets.MenuItem menuItem = new org.eclipse.swt.widgets.MenuItem(
-					parent, swt_style);
-
-			if (swt_style == SWT.SEPARATOR) {continue;}
-
+			final org.eclipse.swt.widgets.MenuItem menuItem;
+			
+			if ( this_is_separator ){
+				
+				addSeparator( parent );
+				
+				continue;
+				
+			}else{
+				
+				menuItem = new org.eclipse.swt.widgets.MenuItem( parent, swt_style );
+			}
+			
 			if (enable_items) {
 
 				if (style == TableContextMenuItem.STYLE_CHECK
@@ -1451,7 +1481,7 @@ public class MenuBuildUtils {
 		 */
 	
 	public static void
-	addSeparater(
+	addSeparator(
 		Menu		menu )
 	{
 		if ( menu.isDisposed() || menu.getItemCount() == 0 ){
