@@ -19,6 +19,7 @@ package com.biglybt.ui.swt;
 
 import java.util.*;
 import java.util.List;
+import java.util.function.Consumer;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.DisposeEvent;
@@ -38,6 +39,8 @@ public class TextViewerWindow {
 	
   private boolean reuseWindow;
   
+  private Consumer<TextViewerWindow> refresher;
+  
   private boolean modal;
   private boolean defer_modal;
   
@@ -46,6 +49,7 @@ public class TextViewerWindow {
   
   private final Composite buttonArea;
   
+  private Button refresh;
   private Button ok;
   private Button cancel;
   
@@ -83,6 +87,15 @@ public class TextViewerWindow {
   TextViewerWindow(
 	Shell parent_shell, String sTitleID, String sMessageID, String sText, boolean _modal, boolean _defer_modal )
   {
+	  this( parent_shell, sTitleID, sMessageID, sText, null, _modal, _defer_modal );
+  }
+  
+  public
+  TextViewerWindow(
+	Shell parent_shell, String sTitleID, String sMessageID, String sText, Consumer<TextViewerWindow> _refresher, boolean _modal, boolean _defer_modal )
+  {
+	refresher = _refresher;
+	  
 	modal = _modal;
 	defer_modal = _defer_modal;
 	
@@ -261,6 +274,17 @@ public class TextViewerWindow {
 	  GridData gridData = new GridData( GridData.FILL_HORIZONTAL );
 	  label.setLayoutData(gridData);
 
+	  if ( refresher != null ){
+		  refresh = new Button(buttonArea, SWT.PUSH);
+		  refresh.setText(MessageText.getString("upnp.refresh.button"));
+		  refresh.addListener(SWT.Selection, new Listener() {
+			  @Override
+			  public void handleEvent(Event event) {
+				  refresher.accept(TextViewerWindow.this);
+			  }
+		  });
+	  }
+	  
 	  if ( cancel_enabled ){
 		  if (Constants.isOSX) {
 			  cancel = new Button(buttonArea, SWT.PUSH);
@@ -276,7 +300,7 @@ public class TextViewerWindow {
 	  }
 	  ok.setText(MessageText.getString("Button.ok"));
 
-	  Utils.makeButtonsEqualWidth( Arrays.asList( ok, cancel ));
+	  Utils.makeButtonsEqualWidth( Arrays.asList( refresh, ok, cancel ));
 
 	  shell.setDefaultButton(ok);
 	  
@@ -378,10 +402,21 @@ public class TextViewerWindow {
   public void
   setText(
 	 String	text )
+  {
+	  setText( text, true );
+  }
+  
+  public void
+  setText(
+	 String		text,
+	 boolean	scrollToBottom )
   {
 	  txtInfo.setText( text);
 
-	  txtInfo.setSelection( txtInfo.getTextLimit());
+	  if ( scrollToBottom ){
+		  
+		  txtInfo.setSelection( txtInfo.getTextLimit());
+	  }
   }
 
   public void
@@ -390,7 +425,10 @@ public class TextViewerWindow {
   {
 	  txtInfo.setEditable( editable );
 	 
-	  cancel_enabled = true;
+	  if ( editable ){
+		  
+		  cancel_enabled = true;
+	  }
 	  
 	  buildButtons();
   }
