@@ -21,6 +21,7 @@ package com.biglybt.ui.swt;
 import static com.biglybt.pif.ui.menus.MenuItem.*;
 
 import java.io.File;
+import java.text.SimpleDateFormat;
 import java.util.*;
 import java.util.List;
 
@@ -1275,6 +1276,8 @@ public class TorrentMenuFancy
 							boolean allAllocatable		= true;
 							boolean allMaskDC 			= true;
 							
+							boolean globalMask = COConfigurationManager.getBooleanParameter( ConfigKeys.Transfer.BCFG_PEERCONTROL_HIDE_PIECE );
+
 							for (DownloadManager dm : dms) {
 								boolean stopped = ManagerUtils.isStopped(dm);
 
@@ -1314,7 +1317,11 @@ public class TorrentMenuFancy
 																
 								allAllocatable &= stopped && !dm.isDataAlreadyAllocated() && !dm.isDownloadComplete( false );	
 								
-								allMaskDC = allMaskDC && dms.getBooleanAttribute( DownloadManagerState.AT_MASK_DL_COMP );
+								Boolean dmmask = dms.getOptionalBooleanAttribute( DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL );
+								
+								boolean mask = dmmask==null?globalMask:dmmask;
+								
+								allMaskDC = allMaskDC && mask;
 							}
 
 							boolean fileRescan = allScanSelected || allScanNotSelected;
@@ -1363,6 +1370,20 @@ public class TorrentMenuFancy
 
 							itemRevertFiles.setEnabled(hasRevertableFiles);
 							
+								// view links
+	
+							final MenuItem itemViewLinks = new MenuItem(menu, SWT.PUSH);
+							Messages.setLanguageText(itemViewLinks, "menu.view.links");
+							itemViewLinks.addListener(SWT.Selection, new ListenerDMTask(dms) {
+								@Override
+								public void 
+								run(
+									DownloadManager[] dms)
+								{
+									ManagerUtils.viewLinks( dms );
+								}
+							});
+						
 								// clear links
 
 							final MenuItem itemClearLinks = new MenuItem(menu, SWT.PUSH);
@@ -1387,7 +1408,7 @@ public class TorrentMenuFancy
 
 												if ( !file_nolink.getAbsolutePath().equals( file_link.getAbsolutePath())){
 
-													file_info.setLink( null );
+													file_info.setLink( null, true );
 												}
 											}
 										}
@@ -1459,25 +1480,56 @@ public class TorrentMenuFancy
 							});
 							itemFileSetResumeComplete.setEnabled(allStopped&&allResumeIncomplete);
 
+							
+								// restore resume
+							
+							final Menu restore_menu = new Menu( menu.getShell(), SWT.DROP_DOWN);
+							
+							MenuItem itemRestoreResume = new MenuItem(menu, SWT.CASCADE);
+							Messages.setLanguageText(itemRestoreResume,	"MyTorrentsView.menu.restore.resume.data");
+							
+							itemRestoreResume.setMenu( restore_menu );
+							
+							boolean restoreEnabled = false;
+							
+							if ( dms.length==1 && allStopped ){
+								DownloadManagerState dmState = dms[0].getDownloadState();
+								
+								List<DownloadManagerState.ResumeHistory> history = dmState.getResumeDataHistory();
+								
+								if ( !history.isEmpty()){
+									restoreEnabled = true;
+								
+									for ( DownloadManagerState.ResumeHistory h: history ){
+										MenuItem itemHistory = new MenuItem(restore_menu, SWT.PUSH);
+										itemHistory.setText( new SimpleDateFormat().format( new Date(h.getDate())));
+										
+										itemHistory.addListener(SWT.Selection,(ev)->{
+											dmState.restoreResumeData( h );;
+										});
+									}
+								}
+							}
+							
+							itemRestoreResume.setEnabled( restoreEnabled);
+			
 								// mask dl comp
-							
-							boolean globalMask = COConfigurationManager.getBooleanParameter( ConfigKeys.Transfer.BCFG_PEERCONTROL_HIDE_PIECE );
-							
+														
 							MenuItem itemMaskDLComp = new MenuItem(menu, SWT.CHECK);
 							
 							if ( dms.length > 0 ){
-								itemMaskDLComp.setSelection( globalMask || allMaskDC );
+								itemMaskDLComp.setSelection( allMaskDC );
 							}
 							
 							Messages.setLanguageText(itemMaskDLComp,"ConfigView.label.hap");
 							itemMaskDLComp.addListener(SWT.Selection, new ListenerDMTask(dms) {
 								@Override
 								public void run(DownloadManager dm) {
-									dm.getDownloadState().setBooleanAttribute( DownloadManagerState.AT_MASK_DL_COMP, itemMaskDLComp.getSelection());
+									dm.getDownloadState().setOptionalBooleanAttribute( DownloadManagerState.AT_MASK_DL_COMP_OPTIONAL, itemMaskDLComp.getSelection());
 								}
 							});
 							
-							itemMaskDLComp.setEnabled( dms.length > 0 && !globalMask );
+							itemMaskDLComp.setEnabled( dms.length > 0 );
 
 							if (userMode > 1 && isSeedingView) {
 
@@ -2055,7 +2107,9 @@ public class TorrentMenuFancy
 						});
 				row.getText().setText(title);
 				
-				row.setEnabled( dms[0].getTorrent().isExportable());
+				TOTorrent torrent = dms[0].getTorrent();
+				
+				row.setEnabled( torrent != null && torrent.isExportable());
 			}
 
 			// Advanced > Export > Export Torrent
@@ -2253,6 +2307,10 @@ public class TorrentMenuFancy
 												}
 											}
 											
+											@Override
+											public void buildStarts(Menu menu){
+											}
+											
 											@Override
 											public void buildComplete(Menu menu){
 												addMenuItemListener(menu, listenerForTrigger);
@@ -2469,7 +2527,12 @@ public class TorrentMenuFancy
 			if ( !dm.canExportDownload()){
 				exportFiles = false;
 			}
-			if ( !dm.isDownloadComplete( false ) || dm.getState() == DownloadManager.STATE_ERROR ){
+			int state = dm.getState();
+			
+			if ( 	!dm.isDownloadComplete( false ) ||  
+					state == DownloadManager.STATE_ERROR || 
+					state == DownloadManager.STATE_STOPPED ){
+				
 				locateFiles = true;
 			}
 			
