@@ -205,16 +205,22 @@ public class UIConfigDefaultsSWT
 		def.addParameter("MyTorrentsView.table.style", 0);
 
 		def.addParameter("v3.topbar.height", 60);
+		def.addParameter("v3.rightbar.width", 150);
 		def.addParameter("v3.topbar.show.plugin", false);
 		def.addParameter("pluginbar.visible", false);
+		def.addParameter("rightbar.visible", false);
 		def.addParameter("quick-links.visible", true);
 		def.addParameter("ui.toolbar.uiswitcher", false);
 		def.addParameter("Table.extendedErase", false);
 		def.addParameter("Table.useTree", false);
 		def.addParameter("Table.tooltip.disable", false);
+		def.addParameter("Table.tooltip.truncate", true);
 		def.addParameter("Table.sort.intuitive", false);
+		def.addParameter("Table.filter.confusable", true );
+		def.addParameter("Table Header Gradient Fill", true);
 		def.addParameter("Dark Table Colors", false );
 		def.addParameter("Dark Misc Colors", false );
+		def.addParameter("Gradient Fill Selection", true );
 		
 		if ("az2".equalsIgnoreCase(COConfigurationManager.getStringParameter("ui", "az3"))) {
 			def.addParameter("v3.Show Welcome", false);
@@ -237,10 +243,13 @@ public class UIConfigDefaultsSWT
 
 		def.addParameter( "Low Resource Silent Update Restart Enabled", true );
 
+		def.addParameter( "Library.ShowTitle", true );
 		def.addParameter( "Library.ShowCatButtons", false );
+		def.addParameter( "Library.ShowCatButtons.CompOnly", false );
 		def.addParameter( "Library.ShowTagButtons", true );
 		def.addParameter( "Library.ShowTagButtons.FiltersOnly", false );
 		def.addParameter( "Library.ShowTagButtons.ImageOverride", false );
+		def.addParameter( "Library.ShowTagButtons.Align", 0);
 		def.addParameter( "Library.ShowTagButtons.CompOnly", false );
 		def.addParameter( "Library.ShowTagButtons.Inclusive", true );
 		
