@@ -36,7 +36,6 @@ import com.biglybt.pif.download.Download;
 import com.biglybt.pif.ui.tables.TableCell;
 import com.biglybt.pif.ui.tables.TableCellRefreshListener;
 import com.biglybt.pif.ui.tables.TableColumn;
-import com.biglybt.pif.ui.tables.TableColumnCreationListener;
 import com.biglybt.pif.ui.tables.TableColumnExtraInfoListener;
 import com.biglybt.pif.ui.tables.TableColumnInfo;
 import com.biglybt.pifimpl.local.PluginCoreUtils;
@@ -60,8 +59,6 @@ public class ColumnTagGroupIcons
 	private static TagManager tag_manager = TagManagerFactory.getTagManager();
 
 	public static final Class DATASOURCE_TYPE = Download.class;
-
-	public static final String COLUMN_ID = "tag_icons";
 	
 	private static int[]	interesting_tts = { TagType.TT_DOWNLOAD_MANUAL, TagType.TT_DOWNLOAD_CATEGORY };
 
@@ -106,7 +103,7 @@ public class ColumnTagGroupIcons
 		
 							if ( sTags == null ){
 								
-								sTags = str;
+								sTags = tag_group.getName() + ": " + str;
 								
 							}else{
 								
@@ -157,7 +154,7 @@ public class ColumnTagGroupIcons
 			bounds.x+=1;
 			bounds.y+=1;
 			bounds.width-=1;
-			bounds.height-=1;
+			bounds.height-=2;
 
 			int w = bounds.width / num_files;			
 			
