@@ -39,7 +39,7 @@ import com.biglybt.ui.swt.Messages;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.mainwindow.ClipboardCopy;
 import com.biglybt.ui.swt.mainwindow.Colors;
-
+import com.biglybt.ui.swt.views.ConfigView;
 import com.biglybt.pif.ui.config.Parameter;
 import com.biglybt.pif.ui.config.ParameterValidator.ValidationInfo;
 import com.biglybt.pif.ui.config.ParameterWithSuffix;
@@ -47,8 +47,6 @@ import com.biglybt.pif.ui.config.ParameterWithSuffix;
 public abstract class BaseSwtParameter<PARAMTYPE extends SwtParameter<VALUETYPE>, VALUETYPE>
 	implements SwtParameter<VALUETYPE>
 {
-	public final static String KEY_LABEL_ADDCOPYTOCLIPMENU = "AddCopyMenu";
-
 	protected final String paramID;
 
 	private Control relatedControl;
@@ -499,7 +497,6 @@ public abstract class BaseSwtParameter<PARAMTYPE extends SwtParameter<VALUETYPE>
 			// rely on current value)
 			curControl.forceFocus();
 		}
-		boolean add_copy = curControl.getData(KEY_LABEL_ADDCOPYTOCLIPMENU) != null;
 
 		if (valueProcessor != null) {
 			if (!valueProcessor.isDefaultValue(thisTyped)) {
@@ -513,13 +510,29 @@ public abstract class BaseSwtParameter<PARAMTYPE extends SwtParameter<VALUETYPE>
 				item.addListener(SWT.Selection, event -> resetToDefault());
 			} else if (valueProcessor.getDefaultValue(thisTyped) != null) {
 				MenuItem item = new MenuItem(menu, SWT.PUSH);
-				item.setText("Currently set to default value");
+				Messages.setLanguageText(item, "menu.config.is.default");
 				item.setEnabled(false);
 			}
 		}
-		if (add_copy && (curControl instanceof Label)) {
-			ClipboardCopy.addCopyToClipMenu(menu,
-					() -> ((Label) curControl).getText().trim());
+		String message = Messages.getLanguageForControl( curControl );
+		if ( message != null && !message.trim().isEmpty()){
+			
+			if ( menu.getItemCount() > 0 ){
+				new MenuItem( menu, SWT.SEPARATOR );
+			}
+			
+			message = message.trim();
+			
+			String context = ConfigView.getSectionContext( curControl );
+			
+			if ( context != null ){
+				
+				message = context + ": " + message;
+			}
+			
+			String f_message = message;
+			
+			ClipboardCopy.addCopyToClipMenu(menu, "copy.config.param.name", ()->f_message );
 		}
 	}
 
