@@ -36,6 +36,7 @@ import com.biglybt.core.logging.Logger;
 import com.biglybt.core.logging.impl.FileLogging;
 import com.biglybt.core.peer.PEPeer;
 import com.biglybt.core.peer.PEPeerManager;
+import com.biglybt.core.peer.PEPiece;
 import com.biglybt.core.util.*;
 import com.biglybt.platform.PlatformManagerFactory;
 import com.biglybt.ui.swt.Messages;
@@ -310,41 +311,50 @@ public class UIDebugGenerator
 		}
 
 		CoreWaiterSWT.waitForCore(TriggerInThread.ANY_THREAD,
-				new CoreRunningListener() {
+			new CoreRunningListener() {
 
-					@Override
-					public void coreRunning(Core core) {
-						core.createOperation(CoreOperation.OP_PROGRESS,
-								new CoreOperationTask() {
-									
-									@Override
-									public String getName(){
-										return null;
-									}
-									@Override
-									public void run(CoreOperation operation) {
-										try {
+				@Override
+				public void coreRunning(Core core) {
+					core.executeOperation(
+						CoreOperation.OP_PROGRESS,
+						new CoreOperationTask() {
+							
+							@Override
+							public String getName(){
+								return null;
+							}
+							
+							@Override
+							public DownloadManager 
+							getDownload()
+							{
+								return null;
+							}
+							
+							@Override
+							public void run(CoreOperation operation) {
+								try {
 
-											File fEvidence = new File(path, "evidence.log");
-											PrintWriter pw = new PrintWriter(fEvidence, "UTF-8");
+									File fEvidence = new File(path, "evidence.log");
+									PrintWriter pw = new PrintWriter(fEvidence, "UTF-8");
 
-											AEDiagnostics.generateEvidence(pw);
+									AEDiagnostics.generateEvidence(pw);
 
-											pw.close();
+									pw.close();
 
-										} catch (IOException e) {
+								} catch (IOException e) {
 
-											Debug.printStackTrace(e);
-										}
-									}
+									Debug.printStackTrace(e);
+								}
+							}
 
-									@Override
-									public ProgressCallback getProgressCallback() {
-										return null;
-									}
-								});
-					}
-				});
+							@Override
+							public ProgressCallback getProgressCallback() {
+								return null;
+							}
+						});
+				}
+			});
 
 		try {
 			final File outFile = new File(SystemProperties.getUserPath(), "debug.zip");
@@ -725,8 +735,23 @@ public class UIDebugGenerator
 		}else{
 			return( name );
 		}
-		
 	}
+	
+	public static String
+	obfuscateDownloadName(
+		PEPiece	piece )
+	{
+		if (piece == null) return( "" );
+		PEPeerManager manager = piece.getManager();
+		if (manager == null) return( "" );
+		String name = manager.getDisplayName();
+		if ( name.length() > 3 ){
+			return( name.substring( 0,  3));
+		}else{
+			return( name );
+		}
+	}
+	
 	public static String
 	obfuscateDownloadName(
 		DownloadManager	dm )
