@@ -54,6 +54,9 @@ public class Colors implements ParameterListener {
   public static final int FADED_LIGHTEST = 0;
   public static final int FADED_DARKEST = 9;
 
+  	// sometimes we just want static colours (e.g when on Linux in dark mode the dynamic blues ain't great)
+  
+  public static final Color[] bluesFixed  = new Color[BLUES_DARKEST + 1];
   public static Color[] blues = new Color[BLUES_DARKEST + 1];
   public static Color[] faded = new Color[FADED_DARKEST + 1];
   public static Color colorProgressBar;
@@ -80,7 +83,8 @@ public class Colors implements ParameterListener {
   public static Color background;
   public static Color red_ConsoleView;
   public static Color cyan;
-
+  public static Color orange;
+  
   private static final AEMonitor	class_mon	= new AEMonitor( "Colors" );
 	public static int diffHue;
 	public static float diffSatPct;
@@ -97,6 +101,22 @@ public class Colors implements ParameterListener {
 	private final ParameterListener configListener;
 
   private void allocateBlues() {
+	  
+	  Color[] temp = {
+		  new Color(display, 255, 255, 255 ),
+		  new Color(display, 226, 240, 255 ),
+		  new Color(display, 198, 226, 255 ),
+		  new Color(display, 169, 212, 254 ),
+		  new Color(display, 141, 198, 254 ),
+		  new Color(display, 113, 184, 255 ),
+		  new Color(display, 84, 170, 254 ),
+		  new Color(display, 56, 156, 255 ),
+		  new Color(display, 28, 142, 255 ),
+		  new Color(display, 0, 128, 255 )
+	  };
+	  
+	  System.arraycopy( temp, 0, bluesFixed, 0, temp.length );
+	  
 	  int r = COConfigurationManager.getIntParameter("Color Scheme.red");
 	  int g = COConfigurationManager.getIntParameter("Color Scheme.green");
 	  int b = COConfigurationManager.getIntParameter("Color Scheme.blue");
@@ -128,7 +148,7 @@ public class Colors implements ParameterListener {
             - ((float) i / (float) (blues.length - 1));
         hslColor.blend(tR, tG, tB, blendBy);
         blues[i] = ColorCache.getColor(display, hslColor.getRed(),
-						hslColor.getGreen(), hslColor.getBlue());
+						hslColor.getGreen(), hslColor.getBlue());        
         int iSat = hslColor.getSaturation();
         int luminence = hslColor.getLuminence();
         if (luminence < 20) {
@@ -382,6 +402,7 @@ public class Colors implements ParameterListener {
 		background = ColorCache.getColor(display, 248, 248, 248);
 		red_ConsoleView = ColorCache.getColor(display, 255, 192, 192);
 		cyan = ColorCache.getColor(display, 0, 255, 255);
+		orange = ColorCache.getColor(display, 240, 120, 0);
 		colorAltRowDefault = ColorCache.getColor( display, 240,244,250);
 		
 		allocateColorWarning();
