@@ -481,6 +481,15 @@ public class TabbedMDI
   						selectNextTab(false);
   						event.doit = false;
   					}
+  				}else{
+  					if (focus_control == tabFolder ){
+  						TabbedEntry current = getCurrentEntry();
+  						if ( current != null ){
+  							if ( current.processAccelerator( event.character, event.stateMask )){
+  								event.doit = false;
+  							}
+  						}
+  					}
   				}
   			}
   		});
@@ -534,7 +543,19 @@ public class TabbedMDI
 						mi.addListener(SWT.Selection, new Listener() {
 							@Override
 							public void handleEvent(Event event) {
-								String key = props_prefix + ".closedtabs";
+								
+								String key = props_prefix + ".openedtabs";
+
+								Map openedTabs = COConfigurationManager.getMapParameter(key,new HashMap());
+								
+								if ( !openedTabs.containsKey( view_id )){
+									
+									openedTabs.put( view_id, 1 );
+									
+									COConfigurationManager.setParameter(key,openedTabs );
+								}
+								
+								key = props_prefix + ".closedtabs";
 
 								Map closedtabs = COConfigurationManager.getMapParameter(key,
 										new HashMap());
@@ -594,6 +615,10 @@ public class TabbedMDI
 						
 						COConfigurationManager.setParameter(key, mapUserClosedTabs );
 						
+						key = props_prefix + ".openedtabs";
+						
+						COConfigurationManager.setParameter(key, new HashMap<>() );
+						
 						setPreferredOrder( new String[0] );
 						
 						String key2 = props_prefix + ".tabOrder";
@@ -775,6 +800,31 @@ public class TabbedMDI
 		
 		for (UISWTViewBuilderCore builder : builders){
 			
+			boolean defaultVisibility = builder.getDefaultVisibility();
+			
+			if ( !defaultVisibility ){
+				
+				String key = props_prefix + ".openedtabs";
+
+				Map openedTabs = COConfigurationManager.getMapParameter(key,new HashMap());
+				
+				String view_id = builder.getViewID();
+
+				if ( !openedTabs.containsKey( view_id )){
+				
+					if ( !mapUserClosedTabs.containsKey( view_id )){
+					
+						key = props_prefix + ".closedtabs";
+						
+						Map closedTabs = COConfigurationManager.getMapParameter(key,new HashMap());
+
+						closedTabs.put( view_id, builder.getInitialTitle());
+						
+						COConfigurationManager.setParameter( key, closedTabs );
+					}
+				}
+			}
+			
 			try{
 				createEntry(builder, true);
 				
@@ -1160,11 +1210,12 @@ public class TabbedMDI
 
 	private boolean isEntryClosedByUser(String id) {
 
-		if (mapUserClosedTabs.containsKey(id)) {
-			return true;
+		if ( mapUserClosedTabs.containsKey(id)){
+			
+			return( true );
 		}
-		// TODO Auto-generated method stub
-		return false;
+		
+		return( false );
 	}
 
 	private void setupNewEntry(TabbedEntry entry) {
@@ -1616,6 +1667,27 @@ public class TabbedMDI
 						MainMDISetup.getSb_dashboard().addItemToSidebar( target );
 					}
 				});
+				
+				MenuItem menuItemRightbar = menuManager.addMenuItem( menuParentItem, "label.rightbar");
+				
+				menuItemRightbar.addListener(new MenuItemListener() {
+					@Override
+					public void selected(com.biglybt.pif.ui.menus.MenuItem menu, Object data ) {
+							
+						TabbedEntry	target = entry;
+						
+						if ( data instanceof Object[]) {
+							Object[] odata = (Object[])data;
+							if ( odata.length == 1 && odata[0] instanceof TabbedEntry ) {
+								target = (TabbedEntry)odata[0];
+							}
+						}else if ( data instanceof TabbedEntry ){
+							target = (TabbedEntry)data;
+						}
+						
+						MainMDISetup.getSb_dashboard().addItemToRightbar( target );
+					}
+				});
 			}
 		}
 		
