@@ -40,4 +40,11 @@ public interface UISWTViewEventListener {
 	 * @since 2.3.0.6
 	 */
 	public boolean eventOccurred(UISWTViewEvent event);
+	
+	public default boolean
+	informOfDuplicates(
+		int		type )
+	{
+		return( false );
+	}
 }
