@@ -531,7 +531,7 @@ ProgressWindow
 		layout.numColumns = 2;
 		shell.setLayout(layout);
 
-		Color bg = Utils.isDarkAppearancePartial()?null:Colors.white;
+		Color bg = ( Utils.isDarkAppearanceNative() || Utils.isDarkAppearancePartial())?null:Colors.white;
 		
 		shell.setBackground( bg );
 		
