@@ -1343,7 +1343,7 @@ SBC_SearchResultsView
 
 					item.setEnabled( results.length > 0 );
 
-					SearchSubsUtils.addMenu( results, menu );
+					SearchSubsUtils.addMenu( null, results, menu );
 
 					new MenuItem(menu, SWT.SEPARATOR );
 
@@ -1386,14 +1386,15 @@ SBC_SearchResultsView
 	filterCheck(
 		SBC_SearchResult 	ds,
 		String 				filter,
-		boolean 			regex)
+		boolean 			regex,
+		boolean				confusable )
 	{
 		if (!isOurContent(ds)){
 
 			return false;
 		}
 
-		return( SearchSubsUtils.filterCheck( ds, filter, regex ));
+		return( SearchSubsUtils.filterCheck( ds, filter, regex, confusable ));
 	}
 
 	@Override
@@ -1844,6 +1845,11 @@ SBC_SearchResultsView
 	{
 		String link = entry.getTorrentLink();
 
+		if ( link == null ){
+			
+			return;
+		}
+		
 		if ( link.startsWith( "chat:" )){
 
 			Utils.launch( link );
