@@ -906,7 +906,7 @@ public class MessageBoxShell
 					Rectangle area = canvas.getClientArea();
 					sp = new GCStringPrinter(e.gc, text, area, true, false, SWT.WRAP
 							| SWT.TOP);
-					sp.setUrlColor(ColorCache.getColor(e.gc.getDevice(), "#0000ff"));
+					sp.setUrlColor(e.gc.getDevice().getSystemColor(SWT.COLOR_LINK_FOREGROUND));
 					if (urlColor != null) {
 						sp.setUrlColor(urlColor);
 					}
