@@ -590,6 +590,13 @@ MainWindowDelayStub
 				public void fix(UIFunctionsSWT uif){ uif.runOnUIThread( ui_type, runnable ); }});
 		}
 
+		@Override
+		public boolean
+		isUIThread()
+		{
+			return( Utils.isSWTThread());
+		}
+		
 		@Override
 		public void
 		refreshLanguage()
