@@ -27,7 +27,7 @@ import com.biglybt.core.torrent.impl.TorrentOpenFileOptions;
 import com.biglybt.core.util.DisplayFormatters;
 import com.biglybt.ui.swt.views.table.TableCellSWT;
 import com.biglybt.ui.swt.views.table.TableCellSWTPaintListener;
-
+import com.biglybt.ui.swt.views.table.utils.TableColumnSWTUtils;
 import com.biglybt.pif.ui.tables.*;
 
 public class TableColumnOTOF_Size
@@ -59,6 +59,7 @@ public class TableColumnOTOF_Size
   	TorrentOpenFileOptions tfi = (TorrentOpenFileOptions) ds;
   	cell.setSortValue(tfi.lSize);
   	cell.setText(DisplayFormatters.formatByteCountToKiBEtc(tfi.lSize));
+  	TableColumnSWTUtils.setSizeAlpha( cell, tfi.lSize );
   }
 
 	@Override
@@ -73,18 +74,18 @@ public class TableColumnOTOF_Size
 
   	Rectangle bounds = cell.getBounds();
 
-		bounds.width = (int) (bounds.width * pct);
-		if (bounds.width > 2) {
-			bounds.x++;
-			bounds.y++;
-			bounds.height -= 2;
-			bounds.width -= 2;
+  	bounds.width = (int) (bounds.width * pct);
+  	if (bounds.width > 2) {
+  		bounds.x++;
+  		bounds.y++;
+  		bounds.height -= 2;
+  		bounds.width -= 2;
   		gc.setBackground(gc.getForeground());
   		int alpha = gc.getAlpha();
   		gc.setAlpha(10);
   		gc.fillRectangle(bounds);
   		gc.setAlpha(alpha);
-		}
+  	}
 	}
 
 	@Override
