@@ -86,6 +86,8 @@ SBC_SubscriptionResultsView
 {
 	public static final String TABLE_SR = "SubscriptionResults";
 
+	private final Object FILTER_KEY = new Object();	// not static as we want separate per view
+	
 	private static boolean columnsAdded = false;
 
 	private static TableViewSWT.ColorRequester colour_requester = ()->1;
@@ -114,6 +116,8 @@ SBC_SubscriptionResultsView
 
 	private Subscription	 			ds;
 	private SubscriptionResultFilter	ds_filter = SubscriptionResultFilter.getTransientFilter();
+	private Runnable 					pFilterUpdater;
+	private long						ds_filter_version = -1;
 	
 	private List<SubscriptionResultFilterable>	last_selected_content = new ArrayList<>();
 
@@ -268,9 +272,9 @@ SBC_SubscriptionResultsView
 
 			cFilters.setLayout( layout );
 
-			Runnable pFilterUpdater = null;
+			pFilterUpdater = null;
 
-			if ( ds != null && ds.isUpdateable()){
+			if ( ds != null ){
 
 				try{
 					Composite pFilters = new Composite(cFilters, SWT.NONE);
@@ -282,6 +286,9 @@ SBC_SubscriptionResultsView
 
 					pFilters.setLayout( layout );
 
+					final Label deplabel = new Label( pFilters, SWT.NONE );
+					deplabel.setLayoutData(new GridData( GridData.FILL_HORIZONTAL ));
+					
 					final Label pflabel = new Label( pFilters, SWT.NONE );
 					pflabel.setLayoutData(new GridData( GridData.FILL_HORIZONTAL ));
 										
@@ -291,26 +298,74 @@ SBC_SubscriptionResultsView
 						public void
 						run()
 						{
-							long kInB = DisplayFormatters.getKinB();
-							long mInB = kInB*kInB;
-
-							long	min_size = Math.max( 0,  ds_filter.getMinSize()/mInB );
-							long	max_size = Math.max( 0,  ds_filter.getMaxSize()/mInB );
-							long	min_seeds = Math.max( 0,  ds_filter.getMinSeeds());
-							long	max_age = Math.max( 0,  ds_filter.getMaxAgeSecs());
-							
-							pflabel.setText(
-								MessageText.getString(
-									"subs.persistent.filters",
-									new String[]{
-										getString( ds_filter.getWithWords()),
-										getString( ds_filter.getWithoutWords()),
-										String.valueOf( min_size ),
-										String.valueOf( max_size )
+							if ( pflabel.isDisposed()){
+								
+								if ( pFilterUpdater == this ){
 									
-									}) +
-								", " + MessageText.getString( "label.min.seeds") + " = " + ( min_seeds ) + 
-								", " + MessageText.getString( "label.max.age") + " = " + (TimeFormatter.format3( max_age, null, true )));
+									pFilterUpdater = null;
+								}
+								
+								return;
+							}
+							
+							List<Subscription> deps = ds_filter.getDependsOn();
+							
+							if ( deps != null && !deps.isEmpty()){
+								
+								String str = "";
+								for ( Subscription dep: deps ){
+									str += (str.isEmpty()?"":"; ") + dep.getName();
+									
+									try{
+										str += " {" + dep.getFilters().getString().replaceAll("&","&&") + "}";
+									}catch( Throwable e ){
+									}
+								}
+								
+								deplabel.setText( MessageText.getString( "subs.inherited.filters" ) + ": " + str );
+								
+								deplabel.setVisible( true );
+								GridData gd = (GridData)deplabel.getLayoutData();
+								if ( gd.widthHint == 0 ){
+									gd.widthHint = gd.heightHint = SWT.DEFAULT;
+									parent.getParent().getParent().layout(true, true);
+								}
+								
+							}else{
+								deplabel.setVisible( false );
+								GridData gd = (GridData)deplabel.getLayoutData();
+								if ( gd.widthHint != 0 ){
+									gd.widthHint = gd.heightHint = 0;
+									parent.getParent().getParent().layout(true, true);
+								}
+							}
+							
+							if ( ds.isUpdateable()){
+								long kInB = DisplayFormatters.getKinB();
+								long mInB = kInB*kInB;
+	
+								long	min_size = Math.max( 0,  ds_filter.getMinSize()/mInB );
+								long	max_size = Math.max( 0,  ds_filter.getMaxSize()/mInB );
+								long	min_seeds = Math.max( 0,  ds_filter.getMinSeeds());
+								long	max_age = Math.max( 0,  ds_filter.getMaxAgeSecs());
+								
+								pflabel.setText(
+									MessageText.getString(
+										"subs.persistent.filters",
+										new String[]{
+											getString( ds_filter.getWithWords()),
+											getString( ds_filter.getWithoutWords()),
+											String.valueOf( min_size ),
+											String.valueOf( max_size )
+										
+										}) +
+									", " + MessageText.getString( "label.min.seeds") + " = " + ( min_seeds ) + 
+									", " + MessageText.getString( "label.max.age") + " = " + (TimeFormatter.format3( max_age, null, true )));
+							}else{
+								pflabel.setVisible( false );
+								GridData gd = (GridData)pflabel.getLayoutData();
+								gd.widthHint = gd.heightHint = 0;
+							}
 						}
 					};
 
@@ -527,30 +582,32 @@ SBC_SubscriptionResultsView
 			spinMaxAge.addListener(SWT.Selection, maxAgeListener );		
 			combMaxAge.addListener(SWT.Selection, maxAgeListener );
 			
-			if ( ds != null && ds.isUpdateable()){
+			if ( ds != null ){
 
-				label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-				label.setLayoutData(new RowData(-1, sepHeight));
-
-				final Runnable					f_pFilterUpdater 	= pFilterUpdater;
-
-				Button save = new Button( vFilters,SWT.PUSH );
-				save.setText( MessageText.getString( "ConfigView.button.save" ));
-				save.addListener(SWT.Selection, new Listener() {
-					@Override
-					public void handleEvent(Event event) {
-
-						try{
-							ds_filter.save();
-
-							f_pFilterUpdater.run();
-
-						}catch( Throwable e ){
-
-							Debug.out( e );
+				if ( ds.isUpdateable() ){
+					label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
+					label.setLayoutData(new RowData(-1, sepHeight));
+	
+					final Runnable					f_pFilterUpdater 	= pFilterUpdater;
+	
+					Button save = new Button( vFilters,SWT.PUSH );
+					save.setText( MessageText.getString( "ConfigView.button.save" ));
+					save.addListener(SWT.Selection, new Listener() {
+						@Override
+						public void handleEvent(Event event) {
+	
+							try{
+								ds_filter.save();
+	
+								f_pFilterUpdater.run();
+	
+							}catch( Throwable e ){
+	
+								Debug.out( e );
+							}
 						}
-					}
-				});
+					});
+				}
 				
 				label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
 				label.setLayoutData(new RowData(-1, sepHeight));
@@ -875,7 +932,14 @@ SBC_SubscriptionResultsView
 				ds.addListener( this );
 				
 				try{
-					ds_filter = ds.getFilters();
+					ds_filter = (SubscriptionResultFilter)ds.getUserData( FILTER_KEY );
+					
+					if ( ds_filter == null ){
+						
+						ds_filter = ds.getFilters();
+						
+						ds.setUserData( FILTER_KEY, ds_filter );
+					}
 					
 				}catch( Throwable e ){
 					
@@ -898,11 +962,13 @@ SBC_SubscriptionResultsView
 	{
 		if ( reason == CR_RESULTS){
 
-			if ( tv_subs_results != null ) {
+			TableViewSWT<SubscriptionResultFilterable> tv = tv_subs_results;
+					
+			if ( tv != null ) {
 
 				reconcileResults( subs );
 
-				tv_subs_results.runForAllRows(
+				tv.runForAllRows(
 					new TableGroupRowRunner() {
 						@Override
 						public void run(TableRowCore row) {
@@ -910,6 +976,16 @@ SBC_SubscriptionResultsView
 						}
 					});
 			}
+		}else if ( reason == CR_METADATA ){
+			
+			if ( pFilterUpdater != null ){
+				
+				Utils.execSWTThread(()->{
+					
+					pFilterUpdater.run();
+				});
+			}
+
 		}
 	}
 
@@ -1025,6 +1101,10 @@ SBC_SubscriptionResultsView
 
 			if ( ds != null ){
 
+					// remove in case already added
+				
+				ds.removeListener( this );
+				
 				ds.addListener( this );
 			}
 		}
@@ -1276,7 +1356,7 @@ SBC_SubscriptionResultsView
 
 					item.setEnabled( results.length > 0 );
 
-					SearchSubsUtils.addMenu( results, menu );
+					SearchSubsUtils.addMenu( ds, results, menu );
 
 					new MenuItem(menu, SWT.SEPARATOR );
 
@@ -1445,9 +1525,36 @@ SBC_SubscriptionResultsView
 	@Override
 	public void
 	updateUI()
-	{
+	{	
 		if ( tv_subs_results != null ){
 
+			SubscriptionResultFilter	rf = ds_filter;
+			
+			if ( rf != null ){
+			
+				long new_v = rf.getDependenciesVersion();
+				
+				long old_v = ds_filter_version;
+				
+				if ( old_v != new_v ){
+					
+					ds_filter_version = new_v;
+				
+					if ( old_v != -1 ){
+						
+						refilter_dispatcher.dispatch();
+						
+						if ( pFilterUpdater != null ){
+							
+							Utils.execSWTThread(()->{
+								
+								pFilterUpdater.run();
+							});
+						}
+					}
+				}
+			}
+			
 			tv_subs_results.refreshTable( false );
 		}
 	}
@@ -1455,16 +1562,17 @@ SBC_SubscriptionResultsView
 	@Override
 	public boolean
 	filterCheck(
-		SubscriptionResultFilterable 		ds,
-		String 						filter,
-		boolean 					regex )
+		SubscriptionResultFilterable 	ds,
+		String 							filter,
+		boolean 						regex,
+		boolean							confusable )
 	{
 		if (!isOurContent(ds)){
 
 			return false;
 		}
 
-		return( SearchSubsUtils.filterCheck( ds, filter, regex ));
+		return( SearchSubsUtils.filterCheck( ds, filter, regex, confusable ));
 	}
 
 	@Override
