@@ -25,10 +25,8 @@ import java.util.regex.Pattern;
 
 import com.biglybt.pif.ui.UIInstance;
 import com.biglybt.ui.common.table.*;
-import com.biglybt.ui.common.table.TableViewFilterCheck.TableViewFilterCheckEx;
 import com.biglybt.ui.swt.columns.subscriptions.*;
 import com.biglybt.ui.swt.components.BubbleTextBox;
-import com.biglybt.ui.swt.components.BufferedLabel;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.KeyEvent;
@@ -44,6 +42,7 @@ import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.util.ByteFormatter;
 import com.biglybt.core.util.Constants;
 import com.biglybt.core.util.Debug;
+import com.biglybt.core.util.GeneralUtils;
 import com.biglybt.core.util.RegExUtil;
 import com.biglybt.pif.PluginInterface;
 import com.biglybt.pif.ui.UIManager;
@@ -66,7 +65,6 @@ import com.biglybt.core.metasearch.Engine;
 import com.biglybt.core.subs.Subscription;
 import com.biglybt.core.subs.SubscriptionManagerFactory;
 import com.biglybt.core.subs.SubscriptionManagerListener;
-import com.biglybt.core.tag.TagFeatureProperties;
 import com.biglybt.core.vuzefile.VuzeFile;
 import com.biglybt.core.vuzefile.VuzeFileComponent;
 import com.biglybt.core.vuzefile.VuzeFileHandler;
@@ -151,7 +149,7 @@ public class SubscriptionsView
 	 * @see com.biglybt.core.subs.SubscriptionManagerListener#subscriptionChanged(com.biglybt.core.subs.Subscription)
 	 */
 	@Override
-	public void subscriptionChanged(Subscription subscription) {
+	public void subscriptionChanged(Subscription subscription, int reason) {
 		if ( !subscription.isSubscribed()){
 			subscriptionRemoved(subscription);
 		}else if ( view.getRow(subscription) == null ){
@@ -333,8 +331,6 @@ public class SubscriptionsView
 		
 		btnAdd.addListener( SWT.Selection, (ev)->{
 			new SubscriptionWizard();
-
-			COConfigurationManager.setParameter( "subscriptions.wizard.shown", true );
 		});
 		
 		BubbleTextBox bubbleTextBox = new BubbleTextBox(topComposite, SWT.BORDER | SWT.SEARCH | SWT.ICON_SEARCH | SWT.ICON_CANCEL | SWT.SINGLE);
@@ -375,6 +371,11 @@ public class SubscriptionsView
 				new ColumnSubscriptionParent(TABLE_ID),
 				new ColumnSubscriptionError(TABLE_ID),
 				new ColumnSubscriptionNewestDate(TABLE_ID),
+				new ColumnSubscriptionDependsOn(TABLE_ID),
+				new ColumnSubscriptionPublic(TABLE_ID),
+				new ColumnSubscriptionUpdatePeriod(TABLE_ID),
+				new ColumnSubscriptionProtocol(TABLE_ID),
+				new ColumnSubscriptionNextUpdate(TABLE_ID),
 
 		};
 
@@ -493,8 +494,13 @@ public class SubscriptionsView
 			}
 
 			@Override
-			public void selected(TableRowCore[] rows) {
-				rows = view.getSelectedRows();
+			public void 
+			selectionChanged(
+				TableRowCore[] selected_rows, 
+				TableRowCore[] deselected_rows )
+			{
+				TableRowCore[] rows = view.getSelectedRows();
+				
 				ISelectedContent[] sels = new ISelectedContent[rows.length];
 
 				java.util.List<Subscription> subs = new ArrayList<>();
@@ -644,10 +650,21 @@ public class SubscriptionsView
 	filterCheck(
 		Subscription 	ds, 
 		String 			filter, 
-		boolean 		regex)
+		boolean 		regex,
+		boolean			confusable )
 	{
+		if ( confusable ){
+		
+			filter = GeneralUtils.getConfusableEquivalent( filter, true );
+		}
+		
 		String name = ds.getName();
-				
+
+		if ( confusable ){
+		
+			name = GeneralUtils.getConfusableEquivalent( name, false );
+		}
+		
 		String s = regex ? filter : RegExUtil.splitAndQuote( filter, "\\s*[|;]\\s*" );
 
 		boolean	match_result = true;
