@@ -58,7 +58,13 @@ public class ColorCache
 		"COLOR_INFO_BACKGROUND",
 		"COLOR_TITLE_FOREGROUND",
 		"COLOR_TITLE_BACKGROUND",
+		"COLOR_TITLE_BACKGROUND_GRADIENT",
+		"COLOR_TITLE_INACTIVE_FOREGROUND",
+		"COLOR_TITLE_INACTIVE_BACKGROUND",
+		"COLOR_TITLE_INACTIVE_BACKGROUND_GRADIENT",
+		"COLOR_LINK_FOREGROUND",
 	};
+	
 	private static TimerEventPeriodic timerColorCacheChecker;
 	
 	private static boolean forceNoColor;
