@@ -166,9 +166,20 @@ public class FontUtils
 		if (destroyBaseFont) {
 			baseFont.dispose();
 		}
-		// new font might still be bigger than requested height due to Fonts being fonts
-		return runAgain ? getFontWithHeight(font, heightInPixels, style, false)
-				: font;
+			// new font might still be bigger than requested height due to Fonts being fonts
+		
+		if ( runAgain ){
+	
+			Font font2 = getFontWithHeight(font, heightInPixels, style, false);
+			
+			font.dispose();
+			
+			return( font2 );
+			
+		}else{
+			
+			return( font );
+		}
 	}
 
 		// Used by azemp plugin
@@ -482,4 +493,25 @@ public class FontUtils
 		}
 		return width;
 	}
+	
+	public static void
+	setBold(
+		Control	control )
+	{
+		Font existing = control.getFont();
+		
+		if ( existing == null ){
+			
+			Debug.out( "no existing font" );
+			
+			return;
+			
+		}else{
+			Font f = cache( getFontWithStyle( existing, SWT.BOLD, 1.0f ));
+		
+			control.setFont( f );
+			
+			control.addListener( SWT.Dispose, (ev)->{ uncache( f ); });
+		}
+	}
 }
