@@ -23,41 +23,41 @@
 package com.biglybt.ui.swt.utils;
 
 import java.lang.reflect.Field;
+import java.util.Arrays;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import com.biglybt.core.Core;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.program.Program;
 import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.MenuItem;
-import com.biglybt.core.global.GlobalManager;
-import com.biglybt.core.history.DownloadHistoryManager;
 import com.biglybt.core.internat.MessageText;
+import com.biglybt.core.subs.Subscription;
+import com.biglybt.core.subs.SubscriptionManagerFactory;
 import com.biglybt.core.subs.util.SearchSubsResultBase;
+import com.biglybt.core.tag.Tag;
 import com.biglybt.core.util.Base32;
 import com.biglybt.core.util.ByteFormatter;
-import com.biglybt.core.util.HashWrapper;
-import com.biglybt.core.util.RandomUtils;
+import com.biglybt.core.util.GeneralUtils;
 import com.biglybt.core.util.RegExUtil;
-import com.biglybt.core.util.SystemTime;
 import com.biglybt.core.util.UrlUtils;
-import com.biglybt.pif.download.DownloadManager;
+import com.biglybt.pif.ui.menus.MenuManager;
 import com.biglybt.pifimpl.local.PluginInitializer;
+import com.biglybt.ui.common.util.MenuItemManager;
+import com.biglybt.ui.swt.MenuBuildUtils;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.mainwindow.ClipboardCopy;
+import com.biglybt.ui.swt.mainwindow.MenuFactory;
 
-import com.biglybt.core.CoreFactory;
-import com.biglybt.core.download.DownloadManagerState;
 
 public class
 SearchSubsUtils
 {
 	public static boolean
 	addMenu(
-		final SearchSubsResultBase	result,
+		SearchSubsResultBase		result,
 		Menu						menu )
 	{
 		final byte[] hash = result.getHash();
@@ -111,17 +111,32 @@ SearchSubsUtils
 				launchURL(URL);
 			}
 		});
+	
+		com.biglybt.pif.ui.menus.MenuItem[] items = MenuItemManager.getInstance().getAllAsArray(
+				MenuManager.MENU_SUBSCRIPTION_RESULT_CONTEXT);
 
+		if (items.length > 0) {
+			MenuFactory.addSeparatorMenuItem(menu);
+
+			// TODO: Don't send Tag.. send a yet-to-be-created plugin interface version of Tag
+			MenuBuildUtils.addPluginMenuItems(items, menu, true, true,
+					new MenuBuildUtils.MenuItemPluginMenuControllerImpl(new SearchSubsResultBase[]{result}));
+		}
+		
+		
 		return( true );
 	}
 
 	public static void
 	addMenu(
-		final SearchSubsResultBase[]	results,
-		Menu							menu )
+		Subscription				subs_maybe_null,
+		SearchSubsResultBase[]		results,
+		Menu						menu )
 	{
-		boolean	has_hash = false;
-
+		boolean	has_hash 	= false;
+		boolean	all_read	= true;
+		boolean	all_unread	= true;
+		
 		for ( SearchSubsResultBase result: results ){
 
 			byte[] hash = result.getHash();
@@ -129,8 +144,12 @@ SearchSubsUtils
 			if ( hash != null ){
 
 				has_hash = true;
-
-				break;
+			}
+			
+			if ( result.getRead()){
+				all_unread = false;
+			}else{
+				all_read = false;
 			}
 		}
 
@@ -168,6 +187,97 @@ SearchSubsUtils
 		});
 
 		item.setEnabled( has_hash );
+		
+		new MenuItem(menu, SWT.SEPARATOR);
+		
+		item = new MenuItem(menu, SWT.PUSH);
+		item.setText(MessageText.getString("menu.mark.read"));
+		item.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+
+				if ( subs_maybe_null == null || results.length == 1 ){
+					for ( SearchSubsResultBase result: results ){
+	
+						result.setRead( true );
+					}
+				}else{
+					String[]	ids 	= new String[results.length];
+					boolean[]	read	= new boolean[ids.length];
+					
+					Arrays.fill( read, true );
+					
+					for ( int i=0;i<ids.length;i++){
+						ids[i] = results[i].getID();
+					}
+					
+					subs_maybe_null.getHistory().markResults( ids, read );
+				}
+			}
+		});
+		
+		item.setEnabled( !all_read );
+		
+		item = new MenuItem(menu, SWT.PUSH);
+		item.setText(MessageText.getString("menu.mark.read.in.all"));
+		item.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+
+				if ( subs_maybe_null == null || results.length == 1 ){
+					for ( SearchSubsResultBase result: results ){
+	
+						result.setRead( true );
+					}
+				}else{
+					String[]	ids 	= new String[results.length];
+					boolean[]	read	= new boolean[ids.length];
+					
+					Arrays.fill( read, true );
+					
+					for ( int i=0;i<ids.length;i++){
+						ids[i] = results[i].getID();
+					}
+					
+					subs_maybe_null.getHistory().markResults( ids, read );
+				}
+				Utils.getOffOfSWTThread(()->{
+					SubscriptionManagerFactory.getSingleton().markReadInAllSubscriptions( results );
+				});
+			}
+		});
+		
+		item.setEnabled( !all_read );
+		
+		
+		
+		item = new MenuItem(menu, SWT.PUSH);
+		item.setText(MessageText.getString("menu.mark.unread"));
+		item.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+
+				if ( subs_maybe_null == null || results.length == 1 ){
+					for ( SearchSubsResultBase result: results ){
+	
+						result.setRead( false );
+					}
+				}else{
+					String[]	ids 	= new String[results.length];
+					boolean[]	read	= new boolean[ids.length];
+					
+					Arrays.fill( read, false );
+					
+					for ( int i=0;i<ids.length;i++){
+						ids[i] = results[i].getID();
+					}
+					
+					subs_maybe_null.getHistory().markResults( ids, read );
+				}
+			}
+		});
+		
+		item.setEnabled( !all_unread );
 	}
 
 	private static void launchURL(String s) {
@@ -193,13 +303,19 @@ SearchSubsUtils
 	filterCheck(
 		SearchSubsResultBase 	ds,
 		String 					filter,
-		boolean 				regex)
+		boolean 				regex,
+		boolean					confusable )
 	{
 		if ( filter == null || filter.length() == 0 ){
 
 			return( true );
 		}
 
+		if ( confusable ){
+		
+			filter = GeneralUtils.getConfusableEquivalent( filter, true );
+		}
+		
 		try{
 			boolean	hash_filter = filter.startsWith( "t:" );
 
@@ -246,6 +362,11 @@ SearchSubsUtils
 
 				String name = ds.getName();
 
+				if ( confusable ){
+				
+					name = GeneralUtils.getConfusableEquivalent (name, false );
+				}
+				
 				return( pattern.matcher(name).find() == match_result );
 			}
 
@@ -254,87 +375,4 @@ SearchSubsUtils
 			return true;
 		}
 	}
-
-	private static final Object	HS_KEY = new Object();
-
-	public static final int HS_NONE			= 0;
-	public static final int HS_LIBRARY		= 1;
-	public static final int HS_ARCHIVE		= 2;
-	public static final int HS_HISTORY		= 3;
-	public static final int HS_UNKNOWN		= 4;
-	public static final int HS_FETCHING		= 5;
-
-	private static GlobalManager 			gm;
-	private static DownloadManager			dm;
-	private static DownloadHistoryManager	hm;
-
-	public static int
-	getHashStatus(
-		SearchSubsResultBase	result )
-	{
-		if ( result == null ){
-
-			return( HS_NONE );
-		}
-
-		byte[] hash = result.getHash();
-
-		if ( hash == null || hash.length != 20 ){
-
-			return( HS_UNKNOWN );
-		}
-
-		long	now = SystemTime.getMonotonousTime();
-
-		Object[] entry = (Object[])result.getUserData( HS_KEY );
-
-		if ( entry != null ){
-
-			long time = (Long)entry[0];
-
-			if ( now - time < 10*1000 ){
-
-				return((Integer)entry[1] );
-			}
-		}
-
-		synchronized( HS_KEY ){
-
-			if ( gm == null ){
-
-				Core core = CoreFactory.getSingleton();
-
-				gm = core.getGlobalManager();
-				dm = core.getPluginManager().getDefaultPluginInterface().getDownloadManager();
-				hm = (DownloadHistoryManager)gm.getDownloadHistoryManager();
-			}
-		}
-
-		int hs_result;
-
-		com.biglybt.core.download.DownloadManager dl = gm.getDownloadManager(new HashWrapper(hash));
-		if ( dl != null ){
-
-			DownloadManagerState downloadState = dl.getDownloadState();
-			hs_result = downloadState != null
-					&& downloadState.getFlag(DownloadManagerState.FLAG_METADATA_DOWNLOAD)
-							? HS_FETCHING : HS_LIBRARY;
-
-		}else if (dm.lookupDownloadStub( hash ) != null ){
-
-			hs_result = HS_ARCHIVE;
-
-		}else if ( hm.getDates(hash) != null ){
-
-			hs_result = HS_HISTORY;
-
-		}else{
-
-			hs_result = HS_NONE;
-		}
-
-		result.setUserData( HS_KEY, new Object[]{ now + RandomUtils.nextInt( 2500 ), hs_result });
-
-		return( hs_result );
-	}
 }
