@@ -270,12 +270,21 @@ public class SBC_AllTrackersView
 						new ColumnAllTrackersRemovable(column);
 					}
 				});
+		
+		tableManager.registerColumn(AllTrackersViewEntry.class, ColumnAllTrackersTorrentCount.COLUMN_ID,
+				new TableColumnCreationListener() {
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnAllTrackersTorrentCount(column);
+					}
+				});
 
 		
 		tableManager.setDefaultColumnNames(TABLE_NAME,
 				new String[] {
 					ColumnAllTrackersTracker.COLUMN_ID,
 					ColumnAllTrackersStatus.COLUMN_ID,
+					ColumnAllTrackersTorrentCount.COLUMN_ID,
 					ColumnAllTrackersLastGoodDate.COLUMN_ID,
 					ColumnAllTrackersLastBadDate.COLUMN_ID,
 					ColumnAllTrackersBadSinceDate.COLUMN_ID,
@@ -1632,9 +1641,15 @@ public class SBC_AllTrackersView
 	public boolean
 	filterCheck(
 		AllTrackersViewEntry 	ds,
-		String 				filter,
-		boolean 			regex)
+		String 					filter,
+		boolean 				regex,
+		boolean					confusable )
 	{
+		if ( confusable ){
+			
+			return( false );
+		}
+		
 		AllTrackersTracker tracker = ds.getTracker();
 		
 		String name = tracker.getTrackerName();
@@ -1825,6 +1840,11 @@ public class SBC_AllTrackersView
 			return(tracker.getPrivatePercentage());
 		}
 		
+		@Override
+		public int getTorrentCount(){
+			return( tracker.getTorrentCount());
+		}
+		
 		public Tag
 		getTag()
 		{
