@@ -35,6 +35,7 @@ import org.eclipse.swt.widgets.*;
 import com.biglybt.core.CoreFactory;
 import com.biglybt.core.config.COConfigurationManager;
 import com.biglybt.core.download.DownloadManager;
+import com.biglybt.core.util.GeneralUtils;
 import com.biglybt.core.util.RegExUtil;
 import com.biglybt.pifimpl.local.PluginCoreUtils;
 import com.biglybt.pifimpl.local.PluginInitializer;
@@ -741,8 +742,14 @@ public class SBC_ArchivedDownloadsView
 	filterCheck(
 		DownloadStub 	ds,
 		String 			filter,
-		boolean 		regex)
+		boolean 		regex,
+		boolean			confusable )
 	{
+		if ( confusable ){
+		
+			filter = GeneralUtils.getConfusableEquivalent(filter,true);
+		}
+		
 		boolean do_files = filter.toLowerCase( Locale.US ).startsWith( "f:" );
 		
 		if ( do_files ){
@@ -783,6 +790,11 @@ public class SBC_ArchivedDownloadsView
 
 				String name = file.getFile().getName();
 
+				if ( confusable ){
+				
+					name = GeneralUtils.getConfusableEquivalent( name, false );
+				}
+				
 				if ( pattern.matcher( name ).find()){
 
 					result = match_result;
@@ -807,6 +819,11 @@ public class SBC_ArchivedDownloadsView
 
 			String name = ds.getName();
 
+			if ( confusable ){
+			
+				name = GeneralUtils.getConfusableEquivalent( name, false );
+			}
+			
 			Pattern pattern = RegExUtil.getCachedPattern( "archiveview:search", expr, Pattern.CASE_INSENSITIVE | Pattern.UNICODE_CASE );
 
 			return( pattern.matcher(name).find() == match_result );
