@@ -52,6 +52,7 @@ import com.biglybt.core.history.DownloadHistoryManager;
 import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.util.Base32;
 import com.biglybt.core.util.ByteFormatter;
+import com.biglybt.core.util.GeneralUtils;
 import com.biglybt.core.util.HashWrapper;
 import com.biglybt.core.util.UrlUtils;
 import com.biglybt.pif.ui.UIPluginViewToolBarListener;
@@ -797,8 +798,14 @@ public class SBC_DownloadHistoryView
 	filterCheck(
 		DownloadHistory 	ds,
 		String 				filter,
-		boolean 			regex)
+		boolean 			regex,
+		boolean				confusable )
 	{
+		if ( confusable ){
+		
+			filter = GeneralUtils.getConfusableEquivalent(filter,true);
+		}
+		
 		Object o_name;
 
 		if ( filter.startsWith( "t:" )){
@@ -852,7 +859,14 @@ public class SBC_DownloadHistoryView
 
 		if ( o_name instanceof String ){
 
-			bOurs = pattern.matcher((String)o_name).find() == match_result;
+			String name = (String)o_name;
+			
+			if ( confusable ){
+			
+				name = GeneralUtils.getConfusableEquivalent( name, false );
+			}
+			
+			bOurs = pattern.matcher( name ).find() == match_result;
 
 		}else{
 
@@ -864,6 +878,11 @@ public class SBC_DownloadHistoryView
 
 			for ( String name: names ){
 
+				if ( confusable ){
+				
+					name = GeneralUtils.getConfusableEquivalent( name, false );
+				}
+				
 				if ( pattern.matcher( name ).find()){
 
 					bOurs = match_result;
