@@ -141,31 +141,27 @@ public class SBC_LibraryTableView
 				"library-filter", soParent.getParent());
 		BubbleTextBox txtFilter = soFilter == null ? null : soFilter.getBubbleTextBox();
 
-		SWTSkinObjectContainer soCats = (SWTSkinObjectContainer) skin.getSkinObject(
-				"library-categories", soParent.getParent());
-		Composite cCats = soCats == null ? null : soCats.getComposite();
-
 		if (useBigTable) {
 			if (torrentFilterMode == SBC_LibraryView.TORRENTS_COMPLETE
 					|| torrentFilterMode == SBC_LibraryView.TORRENTS_INCOMPLETE
 					|| torrentFilterMode == SBC_LibraryView.TORRENTS_UNOPENED) {
 
-				swtViewListener = torrentView = new MyTorrentsView_Big(core, torrentFilterMode, initialDataSource, getColumnsSupport(), txtFilter, cCats);
+				swtViewListener = torrentView = new MyTorrentsView_Big(core, torrentFilterMode, initialDataSource, getColumnsSupport(), txtFilter);
 
 			} else {
-				swtViewListener = torrentView = new MyTorrentsView_Big(core, torrentFilterMode, initialDataSource, getColumnsSupport(), txtFilter, cCats);
+				swtViewListener = torrentView = new MyTorrentsView_Big(core, torrentFilterMode, initialDataSource, getColumnsSupport(), txtFilter);
 			}
 
 		} else {
 			String tableID = SB_Transfers.getTableIdFromFilterMode(	torrentFilterMode, false, initialDataSource );
 			if (torrentFilterMode == SBC_LibraryView.TORRENTS_COMPLETE) {
-				swtViewListener = torrentView = new MyTorrentsView(core, tableID, true, getColumnsSupport(), txtFilter, cCats,true);
+				swtViewListener = torrentView = new MyTorrentsView(core, tableID, true, getColumnsSupport(), txtFilter, true);
 
 			} else if (torrentFilterMode == SBC_LibraryView.TORRENTS_INCOMPLETE) {
-				swtViewListener = torrentView = new MyTorrentsView(core, tableID, false, getColumnsSupport(), txtFilter, cCats,true);
+				swtViewListener = torrentView = new MyTorrentsView(core, tableID, false, getColumnsSupport(), txtFilter, true);
 
 			} else if (torrentFilterMode == SBC_LibraryView.TORRENTS_UNOPENED) {
-				swtViewListener = torrentView = new MyTorrentsView(core, tableID, true, getColumnsSupport(), txtFilter,	cCats, true){
+				swtViewListener = torrentView = new MyTorrentsView(core, tableID, true, getColumnsSupport(), txtFilter,	 true){
 					@Override
 					public boolean isOurDownloadManager(DownloadManager dm) {
 						if (PlatformTorrentUtils.getHasBeenOpened(dm)) {
@@ -177,10 +173,10 @@ public class SBC_LibraryTableView
 			} else {
 				if ( Utils.getBaseViewID( tableID ).equals( TableManager.TABLE_MYTORRENTS_ALL_SMALL )){
 					
-					swtViewListener = torrentView = new MyTorrentsView_Small( core, torrentFilterMode, initialDataSource, getColumnsSupport(), txtFilter, cCats );
+					swtViewListener = torrentView = new MyTorrentsView_Small( core, torrentFilterMode, initialDataSource, getColumnsSupport(), txtFilter );
 					
 				}else{
-					swtViewListener = new MyTorrentsSuperView(txtFilter, cCats, initialDataSource ) {
+					swtViewListener = new MyTorrentsSuperView(txtFilter, initialDataSource ) {
 						@Override
 						public void initializeDone() {
 							MyTorrentsView seedingview = getSeedingview();
@@ -345,7 +341,7 @@ public class SBC_LibraryTableView
 				ManagerUtils.open(dm, openMode);
 				return;
 			}
-		}else if (mode.equals("3") || mode.equals("4")){
+		}else if (mode.equals("3") || mode.equals("4") || mode.equals( "7" )){
 
 			// Launch
 			DiskManagerFileInfo file = DataSourceUtils.getFileInfo(ds);
@@ -362,7 +358,19 @@ public class SBC_LibraryTableView
 			}
 			DownloadManager dm = DataSourceUtils.getDM(ds);
 			if (dm != null) {
+				if ( mode.equals( "7" )){
+					DiskManagerFileInfo best = PlayUtils.getBestPlayableFile( dm );
+					
+					if ( best != null ){
+						
+						TorrentUtil.runDataSources(new Object[]{ best });
+						
+						return;
+					}
+				}
+					
 				TorrentUtil.runDataSources(new Object[]{ dm });
+				
 				return;
 			}
 		}else if (mode.equals("5")) {
