@@ -34,6 +34,8 @@ import org.eclipse.swt.widgets.*;
 
 import com.biglybt.core.category.Category;
 import com.biglybt.core.config.COConfigurationManager;
+import com.biglybt.core.config.ConfigKeys;
+import com.biglybt.core.config.ParameterListener;
 import com.biglybt.core.download.DownloadManager;
 import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.tag.*;
@@ -45,6 +47,8 @@ import com.biglybt.ui.common.table.*;
 import com.biglybt.ui.common.table.impl.TableColumnManager;
 import com.biglybt.ui.common.table.impl.TableViewImpl;
 import com.biglybt.ui.common.updater.UIUpdatable;
+import com.biglybt.ui.config.ConfigSectionInterfaceTags;
+import com.biglybt.ui.mdi.MultipleDocumentInterface;
 import com.biglybt.ui.selectedcontent.SelectedContentManager;
 import com.biglybt.ui.swt.Messages;
 import com.biglybt.ui.swt.SimpleTextEntryWindow;
@@ -65,7 +69,6 @@ import com.biglybt.ui.swt.views.table.TableViewSWTMenuFillListener;
 import com.biglybt.ui.swt.views.table.impl.TableViewFactory;
 import com.biglybt.ui.swt.views.table.impl.TableViewSWT_TabsCommon;
 import com.biglybt.ui.swt.views.utils.TagUIUtils;
-
 import com.biglybt.pif.ui.UIInputReceiver;
 import com.biglybt.pif.ui.UIInputReceiverListener;
 import com.biglybt.pif.ui.UIPluginViewToolBarListener;
@@ -81,7 +84,7 @@ import com.biglybt.pif.ui.toolbar.UIToolBarItem;
 public class SBC_TagsOverview
 	extends SkinView
 	implements UIUpdatable, UIPluginViewToolBarListener, TableViewFilterCheck<Tag>, TagManagerListener, TagTypeListener,
-	TableViewSWTMenuFillListener, TableSelectionListener, KeyListener {
+	TableViewSWTMenuFillListener, TableSelectionListener, KeyListener, ParameterListener {
 
 	private static final String TABLE_TAGS = "TagsView";
 	// TODO: This should be com.biglybt.pif.tag.Tag but we'd have to
@@ -98,6 +101,27 @@ public class SBC_TagsOverview
 
 	private Object datasource;
 
+	private boolean show_swarm_tags;
+	
+	public
+	SBC_TagsOverview()
+	{
+		COConfigurationManager.addAndFireParameterListener( ConfigKeys.Tag.BCFG_TAG_SHOW_SWARM_TAGS_IN_OVERVIEW, this );
+	}
+	
+	@Override
+	public void 
+	parameterChanged(
+		String parameterName)
+	{
+		show_swarm_tags = COConfigurationManager.getBooleanParameter(parameterName);
+		
+		if ( tv != null ){
+			
+			tv.refilter();
+		}
+	}
+	
 	// @see com.biglybt.pif.ui.toolbar.UIToolBarActivationListener#toolBarItemActivated(ToolBarItem, long, java.lang.Object)
 	@Override
 	public boolean toolBarItemActivated(ToolBarItem item, long activationType,
@@ -198,6 +222,30 @@ public class SBC_TagsOverview
 	public Object skinObjectInitialShow(SWTSkinObject skinObject, Object params) {
 		initColumns();
 
+		SWTSkinObjectContainer	soTopArea 	= (SWTSkinObjectContainer)getSkinObject("tag-top-area");
+		SWTSkinObjectText	 	soTitle 	= (SWTSkinObjectText)getSkinObject("title");
+		
+		for (Control comp: new Control[]{ soTopArea.getComposite(), soTitle.getControl()}){
+			
+			Menu menu = new Menu(comp);
+			comp.setMenu( menu );
+			
+			MenuItem mi = new MenuItem( menu, SWT.PUSH );
+	
+			mi.setText( MessageText.getString( "menu.tag.options"));
+	
+			mi.addListener( SWT.Selection, (ev)->{
+				UIFunctions uif = UIFunctionsManager.getUIFunctions();
+	
+				if ( uif != null ){
+	
+					uif.getMDI().showEntryByID(
+							MultipleDocumentInterface.SIDEBAR_SECTION_CONFIG,
+							ConfigSectionInterfaceTags.SECTION_ID );
+				}
+			});
+		}
+		
 		SWTSkinObjectButton soAddTagButton = (SWTSkinObjectButton) getSkinObject("add-tag");
 		if (soAddTagButton != null) {
 			soAddTagButton.addSelectionListener(new ButtonListenerAdapter() {
@@ -616,6 +664,8 @@ public class SBC_TagsOverview
 			}
 		}
 
+		COConfigurationManager.removeParameterListener( ConfigKeys.Tag.BCFG_TAG_SHOW_SWARM_TAGS_IN_OVERVIEW, this );
+		
 		return super.skinObjectDestroyed(skinObject, params);
 	}
 
@@ -1146,8 +1196,21 @@ public class SBC_TagsOverview
 	filterCheck(
 		Tag 		tag, 
 		String 		filter, 
-		boolean 	regex ) 
+		boolean 	regex,
+		boolean		confusable )
 	{
+		if ( confusable ){
+			
+			return( false );
+		}
+		
+		int tt = tag.getTagType().getTagType();
+		
+		if ( tt == TagType.TT_SWARM_TAG && !show_swarm_tags){
+			
+			return( false );
+		}
+		
 		String name;
 		
 		if ( filter.startsWith( "g:" )){
