@@ -22,8 +22,11 @@ package com.biglybt.ui.swt.views.skin;
 import java.util.*;
 
 import com.biglybt.core.CoreFactory;
+import com.biglybt.ui.UIFunctions;
+import com.biglybt.ui.UIFunctionsManager;
 import com.biglybt.ui.common.ToolBarItem;
 import com.biglybt.ui.common.table.TableView;
+import com.biglybt.ui.mdi.MultipleDocumentInterface;
 import com.biglybt.ui.selectedcontent.ISelectedContent;
 import com.biglybt.ui.selectedcontent.ISelectedVuzeFileContent;
 import com.biglybt.ui.selectedcontent.SelectedContentListener;
@@ -35,11 +38,14 @@ import com.biglybt.ui.swt.skin.SWTSkinObject;
 import com.biglybt.ui.swt.skin.SWTSkinObjectContainer;
 import com.biglybt.ui.swt.skin.SWTSkinObjectText;
 import com.biglybt.ui.swt.utils.SWTRunnable;
+import com.biglybt.ui.swt.views.configsections.ConfigSectionInterfaceDisplaySWT;
+
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.dnd.Clipboard;
 import org.eclipse.swt.dnd.TextTransfer;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
+import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 
 import com.biglybt.core.config.COConfigurationManager;
@@ -48,6 +54,7 @@ import com.biglybt.core.disk.DiskManagerFileInfo;
 import com.biglybt.core.download.DownloadManager;
 import com.biglybt.core.download.DownloadManagerListener;
 import com.biglybt.core.global.GlobalManager;
+import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.util.AERunnable;
 import com.biglybt.core.util.AERunnableBoolean;
 import com.biglybt.core.util.Debug;
@@ -67,8 +74,12 @@ import com.biglybt.ui.swt.mdi.MultipleDocumentInterfaceSWT;
 import com.biglybt.ui.swt.skin.SWTSkinButtonUtility.ButtonListenerAdapter;
 import com.biglybt.ui.swt.toolbar.ToolBarItemSO;
 import com.biglybt.util.DLReferals;
+import com.biglybt.util.JSONUtils;
 import com.biglybt.util.PlayUtils;
 import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Menu;
+import org.eclipse.swt.widgets.MenuItem;
+import org.json.simple.JSONObject;
 
 /**
  * @author TuxPaper
@@ -114,10 +125,10 @@ public class ToolBarView
 		return base;
 	}
 
-	// @see SkinView#showSupport(SWTSkinObject, java.lang.Object)
 	@Override
-	public Object skinObjectInitialShow(SWTSkinObject skinObject, Object params) {
-		
+	public Object 
+	skinObjectInitialShow(SWTSkinObject skinObject, Object params) {
+			
 		boolean uiClassic = COConfigurationManager.getStringParameter("ui").equals( "az2");
 
 		if (uiClassic && !"global-toolbar".equals(skinObject.getViewID())) {
@@ -306,7 +317,11 @@ public class ToolBarView
 					skin.constructionEnd();
 				}
 				
-				Utils.relayout( soMain.getControl());
+				Composite comp = (Composite)soMain.getControl();
+				
+				addMenus( comp );
+				
+				Utils.relayout( comp );
 				
 					// record built state
 				
@@ -328,6 +343,50 @@ public class ToolBarView
 				}
 			});
 	}
+	private void
+	addMenus(
+		Composite comp )
+	{
+		for ( Control kid: comp.getChildren()){
+			
+			Menu menu = kid.getMenu();
+			
+			if ( menu != null ){
+				
+				menu.dispose();
+			}
+			
+			menu = new Menu( kid );
+					
+			kid.setMenu( menu );
+			
+			MenuItem mi = new MenuItem( menu, SWT.PUSH );
+			
+			mi.setText( MessageText.getString( "menu.toolbar.options"));
+			
+			mi.addListener( SWT.Selection, (ev)->{
+				UIFunctions uif = UIFunctionsManager.getUIFunctions();
+
+				if ( uif != null ){
+
+					JSONObject args = new JSONObject();
+
+					args.put( "select", ConfigSectionInterfaceDisplaySWT.REFID_SECTION_TOOLBAR);
+					
+					String args_str = JSONUtils.encodeToJSON( args );
+					
+					uif.getMDI().showEntryByID(
+							MultipleDocumentInterface.SIDEBAR_SECTION_CONFIG,
+							ConfigSectionInterfaceDisplaySWT.SECTION_ID + args_str );
+				}
+			});
+			
+			if ( kid instanceof Composite ){
+				
+				addMenus((Composite)kid);
+			}
+		}
+	}
 	
 	private void setupToolBarItems(boolean uiClassic) {
 		ToolBarItem item;
@@ -565,7 +624,7 @@ public class ToolBarView
 			public void toolBarItemActivated_OffSWT(ToolBarItem item,
 					long activationType, Object datasource) {
 				ISelectedContent[] selected = SelectedContentManager.getCurrentlySelectedContent();
-				TorrentUtil.queueDataSources(selected,false,activationType == ACTIVATIONTYPE_HELD);
+				TorrentUtil.queueDataSources(selected,activationType == ACTIVATIONTYPE_HELD);
 			}
 		});
 		
@@ -634,7 +693,8 @@ public class ToolBarView
 	}
 	
 	@Override
-	public void currentlySelectedContentChanged(
+	public void 
+	currentlySelectedContentChanged(
 			ISelectedContent[] currentContent, String viewID) {
 		//System.err.println("currentlySelectedContentChanged " + viewID + ";" + currentContent + ";" + getMainSkinObject() + this + " via " + Debug.getCompressedStackTrace());
 		refreshCoreToolBarItems();
@@ -644,44 +704,58 @@ public class ToolBarView
 		}
 	}
 
-	// @see SkinView#skinObjectShown(SWTSkinObject, java.lang.Object)
 	@Override
-	public Object skinObjectShown(SWTSkinObject skinObject, Object params) {
+	public Object 
+	skinObjectShown(SWTSkinObject skinObject, Object params) {
 
 		if (showCalled) {
 			return null;
 		}
+				
 		showCalled = true;
 
 		Object object = super.skinObjectShown(skinObject, params);
 
-  	ToolBarItem[] allToolBarItems = tbm.getAllSWTToolBarItems();
-  	for (int i = 0; i < allToolBarItems.length; i++) {
-  		ToolBarItem toolBarItem = allToolBarItems[i];
-  		toolBarItem.addToolBarItemListener(this);
-  		uiFieldChanged(toolBarItem);
-  	}
-
-
-		SelectedContentManager.addCurrentlySelectedContentListener(this);
+		addActiveListeners();
+		
 		return object;
 	}
 
-	// @see SkinView#skinObjectHidden(SWTSkinObject, java.lang.Object)
 	@Override
-	public Object skinObjectHidden(SWTSkinObject skinObject, Object params) {
+	public Object 
+	skinObjectHidden(SWTSkinObject skinObject, Object params) {
 		showCalled = false;
-		SelectedContentManager.removeCurrentlySelectedContentListener(this);
 
-  	ToolBarItem[] allToolBarItems = tbm.getAllSWTToolBarItems();
-  	for (int i = 0; i < allToolBarItems.length; i++) {
-  		ToolBarItem toolBarItem = allToolBarItems[i];
-  		toolBarItem.removeToolBarItemListener(this);
-  	}
+		removeActiveListeners();
 
 		return super.skinObjectHidden(skinObject, params);
 	}
 
+	private void
+	addActiveListeners()
+	{
+		ToolBarItem[] allToolBarItems = tbm.getAllSWTToolBarItems();
+		for (int i = 0; i < allToolBarItems.length; i++) {
+			ToolBarItem toolBarItem = allToolBarItems[i];
+			toolBarItem.addToolBarItemListener(this);
+			uiFieldChanged(toolBarItem);
+		}
+
+		SelectedContentManager.addCurrentlySelectedContentListener(this);
+	}
+	
+	private void
+	removeActiveListeners()
+	{
+		SelectedContentManager.removeCurrentlySelectedContentListener(this);
+
+		ToolBarItem[] allToolBarItems = tbm.getAllSWTToolBarItems();
+		for (int i = 0; i < allToolBarItems.length; i++) {
+			ToolBarItem toolBarItem = allToolBarItems[i];
+			toolBarItem.removeToolBarItemListener(this);
+		}
+	}
+	
 	private void
 	removeItemListeners()
 	{
@@ -692,13 +766,16 @@ public class ToolBarView
 		COConfigurationManager.removeParameterListener( "IconBar.start.stop.separate", this );
 	}
 	
-	// @see SkinView#skinObjectDestroyed(SWTSkinObject, java.lang.Object)
 	@Override
-	public Object skinObjectDestroyed(SWTSkinObject skinObject, Object params) {
+	public Object 
+	skinObjectDestroyed(SWTSkinObject skinObject, Object params) {
+				
 		tbm.removeListener(this);
 
 		removeItemListeners();
 		
+		removeActiveListeners();
+		
 		COConfigurationManager.removeParameterListener( "IconBar.enabled", this );
 		
 		return super.skinObjectDestroyed(skinObject, params);
@@ -980,7 +1057,7 @@ public class ToolBarView
 			UIToolBarItem stopItem = tbm.getToolBarItem("stop");
 			
 			if ( stopItem != null ){
-				stopItem.setTextID( allFiles? "iconBar.stopFiles" : "iconBar.start" );
+				stopItem.setTextID( allFiles? "iconBar.stopFiles" : "iconBar.stop" );
 			}
 		
 			UIToolBarItem ssItem = tbm.getToolBarItem("startstop");
@@ -1358,7 +1435,10 @@ public class ToolBarView
 	{
 		@Override
 		public void pressed(SWTSkinButtonUtility buttonUtility,
-		                    SWTSkinObject skinObject, int stateMask) {
+		                    SWTSkinObject skinObject, int button, int stateMask) {
+			if ( button != 1 ){
+				return;
+			}
 			ToolBarItem item = (ToolBarItem) buttonUtility.getSkinObject().getData(
 					"toolbaritem");
 			boolean rightClick = (stateMask & (SWT.BUTTON3 | SWT.MOD4)) > 0;
