@@ -44,6 +44,7 @@ import com.biglybt.ui.mdi.MdiEntry;
 import com.biglybt.ui.mdi.MultipleDocumentInterface;
 import com.biglybt.ui.swt.FixedHTMLTransfer;
 import com.biglybt.ui.swt.FixedURLTransfer;
+import com.biglybt.ui.swt.MenuBuildUtils;
 import com.biglybt.ui.swt.UIFunctionsManagerSWT;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.debug.ObfuscateImage;
@@ -199,12 +200,12 @@ public class SideBar
 		Display.getDefault().addFilter(SWT.KeyDown, new Listener() {
 			@Override
 			public void handleEvent(Event event) {
-				// F9 is standard Seamonkey, but doesn't work on OSX
+				
 				// Command Option T is standard on OSX
 				// F7 works on both
-				if (event.keyCode == SWT.F9
-						|| event.keyCode == SWT.F7
-						|| (event.keyCode == 116 && event.stateMask == (SWT.COMMAND | SWT.ALT))) {
+				if (	event.keyCode == SWT.F7	|| 
+						(event.keyCode == 116 && event.stateMask == (SWT.COMMAND | SWT.ALT))){
+					
 					event.doit = false;
 					event.keyCode = 0;
 					event.character = '\0';
@@ -255,6 +256,12 @@ public class SideBar
 		UIManager uim = pi.getUIManager();
 		MenuManager menuManager = uim.getMenuManager();
 		
+		{
+			MenuItem menuItem = menuManager.addMenuItem("sidebar._end_", "sep");
+			menuItem.setDisposeWithUIDetach(UIInstance.UIT_SWT);
+			menuItem.setStyle(MenuItem.STYLE_SEPARATOR);
+		}
+		
 		{
 			MenuItem menuItem = menuManager.addMenuItem("sidebar._end_", "UpdateWindow.close");
 			menuItem.setDisposeWithUIDetach(UIInstance.UIT_SWT);
@@ -347,6 +354,20 @@ public class SideBar
 				}
 			});
 			
+			MenuItem menuItemRightbar = menuManager.addMenuItem( menuParentItem, "label.rightbar");
+
+			menuItemRightbar.addListener(new MenuItemListener() {
+				@Override
+				public void selected(MenuItem menu, Object target) {
+					SideBarEntrySWT sbe = getCurrentEntry();
+	
+					if ( sbe != null ){
+						
+						MainMDISetup.getSb_dashboard().addItemToRightbar( sbe );
+					}
+				}
+			});
+			
 			MenuItem menuItemQuickLinks = menuManager.addMenuItem( menuParentItem, ql_res );
 
 			menuItemQuickLinks.addListener(new MenuItemListener() {
@@ -1104,6 +1125,18 @@ public class SideBar
 						
 							break;
 						}
+						case SWT.KeyDown:{
+						
+							MdiEntry currentEntry = getCurrentEntry();
+							
+							if ( currentEntry != null ){
+								
+								if ( currentEntry.processAccelerator( event.character, event.stateMask )){
+									event.doit = false;
+								}
+							}
+							break;
+						}
 					}
 				} catch (Exception e) {
 					Debug.out(e);
@@ -1131,6 +1164,10 @@ public class SideBar
 
 		// to disable collapsing
 		tree.addListener(SWT.Collapse, treeListener);
+		
+		// for accelerators
+		
+		tree.addListener(SWT.KeyDown, treeListener);
 
 
 		dropTarget = new DropTarget(tree, DND.DROP_DEFAULT | DND.DROP_MOVE | DND.DROP_COPY | DND.DROP_LINK
@@ -1284,10 +1321,7 @@ public class SideBar
 
 				if ( entry == null || entry.getParentID() == null ){
 					
-					if ( menuTree.getItemCount() > 0 ){
-						
-						new org.eclipse.swt.widgets.MenuItem( menuTree, SWT.SEPARATOR );
-					}
+					MenuBuildUtils.addSeparator( menuTree );
 					
 					org.eclipse.swt.widgets.MenuItem mi = new org.eclipse.swt.widgets.MenuItem( menuTree, SWT.PUSH );
 					
