@@ -66,11 +66,6 @@ GeneralOpsPanel
 
 	private boolean	unavailable;
 
-	private boolean mouseLeftDown = false;
-	private boolean mouseRightDown = false;
-	private int xDown;
-	private int yDown;
-
 	private String		id;
 	private Image 		img;
 
@@ -124,21 +119,13 @@ GeneralOpsPanel
 
 			@Override
 			public void mouseDown(MouseEvent event) {
-				if(event.button == 1) mouseLeftDown = true;
-				if(event.button == 3) mouseRightDown = true;
-				xDown = event.x;
-				yDown = event.y;
-				scale.saveMinX = scale.minX;
-				scale.saveMaxX = scale.maxX;
-				scale.saveMinY = scale.minY;
-				scale.saveMaxY = scale.maxY;
-				scale.saveRotation = scale.rotation;
+				scale.mouseDown( event );
 			}
 
 			@Override
 			public void mouseUp(MouseEvent event) {
 				
-				if ( mouseLeftDown ){
+				if ( scale.mouseLeftDown ){
 					int	x = event.x;
 					int y = event.y;
 					
@@ -166,7 +153,7 @@ GeneralOpsPanel
 					}
 				}
 				
-				if ( mouseRightDown ){
+				if ( scale.mouseRightDown ){
 					
 					int	x = event.x;
 					int y = event.y;
@@ -213,8 +200,7 @@ GeneralOpsPanel
 					}
 				}	
 				
-				if(event.button == 1) mouseLeftDown = false;
-				if(event.button == 3) mouseRightDown = false;
+				scale.mouseUp( event );
 				
 				refresh();
 			}
@@ -235,36 +221,7 @@ GeneralOpsPanel
 		canvas.addListener(SWT.MouseWheel, new Listener() {
 			@Override
 			public void handleEvent(Event event) {
-				// System.out.println(event.count);
-				scale.saveMinX = scale.minX;
-				scale.saveMaxX = scale.maxX;
-				scale.saveMinY = scale.minY;
-				scale.saveMaxY = scale.maxY;
-
-				int deltaY = event.count * -5;
-				// scaleFactor>1 means zoom in, this happens when
-				// deltaY<0 which happens when the mouse is moved up.
-				float scaleFactor = 1 - (float) deltaY / 300;
-				if(scaleFactor <= 0) scaleFactor = 0.01f;
-
-				// Scalefactor of e.g. 3 makes elements 3 times larger
-				float moveFactor = 1 - 1/scaleFactor;
-
-				Canvas canvas = ((Canvas) event.widget);
-				Point canvasSize = canvas.getSize();
-				// event.x, event.y are relative to control
-				float mouseXpct = (event.x + 1) / (float) canvasSize.x;
-				float mouseYpct = (event.y + 1) / (float) canvasSize.y;
-				float xOfs = (mouseXpct - 0.5f) * (scale.saveMaxX - scale.saveMinX);
-				float yOfs = (mouseYpct - 0.5f) * (scale.saveMaxY - scale.saveMinY);
-
-				float centerX = ((scale.saveMinX + scale.saveMaxX)/2) + xOfs;
-				scale.minX = scale.saveMinX + moveFactor * (centerX - scale.saveMinX);
-				scale.maxX = scale.saveMaxX - moveFactor * (scale.saveMaxX - centerX);
-
-				float centerY = ((scale.saveMinY + scale.saveMaxY)/2) + yOfs;
-				scale.minY = scale.saveMinY + moveFactor * (centerY - scale.saveMinY);
-				scale.maxY = scale.saveMaxY - moveFactor * (scale.saveMaxY - centerY);
+				scale.mouseWheel(event);
 				refresh();
 			}
 		});
@@ -272,67 +229,9 @@ GeneralOpsPanel
 		canvas.addMouseMoveListener(new MouseMoveListener() {
 			@Override
 			public void mouseMove(MouseEvent event) {
-				boolean	do_refresh = false;
-				if(mouseLeftDown && (event.stateMask & SWT.MOD4) == 0) {
-					int deltaX = event.x - xDown;
-					int deltaY = event.y - yDown;
-					float width = scale.width;
-					float height = scale.height;
-					float ratioX = (scale.saveMaxX - scale.saveMinX) / width;
-					float ratioY = (scale.saveMaxY - scale.saveMinY) / height;
-					float realDeltaX = deltaX * ratioX;
-					float realDeltaY  = deltaY * ratioY;
-					scale.minX = scale.saveMinX - realDeltaX;
-					scale.maxX = scale.saveMaxX - realDeltaX;
-					scale.minY = scale.saveMinY - realDeltaY;
-					scale.maxY = scale.saveMaxY - realDeltaY;
-					do_refresh = true;
-				}
-				if(mouseRightDown || (mouseLeftDown && (event.stateMask & SWT.MOD4) > 0)) {
-					int deltaX = event.x - xDown;
-					int deltaY = event.y - yDown;
-					int diffX = Math.abs(deltaX);
-					int diffY = Math.abs(deltaY);
-					// Don't start rotating until a few px movement.  Helps when
-					// user just wants to zoom (move up/down) or rotate (move left/right) 
-					// and doesn't have steady hand
-					if (diffY > diffX && diffX <= 3) {
-						deltaX = 0;
-					}
-					if (diffY > diffX && diffY <= 3) {
-						deltaY = 0;
-					}
-					scale.rotation = scale.saveRotation - (float) deltaX / 100;
+				if ( scale.mouseMove( event )){
 
-					// scaleFactor>1 means zoom in, this happens when
-					// deltaY<0 which happens when the mouse is moved up.
-					float scaleFactor = 1 - (float) deltaY / 300;
-					if(scaleFactor <= 0) scaleFactor = 0.01f;
-
-					// Scalefactor of e.g. 3 makes elements 3 times larger
-					float moveFactor = 1 - 1/scaleFactor;
-
-					Canvas canvas = ((Canvas) event.widget);
-					Point canvasSize = canvas.getSize();
-					// event.x, event.y are relative to control
-					float mouseXpct = (xDown + 1) / (float) canvasSize.x;
-					float mouseYpct = (yDown + 1) / (float) canvasSize.y;
-					float xOfs = (mouseXpct - 0.5f) * (scale.saveMaxX - scale.saveMinX);
-					float yOfs = (mouseYpct - 0.5f) * (scale.saveMaxY - scale.saveMinY);
-
-					float centerX = (scale.saveMinX + scale.saveMaxX)/2 + xOfs;
-					scale.minX = scale.saveMinX + moveFactor * (centerX - scale.saveMinX);
-					scale.maxX = scale.saveMaxX - moveFactor * (scale.saveMaxX - centerX);
-
-					float centerY = (scale.saveMinY + scale.saveMaxY)/2 + yOfs;
-					scale.minY = scale.saveMinY + moveFactor * (centerY - scale.saveMinY);
-					scale.maxY = scale.saveMaxY - moveFactor * (scale.saveMaxY - centerY);
-					do_refresh = true;
-				}
-
-				if ( do_refresh ){
-
-						refresh();
+					refresh();
 				}
 			}
 		});
@@ -534,11 +433,7 @@ GeneralOpsPanel
 		float		max_y,
 		double		rot )
 	{
-		scale.minX 		= min_x;
-		scale.maxX 		= max_x;
-		scale.minY 		= min_y;
-		scale.maxY 		= max_y;
-		scale.rotation 	= rot;
+		scale.setScaleAndRotation( min_x, max_x, min_y, max_y, rot );
 	}
 
 	private boolean isRefreshQueued = false;
@@ -569,8 +464,7 @@ GeneralOpsPanel
 			return;
 		}
 
-		scale.width = size.width;
-		scale.height = size.height;
+		scale.setSize( size );
 
 		boolean needNewImage = img == null || img.isDisposed();
 		if (!needNewImage) {
