@@ -68,6 +68,7 @@ import com.biglybt.pif.ui.UIInputReceiver;
 import com.biglybt.pif.ui.UIInputReceiverListener;
 import com.biglybt.pif.ui.tables.TableRowMouseEvent;
 import com.biglybt.pif.ui.tables.TableRowMouseListener;
+import com.biglybt.pifimpl.local.ui.tables.TableContextMenuItemImpl;
 
 /**
  * A TableView implemented by painting on a canvas
@@ -2152,6 +2153,11 @@ public class TableViewPainted
 		setRowDefaultHeightPX(newHeight);
 		TableRowCore[] rows = getRowsAndSubRows(true);
 		if (rows.length == 0) {
+				// still want table to redraw (especially when using alternate line colours...)
+			Utils.execSWTThreadLater(0,()->{
+				swt_updateCanvasImage(false);
+			});
+			
 			return;
 		}
 		for (TableRowCore row : rows) {
@@ -2261,6 +2267,11 @@ public class TableViewPainted
 		return new TableRowPainted(null, this, object, true);
 	}
 
+	@Override
+	public TableRowSWT createFakeRow(Object object){
+		return new TableRowPainted(null, this, object );
+	}
+	
 	/* (non-Javadoc)
 	 * @see TableViewImpl#visibleRowsChanged()
 	 */
@@ -3129,6 +3140,7 @@ public class TableViewPainted
 					menu.setData(MENUKEY_IS_HEADER, false);
 				}
 				Point pt = cHeaderArea.toControl(event.x, event.y);
+				menu.setData(TableContextMenuItemImpl.MENUKEY_TABLE_VIEW, TableViewPainted.this );
 				menu.setData(MENUKEY_COLUMN, getTableColumnByOffset(pt.x));
 			}
 		});
@@ -3362,7 +3374,7 @@ public class TableViewPainted
 			// optimize multiple row withdraws (e.g. on view construction) so invalidate the
 			// aggregate area
 
-		synchronized( pending_rows ){
+		synchronized( visibleRows_sync ){
 
 			pending_rows.add( row );
 		}
@@ -3374,7 +3386,7 @@ public class TableViewPainted
 
 				List<TableRowPainted>	rows;
 
-				synchronized( pending_rows ){
+				synchronized( visibleRows_sync ){
 
 					if ( pending_rows.size() == 0 ){
 
